<?php
/**
 * Registers a widget to show a section of blog posts.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Blog_Posts_Widget widget.
 */
class Organic_Widgets_Pro_Blog_Posts_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_blog_posts_section', // Base ID.
			__( 'Organic Blog Posts', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'A section displaying recent blog posts.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => false, // No selective refresh to reload masonry on changes.
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'video'     => false,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'          => true,
			'title_font'             => true,
			'title_color'            => true,
			'title_weight'           => true,
			'title_spacing'          => true,
			'title_size'             => true,
			'content_heading_font'   => true,
			'content_heading_size'   => true,
			'content_heading_weight' => true,
			'body_font'              => true,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner'     => false,
			'content_orientation' => true,
			'padding_top'         => true,
			'padding_bottom'      => true,
			'custom_height'       => true,
			'custom_width'        => true,
			'content_width'       => true,
			'full_height'         => false,
		);

		// Display options.
		$this->display_options = array(
			'hide_title'   => false,
			'hide_meta'    => true,
			'hide_content' => true,
			'hide_bg'      => true,
		);

		// Admin Scripts.
		add_action( 'admin_print_scripts-widgets.php', array( $this, 'admin_setup' ) );
		add_action( 'admin_footer-widgets.php', array( $this, 'render_control_template_scripts' ) );

		// Public scripts.
		add_action( 'init', array( $this, 'public_scripts' ) );
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$attr        = array();
		$attr        = apply_filters( 'image_widget_image_attributes', $attr, $instance );
		$bg_image_id = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image    = ( isset( $instance['bg_image'] ) && '' !== $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color    = ( isset( $instance['bg_color'] ) && '' !== $instance['bg_color'] ) ? $instance['bg_color'] : false;
		$category    = ( isset( $instance['category'] ) ) ? $instance['category'] : 0;
		$num_columns = ( isset( $instance['num_columns'] ) ) ? $instance['num_columns'] : 1;
		$max_posts   = ( isset( $instance['max_posts'] ) ) ? $instance['max_posts'] : 3;
		$card_style  = ( isset( $instance['card_style'] ) ) ? $instance['card_style'] : 'style-squared';
		$button_text = ( isset( $instance['button_text'] ) && '' !== $instance['button_text'] ) ? $instance['button_text'] : false;
		$button_url  = ( isset( $instance['button_url'] ) && '' !== $instance['button_url'] ) ? $instance['button_url'] : false;

		// Register Button Link Target Option.
		if ( isset( $instance['button_target'] ) ) {
			$button_target = $instance['button_target'];
		} else {
			$button_target = false;
		}
		// Register BG Fixed Image Option.
		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		// Register BG Repeat Option.
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}
		// Register Content Orientation Option.
		if ( isset( $instance['orientation'] ) ) {
			$content_orientation = $instance['orientation'];
		} else {
			$content_orientation = 'vertical';
		}
		// Register Hide Content BG Option.
		if ( isset( $instance['hide_content_bg'] ) ) {
			$hide_content_bg = $instance['hide_content_bg'];
		} else {
			$hide_content_bg = false;
		}
		// Register Hide Post Meta Option.
		if ( isset( $instance['hide_post_meta'] ) ) {
			$hide_post_meta = $instance['hide_post_meta'];
		} else {
			$hide_post_meta = false;
		}
		// Register Hide Post Content Option.
		if ( isset( $instance['hide_post_content'] ) ) {
			$hide_post_content = $instance['hide_post_content'];
		} else {
			$hide_post_content = false;
		}
		// Register Display Pagination Option.
		if ( isset( $instance['display_pagination'] ) ) {
			$display_pagination = $instance['display_pagination'];
		} else {
			$display_pagination = false;
		}
		// Register Display Full Content Option.
		if ( isset( $instance['display_full_content'] ) ) {
			$display_full_content = $instance['display_full_content'];
		} else {
			$display_full_content = false;
		}

		echo $args['before_widget'];

		?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_max_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content {
					max-width: <?php echo absint( $instance['content_max_width'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) || '' !== $instance['widget_padding_top'] || '' !== $instance['widget_padding_bottom'] ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-blog-posts-section {
					<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
					min-height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_top'] ) { ?>
					padding-top: <?php echo intval( $instance['widget_padding_top'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_bottom'] ) { ?>
					padding-bottom: <?php echo intval( $instance['widget_padding_bottom'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['body_font_family'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-text p,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-card-content p {
					font-family: <?php echo esc_html( $instance['body_font_family'] ); ?>;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_heading_font_family'] ) || ! empty( $instance['content_heading_font_weight'] ) || ! empty( $instance['content_heading_font_size'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-card-content h4 {
					<?php if ( ! empty( $instance['content_heading_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['content_heading_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['content_heading_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['content_heading_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['content_heading_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['content_heading_font_size'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<?php /** BEGIN .organic-widgets-section */ ?>
		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"<?php } ?>
		class="organic-widgets-section organic-widgets-blog-posts-section
		<?php if ( $bg_image_fixed ) echo 'organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo 'organic-widgets-repeat-bg-img'; ?>
		<?php if ( 'horizontal' === $content_orientation ) echo 'organic-widgets-content-horizontal'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>style="background-image:url(<?php echo $bg_image; ?>);"
		<?php } elseif ($bg_color) { ?>style="background-color:<?php echo $bg_color; ?>;"<?php } ?>>

			<?php /** BEGIN .organic-widgets-content */ ?>
			<div class="organic-widgets-content">

			<?php if ( ! empty( $instance['title'] ) ) { ?>
				<<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?> class="organic-widgets-title"><?php echo apply_filters( 'organic_widget_title', $instance['title'] ); ?></<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?>>
			<?php } ?>

			<?php if ( ! empty( $instance['text'] ) ) { ?>
				<div class="organic-widgets-text"><?php echo wp_kses_post( apply_filters( 'the_content', $instance['text'] ) ); ?></div>
			<?php } ?>

			<?php
			if ( get_query_var( 'paged' ) ) {
				$paged = get_query_var( 'paged' );
			} elseif ( get_query_var( 'page' ) ) {
				$paged = get_query_var( 'page' );
			} else {
				$paged = 1;
			}
			?>
			<?php global $wp_query; ?>

			<?php
			$blog_query_args = array(
				'cat'              => $category,
				'posts_per_page'   => $max_posts,
				'paged'            => $paged,
				'post_type'        => 'post',
				'suppress_filters' => 0,
			)
			?>

			<?php $blog_query = new WP_Query( $blog_query_args ); ?>

			<?php
				$temp_query = $wp_query;
				$wp_query   = null;
				$wp_query   = $blog_query;
			?>

			<?php if ( $blog_query->have_posts() ) : ?>

				<?php /** BEGIN .organic-widgets-row */ ?>
				<div class="organic-widgets-blog-posts-holder organic-widgets-post-holder organic-widgets-row organic-widgets-masonry-container <?php echo esc_html( $card_style ); ?>">

					<?php while ( $blog_query->have_posts() ) : $blog_query->the_post(); ?>

					<?php if ( 'vertical' === $content_orientation && '2' >= $num_columns ) { ?>
						<?php $thumb = ( '' !== get_the_post_thumbnail() ) ? wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' ) : false; ?>
					<?php } else { ?>
						<?php $thumb = ( '' !== get_the_post_thumbnail() ) ? wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' ) : false; ?>
					<?php } ?>

					<?php /** BEGIN .organic-widgets-masonry-wrapper */ ?>
					<div class="organic-widgets-masonry-wrapper organic-widgets-column organic-widgets-<?php echo $this->column_string( $num_columns ); ?>">

						<article>

							<?php if ( false === $hide_content_bg ) { ?><div class="organic-widgets-card clearfix"><?php } ?>

								<?php if ( has_post_thumbnail() ) { ?>
								<a class="organic-widgets-featured-img" href="<?php the_permalink(); ?>" style="background-image: url(<?php echo esc_url( $thumb[0] ); ?>);">
									<span class="organic-widgets-hide-img"><?php the_post_thumbnail( 'medium_large' ); ?></span>
								</a>
								<?php } ?>

								<?php /** BEGIN .organic-widgets-card-content */ ?>
								<div class="organic-widgets-card-content">

									<h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

									<?php /** BEGIN .organic-widgets-post-meta */ ?>
									<div class="organic-widgets-post-meta <?php if ( $hide_post_meta ) echo 'organic-widgets-hide-content'; ?>">
										<p class="organic-widgets-post-date">
											<?php echo get_the_date( get_option( 'date_format' ) ); ?>
										</p>
										<p class="organic-widgets-post-author">
											<?php esc_html_e( 'By ', 'organic-widgets-pro' ); ?><?php esc_url( the_author_posts_link() ); ?>
										</p>
									<?php /** END .organic-widgets-post-meta */ ?>
									</div>

									<?php /** BEGIN .organic-widgets-post-content */ ?>
									<div class="organic-widgets-post-content <?php if ( $hide_post_content ) echo 'organic-widgets-hide-content'; ?>">
										<?php if ( false === $display_full_content ) { ?>
											<?php the_excerpt(); ?>
										<?php } else { ?>
											<?php the_content( 'Read More' ); ?>
										<?php } ?>
										<?php edit_post_link( esc_html__( '(Edit)', 'organic-widgets-pro' ), '<p>', '</p>' ); ?>
									<?php /** END .organic-widgets-post-content */ ?>
									</div>

								<?php /** END .organic-widgets-card-content */ ?>
								</div>

							<?php if ( false === $hide_content_bg ) { ?></div><?php } ?>

						</article>

					<?php /** END .organic-widgets-masonry-wrapper */ ?>
					</div>

					<?php endwhile; ?>

				<?php /** END .organic-widgets-row */ ?>
				</div>

				<?php if ( '1' == $display_pagination ) { ?>

					<?php if ( $blog_query->max_num_pages > 1 ) { ?>

						<?php
							the_posts_pagination( array(
								'prev_text' => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Previous Page', 'organic-widgets-pro' ) . ' </span>&laquo;',
								'next_text' => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Next Page', 'organic-widgets-pro' ) . ' </span>&raquo;',
							) );
						?>

					<?php } ?>

				<?php } ?>

				<?php wp_reset_postdata(); ?>
			<?php endif; ?>

			<?php
				$wp_query = null;
				$wp_query = $temp_query;
			?>

			<?php /** END .organic-widgets-content */ ?>
			</div>

			<?php if ( ! empty( $button_url ) ) { ?>
				<div class="organic-widgets-button-holder">
					<a class="organic-widgets-button button" href="<?php echo esc_url( $button_url );?>" <?php if ( '1' == $button_target ) { ?>target="_blank"<?php } ?>><?php if ( ! empty( $button_text ) ) { echo esc_html_e( $button_text, 'organic-widgets-pro' ); } else { esc_html_e( 'See More', 'organic-widgets-pro' ); } ?></a>
				</div>
			<?php } ?>

		<?php /** END .organic-widgets-section */ ?>
		</div>

		<?php

		echo $args['after_widget'];

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'text'  => '',
			)
		);

		// Setup Variables.
		$this->id_prefix = $this->get_field_id( '' );

		if ( isset( $instance['category'] ) ) {
			$category = $instance['category'];
		} else {
			$category = 0;
		}
		if ( isset( $instance['num_columns'] ) ) {
			$num_columns = $instance['num_columns'];
		} else {
			$num_columns = 1;
		}
		if ( isset( $instance['max_posts'] ) ) {
			$max_posts = $instance['max_posts'];
		} else {
			$max_posts = 3;
		}
		if ( isset( $instance['card_style'] ) ) {
			$card_style = $instance['card_style'];
		} else {
			$card_style = 'style-squared';
		}
		if ( isset( $instance['display_pagination'] ) ) {
			$display_pagination = $instance['display_pagination'];
		} else {
			$display_pagination = false;
		}
		if ( isset( $instance['display_full_content'] ) ) {
			$display_full_content = $instance['display_full_content'];
		} else {
			$display_full_content = false;
		}
		if ( isset( $instance['button_text'] ) ) {
			$button_text = $instance['button_text'];
		} else {
			$button_text = false;
		}
		if ( isset( $instance['button_url'] ) ) {
			$button_url = $instance['button_url'];
		} else {
			$button_url = false;
		}
		if ( isset( $instance['button_target'] ) ) {
			$button_target = $instance['button_target'];
		} else {
			$button_target = false;
		}

		?>

		<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" class="title" type="hidden" value="<?php echo esc_attr( $instance['title'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" class="text organic-widgets-wysiwyg-anchor" type="hidden" value="<?php echo esc_attr( $instance['text'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'filter' ); ?>" name="<?php echo $this->get_field_name( 'filter' ); ?>" class="filter" type="hidden" value="on">
		<input id="<?php echo $this->get_field_id( 'visual' ); ?>" name="<?php echo $this->get_field_name( 'visual' ); ?>" class="visual" type="hidden" value="on">

		<p>
			<label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Post Category:', 'organic-widgets-pro' ); ?></label>
			<?php
			wp_dropdown_categories( array(
				'show_option_all' => __( 'All Categories' ),
				'selected'        => $category,
				'id'              => $this->get_field_id( 'category' ),
				'name'            => $this->get_field_name( 'category' ),
			) );
			?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'max_posts' ); ?>"><?php _e( 'Max Number of Posts:', 'organic-widgets-pro' ); ?></label>
			<input type="number" min="1" max="16" value="<?php echo absint( $max_posts ); ?>" id="<?php echo $this->get_field_id( 'max_posts' ); ?>" name="<?php echo $this->get_field_name( 'max_posts' ); ?>" class="widefat" style="width:100%;"/>
		</p>
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $display_pagination, '1' ); ?> id="<?php echo $this->get_field_id( 'display_pagination' ); ?>" name="<?php echo $this->get_field_name( 'display_pagination' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'display_pagination' ); ?>"><?php _e( 'Display Post Pagination', 'organic-widgets-pro' ); ?></label>
		</p>
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $display_full_content, '1' ); ?> id="<?php echo $this->get_field_id( 'display_full_content' ); ?>" name="<?php echo $this->get_field_name( 'display_full_content' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'display_full_content' ); ?>"><?php _e( 'Display Full Post Content', 'organic-widgets-pro' ); ?></label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'num_columns' ); ?>"><?php _e( 'Number of Columns:', 'organic-widgets-pro' ); ?></label>
			<select id="<?php echo $this->get_field_id( 'num_columns' ); ?>" name="<?php echo $this->get_field_name( 'num_columns' ); ?>" class="widefat" style="width:100%;">
				<option <?php selected( $num_columns, '1' ); ?> value="1">1</option>
				<option <?php selected( $num_columns, '2' ); ?> value="2">2</option>
				<option <?php selected( $num_columns, '3' ); ?> value="3">3</option>
				<option <?php selected( $num_columns, '4' ); ?> value="4">4</option>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'card_style' ); ?>"><?php _e( 'Card Style:', 'organic-widgets-pro' ); ?>
				<select id="<?php echo $this->get_field_id( 'card_style' ); ?>" name="<?php echo $this->get_field_name( 'card_style' ); ?>">
					<option value="style-squared" <?php echo ( 'style-squared' === $card_style ) ? 'selected' : ''; ?>><?php _e( 'Square', 'organic-widgets-pro' ); ?></option>
					<option value="style-rounded" <?php echo ( 'style-rounded' === $card_style ) ? 'selected' : ''; ?>><?php _e( 'Round', 'organic-widgets-pro' ); ?></option>
					<option value="style-bordered" <?php echo ( 'style-bordered' === $card_style ) ? 'selected' : ''; ?>><?php _e( 'Border', 'organic-widgets-pro' ); ?></option>
					<option value="style-angular" <?php echo ( 'style-angular' === $card_style ) ? 'selected' : ''; ?>><?php _e( 'Angular', 'organic-widgets-pro' ); ?></option>
				</select>
			</label>
		</p>
		<div class="organic-widgets-option-set">
			<p class="organic-widgets-input-half">
				<label for="<?php echo $this->get_field_id( 'button_text' ); ?>"><?php _e( 'Button Text:', 'organic-widgets-pro' ); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'button_text' ); ?>" name="<?php echo $this->get_field_name( 'button_text' ); ?>" value="<?php echo esc_html( $button_text ); ?>" />
			</p>
			<p class="organic-widgets-input-half last">
				<label for="<?php echo $this->get_field_id( 'button_url' ); ?>"><?php _e('Button URL', 'organic-widgets-pro'); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'button_url' ); ?>" name="<?php echo $this->get_field_name( 'button_url' ); ?>" value="<?php echo esc_url( $button_url ); ?>" />
			</p>
		</div>
		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $button_target, '1' ); ?> id="<?php echo $this->get_field_id( 'button_target' ); ?>" name="<?php echo $this->get_field_name( 'button_target' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'button_target' ); ?>"><?php esc_html_e( 'Open Link In New Window', 'organic-widgets-pro' ); ?></label>
		</p>

		<br />

		<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

		<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

		<?php $this->section_display_input_markup( $instance, $this->display_options ); ?>

		<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php _e( 'Custom Widget Class', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
		</p>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
		</p>

		<?php

	}

	/**
	 * Render form template scripts.
	 *
	 * @access public
	 */
	public function render_control_template_scripts() {

		?>
		<script type="text/html" id="tmpl-widget-organic_widgets_blog_posts_section-control-fields">

			<# var elementIdPrefix = 'el' + String( Math.random() ).replace( /\D/g, '' ) + '_' #>

			<p>
				<label for="{{ elementIdPrefix }}title"><?php esc_html_e( 'Title:' ); ?></label>
				<input id="{{ elementIdPrefix }}title" type="text" class="widefat title">
			</p>
			<p>
				<label for="{{ elementIdPrefix }}text" class="screen-reader-text"><?php esc_html_e( 'Content:' ); ?></label>
				<textarea id="{{ elementIdPrefix }}text" class="widefat text" style="height: 200px" rows="16" cols="20"></textarea>
			</p>
		</script>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		/*--- Text/Title ----*/
		if ( ! isset( $newinstance['filter'] ) ) {
			$instance['filter'] = false;
		}
		if ( ! isset( $newinstance['visual'] ) ) {
			$instance['visual'] = null;
		}
		// Upgrade 4.8.0 format.
		if ( isset( $old_instance['filter'] ) && 'content' === $old_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( 'content' === $new_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( isset( $new_instance['visual'] ) ) {
			$instance['visual'] = ! empty( $new_instance['visual'] );
		}
		// Filter is always true in visual mode.
		if ( ! empty( $instance['visual'] ) ) {
			$instance['filter'] = true;
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance['title'] = $new_instance['title'];
			$instance['text']  = $new_instance['text'];
		} else {
			$instance['title'] = wp_kses_post( $new_instance['title'] );
			$instance['text']  = wp_kses_post( $new_instance['text'] );
		}
		/*--- END Text/Title ----*/

		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}
		if ( isset( $new_instance['category'] ) ) {
			$instance['category'] = wp_strip_all_tags( $new_instance['category'] );
		}
		if ( isset( $new_instance['num_columns'] ) ) {
			$instance['num_columns'] = wp_strip_all_tags( $new_instance['num_columns'] );
		}
		if ( isset( $new_instance['max_posts'] ) ) {
			$instance['max_posts'] = wp_strip_all_tags( $new_instance['max_posts'] );
		}
		if ( isset( $new_instance['card_style'] ) ) {
			$instance['card_style'] = wp_strip_all_tags( $new_instance['card_style'] );
		}
		if ( isset( $new_instance['display_pagination'] ) ) {
			$instance['display_pagination'] = true;
		} else {
			$instance['display_pagination'] = false;
		}
		if ( isset( $new_instance['display_full_content'] ) ) {
			$instance['display_full_content'] = true;
		} else {
			$instance['display_full_content'] = false;
		}
		if ( isset( $new_instance['button_text'] ) ) {
			$instance['button_text'] = wp_strip_all_tags( $new_instance['button_text'] );
		}
		if ( isset( $new_instance['button_url'] ) ) {
			$instance['button_url'] = wp_strip_all_tags( $new_instance['button_url'] );
		}
		if ( isset( $new_instance['button_target'] ) ) {
			$instance['button_target'] = true;
		} else {
			$instance['button_target'] = false;
		}

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		/*--- END Background ----*/

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = wp_strip_all_tags( $new_instance['title_text_heading'] );
		}
		if ( isset( $new_instance['title_text_color'] ) ) {
			$instance['title_text_color'] = wp_strip_all_tags( $new_instance['title_text_color'] );
		}
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		if ( isset( $new_instance['content_heading_font_family'] ) ) {
			$instance['content_heading_font_family'] = wp_strip_all_tags( $new_instance['content_heading_font_family'] );
		}
		if ( isset( $new_instance['content_heading_font_weight'] ) ) {
			$instance['content_heading_font_weight'] = wp_strip_all_tags( $new_instance['content_heading_font_weight'] );
		}
		if ( isset( $new_instance['content_heading_font_size'] ) ) {
			$instance['content_heading_font_size'] = wp_strip_all_tags( $new_instance['content_heading_font_size'] );
		}
		if ( isset( $new_instance['body_font_family'] ) ) {
			$instance['body_font_family'] = wp_strip_all_tags( $new_instance['body_font_family'] );
		}
		/*--- END Font Options ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['orientation'] ) ) {
			$instance['orientation'] = wp_strip_all_tags( $new_instance['orientation'] );
		}
		if ( isset( $new_instance['widget_padding_top'] ) ) {
			$instance['widget_padding_top'] = wp_strip_all_tags( $new_instance['widget_padding_top'] );
		}
		if ( isset( $new_instance['widget_padding_bottom'] ) ) {
			$instance['widget_padding_bottom'] = wp_strip_all_tags( $new_instance['widget_padding_bottom'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['content_max_width'] ) ) {
			$instance['content_max_width'] = wp_strip_all_tags( $new_instance['content_max_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		/*--- END Layout ----*/

		/*--- Display ----*/
		if ( isset( $new_instance['hide_post_meta'] ) ) {
			$instance['hide_post_meta'] = true;
		} else {
			$instance['hide_post_meta'] = false;
		}
		if ( isset( $new_instance['hide_post_content'] ) ) {
			$instance['hide_post_content'] = true;
		} else {
			$instance['hide_post_content'] = false;
		}
		if ( isset( $new_instance['hide_content_bg'] ) ) {
			$instance['hide_content_bg'] = true;
		} else {
			$instance['hide_content_bg'] = false;
		}
		if ( isset( $new_instance['display_full_content'] ) ) {
			$instance['display_full_content'] = true;
		} else {
			$instance['display_full_content'] = false;
		}
		/*--- END Display ----*/

		return $instance;
	}

	/**
	 * Enqueue admin javascript.
	 */
	public function admin_setup() {

		// Text Editor.
		wp_enqueue_editor();
		wp_enqueue_script( 'organic-widgets-blog-posts-section-text-title', plugin_dir_url( __FILE__ ) . 'js/blog-posts-section-widgets.js', array( 'jquery', 'wp-embed', 'underscore' ), '1.0', true );
		wp_localize_script( 'organic-widgets-blog-posts-section-text-title', 'OrganicBlogPostsSectionWidget', array(
			'id_base' => $this->id_base,
		) );
		wp_add_inline_script( 'organic-widgets-blog-posts-section-text-title', 'wp.organicBlogPostsSectionWidget.init();', 'after' );

		wp_enqueue_media();

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );

		wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
		wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
			'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
			'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
		) );

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_script( 'organic-widgets-masonry', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/masonry-setup.js', array( 'jquery', 'masonry' ), '1.0', true );

	}

} // class Organic_Widgets_Pro_Blog_Posts_Widget
