<?php
/**
 * Registers a widget to show business information.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Business_Info_Widget widget.
 */
class Organic_Widgets_Pro_Business_Info_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_business_info_section', // Base ID.
			__( 'Organic Business Info', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'Display your business information.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'video'     => false,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'          => true,
			'title_font'             => true,
			'title_color'            => true,
			'title_weight'           => true,
			'title_spacing'          => true,
			'title_size'             => true,
			'content_heading_font'   => false,
			'content_heading_size'   => false,
			'content_heading_weight' => false,
			'body_font'              => true,
			'text_alignment'         => false,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner'     => false,
			'content_orientation' => false,
			'padding_top'         => true,
			'padding_bottom'      => true,
			'custom_height'       => true,
			'custom_width'        => true,
			'content_width'       => true,
			'full_height'         => false,
		);

		// Admin Scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_setup' ) );
		add_action( 'admin_footer-widgets.php', array( $this, 'render_control_template_scripts' ) );

		// Public Scripts.
		if ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) {
			add_action( 'init', array( $this, 'public_scripts' ) );
		}
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$attr        = array();
		$attr        = apply_filters( 'image_widget_image_attributes', $attr, $instance );
		$bg_image_id = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image    = ( isset( $instance['bg_image'] ) && '' != $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color    = ( isset( $instance['bg_color'] ) && '' != $instance['bg_color'] ) ? $instance['bg_color'] : false;

		// Register European Address Format Option.
		if ( isset( $instance['eu_format'] ) ) {
			$eu_format = $instance['eu_format'];
		} else {
			$eu_format = false;
		}
		// Register BG Fixed Position Option.
		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		// Register BG Repeat Option.
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}

		$repeatable_array = ( isset( $instance['repeatable_array'] ) ) ? json_decode( $instance['repeatable_array'], true) : array();

		echo $args['before_widget'];

		?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_max_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content {
					max-width: <?php echo absint( $instance['content_max_width'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) || '' !== $instance['widget_padding_top'] || '' !== $instance['widget_padding_bottom'] ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-business-info-section {
					<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
					min-height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_top'] ) { ?>
					padding-top: <?php echo absint( $instance['widget_padding_top'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_bottom'] ) { ?>
					padding-bottom: <?php echo absint( $instance['widget_padding_bottom'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?>  .organic-widgets-business-info-column h6 {
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['body_font_family'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-business-info-section p {
					font-family: <?php echo esc_html( $instance['body_font_family'] ); ?>;
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<?php /** BEGIN .organic-widgets-section */ ?>
		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"<?php } ?>
		class="organic-widgets-section organic-widgets-business-info-section
		<?php if ( $bg_image_fixed ) echo 'organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo 'organic-widgets-repeat-bg-img'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>
			style="background-image:url(<?php echo esc_url( $bg_image ); ?>);"
		<?php } if ( $bg_color ) { ?>
			style="background-color:<?php echo esc_attr( $bg_color ); ?>;"
		<?php } ?>>

			<?php /** BEGIN .organic-widgets-content */ ?>
			<div class="organic-widgets-content">

				<?php /** BEGIN .organic-widgets-business-info */ ?>
				<div class="organic-widgets-business-info organic-widgets-business-info-column">

				<?php if ( ! empty( $instance['title'] ) ) { ?>
					<<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h4<?php } ?> class="organic-widgets-title"><?php echo apply_filters( 'organic_widget_title', $instance['title'] ); ?></<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h4<?php } ?>>
				<?php } ?>

				<?php if ( ! empty( $instance['text'] ) ) { ?>
					<div class="organic-widgets-text"><?php echo apply_filters( 'the_content', $instance['text'] ); ?></div>
				<?php } ?>

				<?php /** END .organic-widgets-business-info */ ?>
				</div>

				<?php if ( ! empty( $instance['business_hours'] ) ||
				! empty( $instance['business_hours_mon_open'] ) || ! empty( $instance['business_hours_mon_close'] ) ||
				! empty( $instance['business_hours_tues_open'] ) || ! empty( $instance['business_hours_tues_close'] ) ||
				! empty( $instance['business_hours_wed_open'] ) || ! empty( $instance['business_hours_wed_close'] ) ||
				! empty( $instance['business_hours_thurs_open'] ) || ! empty( $instance['business_hours_thurs_close'] ) ||
				! empty( $instance['business_hours_fri_open'] ) || ! empty( $instance['business_hours_fri_close'] ) ||
				! empty( $instance['business_hours_sat_open'] ) || ! empty( $instance['business_hours_sat_close'] ) ||
				! empty( $instance['business_hours_sun_open'] ) || ! empty( $instance['business_hours_sun_close'] ) ) { ?>

				<?php /** BEGIN .organic-widgets-business-hours */ ?>
				<div class="organic-widgets-business-hours organic-widgets-business-info-column">

					<?php if ( ! empty( $instance['business_hours'] ) ) { ?>
						<h6 class="organic-widgets-business-hours-title"><?php echo esc_html( $instance['business_hours'] ); ?></h6>
					<?php } ?>

					<?php if ( ! empty( $instance['business_hours_mon_open'] ) || ! empty( $instance['business_hours_mon_close'] ) ) { ?>
						<p class="organic-widgets-business-time">
							<span class="organic-widgets-business-day"><?php esc_html_e( 'Mon:', 'organic-widgets-pro' ) ?></span>
							<span class="organic-widgets-business-open-close">
								<?php echo esc_html( $instance['business_hours_mon_open'] ); ?> <?php esc_html_e( ' - ', 'organic-widgets-pro' ) ?> <?php echo esc_html( $instance['business_hours_mon_close'] ); ?>
							</span>
						</p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_hours_tues_open'] ) || ! empty( $instance['business_hours_tues_close'] ) ) { ?>
						<p class="organic-widgets-business-time">
							<span class="organic-widgets-business-day"><?php esc_html_e( 'Tues:', 'organic-widgets-pro' ) ?></span>
							<span class="organic-widgets-business-open-close">
								<?php echo esc_html( $instance['business_hours_tues_open'] ); ?> <?php esc_html_e( ' - ', 'organic-widgets-pro' ) ?> <?php echo esc_html( $instance['business_hours_tues_close'] ); ?>
							</span>
						</p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_hours_wed_open'] ) || ! empty( $instance['business_hours_wed_close'] ) ) { ?>
						<p class="organic-widgets-business-time">
							<span class="organic-widgets-business-day"><?php esc_html_e( 'Wed:', 'organic-widgets-pro' ) ?></span>
							<span class="organic-widgets-business-open-close">
								<?php echo esc_html( $instance['business_hours_wed_open'] ); ?> <?php esc_html_e( ' - ', 'organic-widgets-pro' ) ?> <?php echo esc_html( $instance['business_hours_wed_close'] ); ?>
							</span>
						</p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_hours_thurs_open'] ) || ! empty( $instance['business_hours_thurs_close'] ) ) { ?>
						<p class="organic-widgets-business-time">
							<span class="organic-widgets-business-day"><?php esc_html_e( 'Thur:', 'organic-widgets-pro' ) ?></span>
							<span class="organic-widgets-business-open-close">
								<?php echo esc_html( $instance['business_hours_thurs_open'] ); ?> <?php esc_html_e( ' - ', 'organic-widgets-pro' ) ?> <?php echo esc_html( $instance['business_hours_thurs_close'] ); ?>
							</span>
						</p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_hours_fri_open'] ) || ! empty( $instance['business_hours_fri_close'] ) ) { ?>
						<p class="organic-widgets-business-time">
							<span class="organic-widgets-business-day"><?php esc_html_e( 'Fri:', 'organic-widgets-pro' ) ?></span>
							<span class="organic-widgets-business-open-close">
								<?php echo esc_html( $instance['business_hours_fri_open'] ); ?> <?php esc_html_e( ' - ', 'organic-widgets-pro' ) ?> <?php echo esc_html( $instance['business_hours_fri_close'] ); ?>
							</span>
						</p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_hours_sat_open'] ) || ! empty( $instance['business_hours_sat_close'] ) ) { ?>
						<p class="organic-widgets-business-time">
							<span class="organic-widgets-business-day"><?php esc_html_e( 'Sat:', 'organic-widgets-pro' ) ?></span>
							<span class="organic-widgets-business-open-close">
								<?php echo esc_html( $instance['business_hours_sat_open'] ); ?> <?php esc_html_e( ' - ', 'organic-widgets-pro' ) ?> <?php echo esc_html( $instance['business_hours_sat_close'] ); ?>
							</span>
						</p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_hours_sun_open'] ) || ! empty( $instance['business_hours_sun_close'] ) ) { ?>
						<p class="organic-widgets-business-time">
							<span class="organic-widgets-business-day"><?php esc_html_e( 'Sun:', 'organic-widgets-pro' ) ?></span>
							<span class="organic-widgets-business-open-close">
								<?php echo esc_html( $instance['business_hours_sun_open'] ); ?> <?php esc_html_e( ' - ', 'organic-widgets-pro' ) ?> <?php echo esc_html( $instance['business_hours_sun_close'] ); ?>
							</span>
						</p>
					<?php } ?>

				<?php /** END .organic-widgets-business-hours */ ?>
				</div>

				<?php } ?>

				<?php if ( ! empty( $instance['business_name'] ) || ! empty( $instance['business_address_1'] ) ||
				! empty( $instance['business_address_2'] ) || ! empty( $instance['business_city'] ) ||
				! empty( $instance['business_state'] ) || ! empty( $instance['business_zip'] ) ) { ?>

				<?php /** BEGIN .organic-widgets-business-address */ ?>
				<div class="organic-widgets-business-address organic-widgets-business-info-column">

					<?php if ( ! empty( $instance['business_name'] ) ) { ?>
						<h6 class="organic-widgets-business-name"><?php echo esc_html( $instance['business_name'] ); ?></h6>
					<?php } ?>

					<?php if ( ! empty( $instance['business_address_1'] ) ) { ?>
						<p class="organic-widgets-business-address-1"><?php echo esc_html( $instance['business_address_1'] ); ?></p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_address_2'] ) ) { ?>
						<p class="organic-widgets-business-address-2"><?php echo esc_html( $instance['business_address_2'] ); ?></p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_city'] ) || ! empty( $instance['business_state'] ) || ! empty( $instance['business_zip'] ) ) { ?>
						<?php if ( '1' != $eu_format ) { ?>
							<p class="organic-widgets-business-city-state-zip">
								<span class="organic-widgets-business-city"><?php echo esc_html( $instance['business_city'] ); ?></span>, <span class="organic-widgets-business-state"><?php echo esc_html( $instance['business_state'] ); ?></span> <span class="organic-widgets-business-zip"><?php echo esc_html( $instance['business_zip'] ); ?></span>
							</p>
						<?php } else { ?>
							<p class="organic-widgets-business-city-state-zip">
								<span class="organic-widgets-business-zip"><?php echo esc_html( $instance['business_zip'] ); ?></span> <span class="organic-widgets-business-city"><?php echo esc_html( $instance['business_city'] ); ?></span> <span class="organic-widgets-business-state"><?php echo esc_html( $instance['business_state'] ); ?></span>
							</p>
						<?php } ?>
						<p class="organic-widgets-google-maps-link">
							<a href="https://maps.google.com/?q= <?php echo esc_html( $instance['business_address_1'] ); ?>, <?php echo esc_html( $instance['business_city'] ); ?>, <?php echo esc_html( $instance['business_state'] ); ?>, <?php echo esc_html( $instance['business_zip'] ); ?>" target="_blank"><?php esc_html_e( 'View Map', 'organic-widgets-pro' ); ?></a>
						</p>
					<?php } ?>

				<?php /** END .organic-widgets-business-address */ ?>
				</div>

				<?php } ?>

				<?php if ( ! empty( $instance['business_phone'] ) || ! empty( $instance['business_cell'] ) || ! empty( $instance['business_fax'] ) ||
				! empty( $instance['business_email'] ) || ! empty( $repeatable_array ) ) { ?>

				<?php /** BEGIN .organic-widgets-business-contact */ ?>
				<div class="organic-widgets-business-contact organic-widgets-business-info-column">

					<?php if ( ! empty( $instance['business_phone'] ) ) { ?>
						<p class="organic-widgets-business-phone"><i class="fa fa-phone"></i> <a href="tel:<?php echo esc_html( $instance['business_phone'] ); ?>"><?php echo esc_html( $instance['business_phone'] ); ?></a></p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_cell'] ) ) { ?>
						<p class="organic-widgets-business-phone"><i class="fa fa-mobile"></i> <a href="tel:<?php echo esc_html( $instance['business_cell'] ); ?>"><?php echo esc_html( $instance['business_cell'] ); ?></a></p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_fax'] ) ) { ?>
						<p class="organic-widgets-business-fax"><i class="fa fa-fax"></i> <a href="tel:<?php echo esc_html( $instance['business_fax'] ); ?>"><?php echo esc_html( $instance['business_fax'] ); ?></a></p>
					<?php } ?>

					<?php if ( ! empty( $instance['business_email'] ) ) { ?>
						<p class="organic-widgets-business-email"><i class="fa fa-envelope"></i>  <a href="mailto:<?php echo esc_html( is_email( $instance['business_email'] ) ); ?>"><?php echo esc_html( is_email( $instance['business_email'] ) ); ?></a></p>
					<?php } ?>

					<?php if ( ! empty( $repeatable_array ) ) { ?>

					<ul class="organic-widgets-social-icons">

						<?php foreach ( $repeatable_array as $social_link ) { ?>

							<?php if ( ! empty( $social_link['link_url'] ) ) { ?>

								<?php $is_email = is_email( $social_link['link_url'] ) ? true : false; ?>

								<li><a href="<?php if ( $is_email ) { echo 'mailto:'; } echo esc_url( $social_link['link_url'] ); ?>" target="_blank"><i class="fa"></i></a></li>

							<?php } ?>

						<?php } ?>

					</ul>

					<?php } ?>

				<?php /** END .organic-widgets-business-contact */ ?>
				</div>

				<?php } ?>

			<?php /** END .organic-widgets-content */ ?>
			</div>

		<?php /** END .organic-widgets-section */ ?>
		</div>

		<?php

		echo $args['after_widget'];

	} // End widget()

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'text'  => '',
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		if ( ! isset( $instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = 'h4';
		}
		if ( isset( $instance['business_name'] ) ) {
			$business_name = $instance['business_name'];
		} else {
			$business_name = '';
		}
		if ( isset( $instance['business_address_1'] ) ) {
			$business_address_1 = $instance['business_address_1'];
		} else {
			$business_address_1 = '';
		}
		if ( isset( $instance['business_address_2'] ) ) {
			$business_address_2 = $instance['business_address_2'];
		} else {
			$business_address_2 = '';
		}
		if ( isset( $instance['business_city'] ) ) {
			$business_city = $instance['business_city'];
		} else {
			$business_city = '';
		}
		if ( isset( $instance['business_state'] ) ) {
			$business_state = $instance['business_state'];
		} else {
			$business_state = '';
		}
		if ( isset( $instance['business_zip'] ) ) {
			$business_zip = $instance['business_zip'];
		} else {
			$business_zip = '';
		}
		if ( isset( $instance['eu_format'] ) ) {
			$eu_format = $instance['eu_format'];
		} else {
			$eu_format = false;
		}

		if ( isset( $instance['business_hours'] ) ) {
			$business_hours = $instance['business_hours'];
		} else {
			$business_hours = '';
		}
		if ( isset( $instance['business_hours_mon_open'] ) ) {
			$business_hours_mon_open = $instance['business_hours_mon_open'];
		} else {
			$business_hours_mon_open = '';
		}
		if ( isset( $instance['business_hours_mon_close'] ) ) {
			$business_hours_mon_close = $instance['business_hours_mon_close'];
		} else {
			$business_hours_mon_close = '';
		}
		if ( isset( $instance['business_hours_tues_open'] ) ) {
			$business_hours_tues_open = $instance['business_hours_tues_open'];
		} else {
			$business_hours_tues_open = '';
		}
		if ( isset( $instance['business_hours_tues_close'] ) ) {
			$business_hours_tues_close = $instance['business_hours_tues_close'];
		} else {
			$business_hours_tues_close = '';
		}
		if ( isset( $instance['business_hours_wed_open'] ) ) {
			$business_hours_wed_open = $instance['business_hours_wed_open'];
		} else {
			$business_hours_wed_open = '';
		}
		if ( isset( $instance['business_hours_wed_close'] ) ) {
			$business_hours_wed_close = $instance['business_hours_wed_close'];
		} else {
			$business_hours_wed_close = '';
		}
		if ( isset( $instance['business_hours_thurs_open'] ) ) {
			$business_hours_thurs_open = $instance['business_hours_thurs_open'];
		} else {
			$business_hours_thurs_open = '';
		}
		if ( isset( $instance['business_hours_thurs_close'] ) ) {
			$business_hours_thurs_close = $instance['business_hours_thurs_close'];
		} else {
			$business_hours_thurs_close = '';
		}
		if ( isset( $instance['business_hours_fri_open'] ) ) {
			$business_hours_fri_open = $instance['business_hours_fri_open'];
		} else {
			$business_hours_fri_open = '';
		}
		if ( isset( $instance['business_hours_fri_close'] ) ) {
			$business_hours_fri_close = $instance['business_hours_fri_close'];
		} else {
			$business_hours_fri_close = '';
		}
		if ( isset( $instance['business_hours_sat_open'] ) ) {
			$business_hours_sat_open = $instance['business_hours_sat_open'];
		} else {
			$business_hours_sat_open = '';
		}
		if ( isset( $instance['business_hours_sat_close'] ) ) {
			$business_hours_sat_close = $instance['business_hours_sat_close'];
		} else {
			$business_hours_sat_close = '';
		}
		if ( isset( $instance['business_hours_sun_open'] ) ) {
			$business_hours_sun_open = $instance['business_hours_sun_open'];
		} else {
			$business_hours_sun_open = '';
		}
		if ( isset( $instance['business_hours_sun_close'] ) ) {
			$business_hours_sun_close = $instance['business_hours_sun_close'];
		} else {
			$business_hours_sun_close = '';
		}

		if ( isset( $instance['business_phone'] ) ) {
			$business_phone = $instance['business_phone'];
		} else {
			$business_phone = '';
		}
		if ( isset( $instance['business_cell'] ) ) {
			$business_cell = $instance['business_cell'];
		} else {
			$business_cell = '';
		}
		if ( isset( $instance['business_fax'] ) ) {
			$business_fax = $instance['business_fax'];
		} else {
			$business_fax = '';
		}
		if ( isset( $instance['business_email'] ) ) {
			$business_email = $instance['business_email'];
		} else {
			$business_email = '';
		}
		if ( isset( $instance['repeatable_array'] ) ) {
			$repeatable_array = json_decode( $instance['repeatable_array'], true );
		} else {
			$repeatable_array = array();
		}

		?>

		<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" class="title" type="hidden" value="<?php echo esc_attr( $instance['title'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" class="text organic-widgets-wysiwyg-anchor" type="hidden" value="<?php echo esc_attr( $instance['text'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'filter' ); ?>" name="<?php echo $this->get_field_name( 'filter' ); ?>" class="filter" type="hidden" value="on">
		<input id="<?php echo $this->get_field_id( 'visual' ); ?>" name="<?php echo $this->get_field_name( 'visual' ); ?>" class="visual" type="hidden" value="on">

		<p>
			<label for="<?php echo $this->get_field_id( 'business_name' ); ?>"><?php _e( 'Business Name:', 'organic-widgets-pro' ) ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'business_name' ); ?>" name="<?php echo $this->get_field_name( 'business_name' ); ?>" value="<?php if ( $business_name ) echo $business_name; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'business_address_1' ); ?>"><?php _e( 'Business Address:', 'organic-widgets-pro' ) ?></label>
			<input class="widefat address" type="text" placeholder="Address 1" id="<?php echo $this->get_field_id( 'business_address_1' ); ?>" name="<?php echo $this->get_field_name( 'business_address_1' ); ?>" value="<?php if ( $business_address_1 ) echo $business_address_1; ?>" />
			<input class="widefat address" type="text" placeholder="Address 2" id="<?php echo $this->get_field_id( 'business_address_2' ); ?>" name="<?php echo $this->get_field_name( 'business_address_2' ); ?>" value="<?php if ( $business_address_2 ) echo $business_address_2; ?>" />
			<span class="city-state-zip">
				<input class="widefat city" type="text" placeholder="City" id="<?php echo $this->get_field_id( 'business_city' ); ?>" name="<?php echo $this->get_field_name( 'business_city' ); ?>" value="<?php if ( $business_city ) echo $business_city; ?>" />
				<input class="widefat state" type="text" placeholder="State" id="<?php echo $this->get_field_id( 'business_state' ); ?>" name="<?php echo $this->get_field_name( 'business_state' ); ?>" value="<?php if ( $business_state ) echo $business_state; ?>" />
				<input class="widefat zip" type="text" placeholder="Zip Code" id="<?php echo $this->get_field_id( 'business_zip' ); ?>" name="<?php echo $this->get_field_name( 'business_zip' ); ?>" value="<?php if ( $business_zip ) echo $business_zip; ?>" />
			</span>
		</p>

		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $eu_format, '1' ); ?> id="<?php echo $this->get_field_id( 'eu_format' ); ?>" name="<?php echo $this->get_field_name( 'eu_format' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'eu_format' ); ?>"><?php esc_html_e( 'European Address Format', 'organic-widgets-pro' ); ?></label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'business_phone' ); ?>"><?php esc_html_e( 'Business Phone:', 'organic-widgets-pro' ) ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'business_phone' ); ?>" name="<?php echo $this->get_field_name( 'business_phone' ); ?>" value="<?php if ( $business_phone ) echo $business_phone; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'business_cell' ); ?>"><?php esc_html_e( 'Business Cell:', 'organic-widgets-pro' ) ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'business_cell' ); ?>" name="<?php echo $this->get_field_name( 'business_cell' ); ?>" value="<?php if ( $business_cell ) echo $business_cell; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'business_fax' ); ?>"><?php esc_html_e( 'Business Fax:', 'organic-widgets-pro' ) ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'business_fax' ); ?>" name="<?php echo $this->get_field_name( 'business_fax' ); ?>" value="<?php if ( $business_fax ) echo $business_fax; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'business_email' ); ?>"><?php esc_html_e( 'Business Email:', 'organic-widgets-pro' ) ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'business_email' ); ?>" name="<?php echo $this->get_field_name( 'business_email' ); ?>" value="<?php if ( $business_email ) echo $business_email; ?>" />
		</p>

		<p>
			<label><?php _e( 'Business Hours:', 'organic-widgets-pro' ) ?></label>
			<input class="widefat" type="text" placeholder="My Business Hours" id="<?php echo $this->get_field_id( 'business_hours' ); ?>" name="<?php echo $this->get_field_name( 'business_hours' ); ?>" value="<?php if ( $business_hours ) echo $business_hours; ?>" />
			<span class="hours">
				<label class="day" for="<?php echo $this->get_field_id( 'business_hours_mon_open' ); ?>"><?php _e( 'Mon:', 'organic-widgets-pro' ) ?></label>
				<span class="open-close">
					<input class="widefat hour" type="text" placeholder="8am" id="<?php echo $this->get_field_id( 'business_hours_mon_open' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_mon_open' ); ?>" value="<?php if ( $business_hours_mon_open ) echo esc_html( $business_hours_mon_open ); ?>" />
					<input class="widefat hour" type="text" placeholder="5pm" id="<?php echo $this->get_field_id( 'business_hours_mon_close' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_mon_close' ); ?>" value="<?php if ( $business_hours_mon_close ) echo esc_html( $business_hours_mon_close ); ?>" />
				</span>
			</span>
			<span class="hours">
				<label class="day" for="<?php echo $this->get_field_id( 'business_hours_tues_open' ); ?>"><?php _e( 'Tues:', 'organic-widgets-pro' ) ?></label>
				<span class="open-close">
					<input class="widefat hour" type="text" placeholder="8am" id="<?php echo $this->get_field_id( 'business_hours_tues_open' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_tues_open' ); ?>" value="<?php if ( $business_hours_tues_open ) echo esc_html( $business_hours_tues_open ); ?>" />
					<input class="widefat hour" type="text" placeholder="5pm" id="<?php echo $this->get_field_id( 'business_hours_tues_close' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_tues_close' ); ?>" value="<?php if ( $business_hours_tues_close ) echo esc_html( $business_hours_tues_close ); ?>" />
				</span>
			</span>
			<span class="hours">
				<label class="day" for="<?php echo $this->get_field_id( 'business_hours_wed_open' ); ?>"><?php _e( 'Wed:', 'organic-widgets-pro' ) ?></label>
				<span class="open-close">
					<input class="widefat hour" type="text" placeholder="8am" id="<?php echo $this->get_field_id( 'business_hours_wed_open' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_wed_open' ); ?>" value="<?php if ( $business_hours_wed_open ) echo esc_html( $business_hours_wed_open ); ?>" />
					<input class="widefat hour" type="text" placeholder="5pm" id="<?php echo $this->get_field_id( 'business_hours_wed_close' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_wed_close' ); ?>" value="<?php if ( $business_hours_wed_close ) echo esc_html( $business_hours_wed_close ); ?>" />
				</span>
			</span>
			<span class="hours">
				<label class="day" for="<?php echo $this->get_field_id( 'business_hours_thurs_open' ); ?>"><?php _e( 'Thur:', 'organic-widgets-pro' ) ?></label>
				<span class="open-close">
					<input class="widefat hour" type="text" placeholder="8am" id="<?php echo $this->get_field_id( 'business_hours_thurs_open' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_thurs_open' ); ?>" value="<?php if ( $business_hours_thurs_open ) echo esc_html( $business_hours_thurs_open ); ?>" />
					<input class="widefat hour" type="text" placeholder="5pm" id="<?php echo $this->get_field_id( 'business_hours_thurs_close' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_thurs_close' ); ?>" value="<?php if ( $business_hours_thurs_close ) echo esc_html( $business_hours_thurs_close ); ?>" />
				</span>
			</span>
			<span class="hours">
				<label class="day" for="<?php echo $this->get_field_id( 'business_hours_fri_open' ); ?>"><?php _e( 'Fri:', 'organic-widgets-pro' ) ?></label>
				<span class="open-close">
					<input class="widefat hour" type="text" placeholder="8am" id="<?php echo $this->get_field_id( 'business_hours_fri_open' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_fri_open' ); ?>" value="<?php if ( $business_hours_fri_open ) echo esc_html( $business_hours_fri_open ); ?>" />
					<input class="widefat hour" type="text" placeholder="5pm" id="<?php echo $this->get_field_id( 'business_hours_fri_close' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_fri_close' ); ?>" value="<?php if ( $business_hours_fri_close ) echo esc_html( $business_hours_fri_close ); ?>" />
				</span>
			</span>
			<span class="hours">
				<label class="day" for="<?php echo $this->get_field_id( 'business_hours_sat_open' ); ?>"><?php _e( 'Sat:', 'organic-widgets-pro' ) ?></label>
				<span class="open-close">
					<input class="widefat hour" type="text" placeholder="Closed" id="<?php echo $this->get_field_id( 'business_hours_sat_open' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_sat_open' ); ?>" value="<?php if ( $business_hours_sat_open ) echo esc_html( $business_hours_sat_open ); ?>" />
					<input class="widefat hour" type="text" id="<?php echo $this->get_field_id( 'business_hours_sat_close' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_sat_close' ); ?>" value="<?php if ( $business_hours_sat_close ) echo esc_html( $business_hours_sat_close ); ?>" />
				</span>
			</span>
			<span class="hours">
				<label class="day" for="<?php echo $this->get_field_id( 'business_hours_sun_open' ); ?>"><?php _e( 'Sun:', 'organic-widgets-pro' ) ?></label>
				<span class="open-close">
					<input class="widefat hour" type="text" placeholder="Closed" id="<?php echo $this->get_field_id( 'business_hours_sun_open' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_sun_open' ); ?>" value="<?php if ( $business_hours_sun_open ) echo esc_html( $business_hours_sun_open ); ?>" />
					<input class="widefat hour" type="text" id="<?php echo $this->get_field_id( 'business_hours_sun_close' ); ?>" name="<?php echo $this->get_field_name( 'business_hours_sun_close' ); ?>" value="<?php if ( $business_hours_sun_close ) echo esc_html( $business_hours_sun_close ); ?>" />
				</span>
			</span>
		</p>

		<br />

		<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

		<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

		<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

		<div class="organic-widgets-repeatable-form-item-widget-admin">

			<?php $this->repeatable_form_item_inputs_markup( $repeatable_array, 'Social Links' ); ?>

		</div>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php _e('Custom Widget Class', 'organic-widgets-pro'); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
		</p>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
		</p>

		<?php

	}

	/**
	 * Ouput HTML for a Repeatable Social Link Form Item
	 *
	 * @access protected
	 */
	protected function echo_repeatable_form_item( $id = 'template', $order = 'template', $repeatable = false ) {

		if ( 'template' === $id || 'template' === $order ) {
			$template = true;
			$id       = '';
			$order    = '';
		} else {
			$id       = (int) $id;
			$template = false;
		}
		?>

		<div class="<?php if ( $template ) { echo 'organic-widgets-repeatable-form-item-template'; } else { echo 'organic-widgets-repeatable-form-item'; } ?>" data-feature-id="<?php echo $id; ?>" data-order="<?php echo $order; ?>">

			<div class="organic-widgets-repeatable-form-item-title-bar">
				<?php _e( 'Social Link:', 'organic-widgets-pro' ) ?>
				<span class="organic-widgets-repeatable-item-number">
					<?php
					if ( is_numeric( $order ) ) {
						echo $order + 1;
					}
					?>
				</span>
			</div>

			<div class="organic-widgets-repeatable-form-item-fields-wrapper">

				<p>
					<label style="display:none;"><?php _e( 'Social Link:', 'organic-widgets-pro' ) ?></label>
					<input class="widefat organic-widgets-feature-list-link-url-input organic-widgets-repeatable-form-item-input" data-input-name="link_url" data-activator="true" type="text" value="<?php if ( $repeatable && array_key_exists( 'link_url', $repeatable ) ) { if ( is_email( $repeatable['link_url'] ) ) { echo esc_html( $repeatable['link_url'] ); } else { echo esc_url($repeatable['link_url']); } } ?>" />
				</p>

				<div class="organic-widgets-clear"></div>

			</div>

			<?php $this->echo_repeatable_form_item_actions(); ?>

		</div>

		<?php
	}

	/**
	 * Render form template scripts.
	 *
	 * @access public
	 */
	public function render_control_template_scripts() {

		?>
		<script type="text/html" id="tmpl-widget-organic_widgets_business_info_section-control-fields">

			<# var elementIdPrefix = 'el' + String( Math.random() ).replace( /\D/g, '' ) + '_' #>

			<p>
				<label for="{{ elementIdPrefix }}title"><?php esc_html_e( 'Title:' ); ?></label>
				<input id="{{ elementIdPrefix }}title" type="text" class="widefat title">
			</p>
			<p>
				<label for="{{ elementIdPrefix }}text" class="screen-reader-text"><?php esc_html_e( 'Content:' ); ?></label>
				<textarea id="{{ elementIdPrefix }}text" class="widefat text" style="height: 200px" rows="16" cols="20"></textarea>
			</p>
		</script>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		/*--- Text/Title ----*/
		if ( ! isset( $newinstance['filter'] ) ) {
			$instance['filter'] = false;
		}
		if ( ! isset( $newinstance['visual'] ) ) {
			$instance['visual'] = null;
		}
		// Upgrade 4.8.0 format.
		if ( isset( $old_instance['filter'] ) && 'content' === $old_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( 'content' === $new_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( isset( $new_instance['visual'] ) ) {
			$instance['visual'] = ! empty( $new_instance['visual'] );
		}
		// Filter is always true in visual mode.
		if ( ! empty( $instance['visual'] ) ) {
			$instance['filter'] = true;
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance['title'] = $new_instance['title'];
			$instance['text']  = $new_instance['text'];
		} else {
			$instance['title'] = wp_kses_post( $new_instance['title'] );
			$instance['text']  = wp_kses_post( $new_instance['text'] );
		}
		/*--- END Text/Title ----*/

		/*--- Unique Options ----*/
		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}
		if ( isset( $new_instance['business_name'] ) ) {
			$instance['business_name'] = wp_strip_all_tags( $new_instance['business_name'] );
		}
		if ( isset( $new_instance['business_address_1'] ) ) {
			$instance['business_address_1'] = wp_strip_all_tags( $new_instance['business_address_1'] );
		}
		if ( isset( $new_instance['business_address_2'] ) ) {
			$instance['business_address_2'] = wp_strip_all_tags( $new_instance['business_address_2'] );
		}
		if ( isset( $new_instance['business_city'] ) ) {
			$instance['business_city'] = wp_strip_all_tags( $new_instance['business_city'] );
		}
		if ( isset( $new_instance['business_state'] ) ) {
			$instance['business_state'] = wp_strip_all_tags( $new_instance['business_state'] );
		}
		if ( isset( $new_instance['business_zip'] ) ) {
			$instance['business_zip'] = wp_strip_all_tags( $new_instance['business_zip'] );
		}
		if ( isset( $new_instance['eu_format'] ) ) {
			$instance['eu_format'] = true;
		} else {
			$instance['eu_format'] = false;
		}

		if ( isset( $new_instance['business_hours'] ) ) {
			$instance['business_hours'] = wp_strip_all_tags( $new_instance['business_hours'] );
		}
		if ( isset( $new_instance['business_hours_mon_open'] ) ) {
			$instance['business_hours_mon_open'] = wp_strip_all_tags( $new_instance['business_hours_mon_open'] );
		}
		if ( isset( $new_instance['business_hours_mon_close'] ) ) {
			$instance['business_hours_mon_close'] = wp_strip_all_tags( $new_instance['business_hours_mon_close'] );
		}
		if ( isset( $new_instance['business_hours_tues_open'] ) ) {
			$instance['business_hours_tues_open'] = wp_strip_all_tags( $new_instance['business_hours_tues_open'] );
		}
		if ( isset( $new_instance['business_hours_tues_close'] ) ) {
			$instance['business_hours_tues_close'] = wp_strip_all_tags( $new_instance['business_hours_tues_close'] );
		}
		if ( isset( $new_instance['business_hours_wed_open'] ) ) {
			$instance['business_hours_wed_open'] = wp_strip_all_tags( $new_instance['business_hours_wed_open'] );
		}
		if ( isset( $new_instance['business_hours_wed_close'] ) ) {
			$instance['business_hours_wed_close'] = wp_strip_all_tags( $new_instance['business_hours_wed_close'] );
		}
		if ( isset( $new_instance['business_hours_thurs_open'] ) ) {
			$instance['business_hours_thurs_open'] = wp_strip_all_tags( $new_instance['business_hours_thurs_open'] );
		}
		if ( isset( $new_instance['business_hours_thurs_close'] ) ) {
			$instance['business_hours_thurs_close'] = wp_strip_all_tags( $new_instance['business_hours_thurs_close'] );
		}
		if ( isset( $new_instance['business_hours_fri_open'] ) ) {
			$instance['business_hours_fri_open'] = wp_strip_all_tags( $new_instance['business_hours_fri_open'] );
		}
		if ( isset( $new_instance['business_hours_fri_close'] ) ) {
			$instance['business_hours_fri_close'] = wp_strip_all_tags( $new_instance['business_hours_fri_close'] );
		}
		if ( isset( $new_instance['business_hours_sat_open'] ) ) {
			$instance['business_hours_sat_open'] = wp_strip_all_tags( $new_instance['business_hours_sat_open'] );
		}
		if ( isset( $new_instance['business_hours_sat_close'] ) ) {
			$instance['business_hours_sat_close'] = wp_strip_all_tags( $new_instance['business_hours_sat_close'] );
		}
		if ( isset( $new_instance['business_hours_sun_open'] ) ) {
			$instance['business_hours_sun_open'] = wp_strip_all_tags( $new_instance['business_hours_sun_open'] );
		}
		if ( isset( $new_instance['business_hours_sun_close'] ) ) {
			$instance['business_hours_sun_close'] = wp_strip_all_tags( $new_instance['business_hours_sun_close'] );
		}

		if ( isset( $new_instance['business_phone'] ) ) {
			$instance['business_phone'] = wp_strip_all_tags( $new_instance['business_phone'] );
		}
		if ( isset( $new_instance['business_cell'] ) ) {
			$instance['business_cell'] = wp_strip_all_tags( $new_instance['business_cell'] );
		}
		if ( isset( $new_instance['business_fax'] ) ) {
			$instance['business_fax'] = wp_strip_all_tags( $new_instance['business_fax'] );
		}
		if ( isset( $new_instance['business_email'] ) ) {
			$instance['business_email'] = wp_strip_all_tags( $new_instance['business_email'] );
		}
		if ( isset( $new_instance['repeatable_array'] ) ) {
			$instance['repeatable_array'] = $new_instance['repeatable_array'];
		}
		/*--- END Unique Options ----*/

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		/*--- END Background ----*/

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = wp_strip_all_tags( $new_instance['title_text_heading'] );
		}
		if ( isset( $new_instance['title_text_color'] ) ) {
			$instance['title_text_color'] = wp_strip_all_tags( $new_instance['title_text_color'] );
		}
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		if ( isset( $new_instance['body_font_family'] ) ) {
			$instance['body_font_family'] = wp_strip_all_tags( $new_instance['body_font_family'] );
		}
		/*--- END Font Options ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['widget_padding_top'] ) ) {
			$instance['widget_padding_top'] = wp_strip_all_tags( $new_instance['widget_padding_top'] );
		}
		if ( isset( $new_instance['widget_padding_bottom'] ) ) {
			$instance['widget_padding_bottom'] = wp_strip_all_tags( $new_instance['widget_padding_bottom'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['content_max_width'] ) ) {
			$instance['content_max_width'] = wp_strip_all_tags( $new_instance['content_max_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		/*--- END Layout ----*/

		return $instance;

	}

	/**
	 * Enqueue all the javascript.
	 */
	public function admin_setup() {

		// Text Editor.
		wp_enqueue_editor();
		wp_enqueue_script( 'organic-widgets-business-info-section-text-title', plugin_dir_url( __FILE__ ) . 'js/business-info-widgets.js', array( 'jquery', 'wp-embed', 'underscore' ), '1.0', true );
		wp_localize_script( 'organic-widgets-business-info-section-text-title', 'OrganicBusinessInfoWidget', array(
			'id_base' => $this->id_base,
		) );
		wp_add_inline_script( 'organic-widgets-business-info-section-text-title', 'wp.organicBusinessInfoWidget.init();', 'after' );

		wp_enqueue_media();

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ) );

		wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ) );
		wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
			'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
			'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
		) );

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		wp_enqueue_style( 'organic-widgets-fontawesome', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/css/font-awesome.css' );
		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ) );
		}

	}

} // class Organic_Widgets_Pro_Business_Info_Widget
