<?php
/**
 * Registers a widget to show a slideshow of posts.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Content_Slideshow_Widget widget.
 */
class Organic_Widgets_Pro_Content_Slideshow_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_content_slideshow_section', // Base ID.
			__( 'Organic Content Slideshow', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'A content slideshow of posts.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'hide_bg'   => true,
			'video'     => false,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'  => true,
			'title_font'     => true,
			'title_color'    => true,
			'title_weight'   => true,
			'title_spacing'  => true,
			'title_size'     => true,
			'body_font'      => true,
			'body_color'     => true,
			'text_alignment' => true,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner' => true,
			'padding_top'     => false,
			'padding_bottom'  => false,
			'custom_height'   => true,
			'custom_width'    => true,
			'full_height'     => false,
		);

		// Display options.
		$this->display_options = array(
			'hide_title'   => true,
			'hide_meta'    => true,
			'hide_button'  => true,
			'hide_content' => true,
			'hide_bg'      => true,
		);

		// Admin Scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_setup' ) );

		// Public scripts.
		if ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'public_scripts' ) );
		}
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$attr                       = array();
		$attr                       = apply_filters( 'image_widget_image_attributes', $attr, $instance );
		$bg_image_id                = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image                   = ( isset( $instance['bg_image'] ) && '' != $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color                   = ( isset( $instance['bg_color'] ) && '' != $instance['bg_color'] ) ? $instance['bg_color'] : false;
		$category                   = ( isset( $instance['category'] ) ) ? $instance['category'] : 0;
		$max_posts                  = ( isset( $instance['max_posts'] ) ) ? $instance['max_posts'] : 5;
		$posts_per_slide            = ( isset( $instance['posts_per_slide'] ) ) ? $instance['posts_per_slide'] : 1;
		$slide_style                = ( isset( $instance['slide_style'] ) ) ? $instance['slide_style'] : 'style-default';
		$slideshow_interval         = ( isset( $instance['slideshow_interval'] ) ) ? $instance['slideshow_interval'] : 12000;
		$post_button_text           = ( isset( $instance['post_button_text'] ) ) ? $instance['post_button_text'] : 'Read More';

		if ( isset( $instance['slideshow_transition_style'] ) && '1' === $posts_per_slide ) {
			$slideshow_transition_style = $instance['slideshow_transition_style'];
		} else {
			$slideshow_transition_style = 'slide';
		}
		if ( isset( $instance['fixed_slide_height'] ) ) {
			$fixed_slide_height = $instance['fixed_slide_height'];
		} else {
			$fixed_slide_height = 0;
		}
		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}
		// Register Hide Content BG Option.
		if ( isset( $instance['hide_content_bg'] ) ) {
			$hide_content_bg = $instance['hide_content_bg'];
		} else {
			$hide_content_bg = false;
		}
		// Register Hide Post Title Option.
		if ( isset( $instance['hide_post_title'] ) ) {
			$hide_post_title = $instance['hide_post_title'];
		} else {
			$hide_post_title = false;
		}
		// Register Hide Post Meta Option.
		if ( isset( $instance['hide_post_meta'] ) ) {
			$hide_post_meta = $instance['hide_post_meta'];
		} else {
			$hide_post_meta = false;
		}
		// Register Hide Post Button Option.
		if ( isset( $instance['hide_post_button'] ) ) {
			$hide_post_button = $instance['hide_post_button'];
		} else {
			$hide_post_button = false;
		}
		// Register Hide Post Content Option.
		if ( isset( $instance['hide_post_content'] ) ) {
			$hide_post_content = $instance['hide_post_content'];
		} else {
			$hide_post_content = false;
		}
		// Register Text Align Option.
		if ( isset( $instance['text_align'] ) ) {
			$text_align = $instance['text_align'];
		} else {
			$text_align = 'left';
		}

		echo $args['before_widget'];

		?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-flexslider,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-flexslider .slides li.post {
					height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title a {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['body_font_family'] ) || ! empty( $instance['body_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content p {
					<?php if ( ! empty( $instance['body_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['body_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['body_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['body_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( $bg_color ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-card,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content-slideshow-section.style-default .organic-widgets-content {
					background-color: <?php echo esc_attr( $bg_color ); ?>;
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<?php /** BEGIN .organic-widgets-section */ ?>
		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"<?php } ?>
		class="organic-widgets-section organic-widgets-content-slideshow-section
		<?php echo esc_html( $slide_style ); ?>
		<?php if ( $bg_image_fixed ) echo 'organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo 'organic-widgets-repeat-bg-img'; ?>
		<?php if ( $hide_content_bg ) echo 'organic-widgets-no-content-bg'; ?>
		<?php if ( '1' !== $posts_per_slide ) echo 'organic-widgets-multi-posts-slide'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>style="background-image:url(<?php echo esc_url( $bg_image ); ?>);"
		<?php } if ( $bg_color ) { ?>style="background-color:<?php echo esc_attr( $bg_color ); ?>;"<?php } ?>>

			<?php
				$post_type = 'post';
				$tax_query = array(
					array(
						'taxonomy' => 'category',
						'field'    => 'id',
						'terms'    => $category,
					),
				);

			$slideshow_query = new WP_Query( array(
				'posts_per_page'   => $max_posts,
				'post_type'        => $post_type,
				'suppress_filters' => 0,
				'tax_query'        => $tax_query,
			) );
			?>

			<?php if ( $slideshow_query->have_posts() ) { ?>

				<?php /** BEGIN .flexslider */ ?>
				<div class="organic-widgets-flexslider loading" data-speed="<?php echo esc_attr( $slideshow_interval ); ?>" data-transition="<?php echo esc_attr( $slideshow_transition_style ); ?>" data-height="<?php echo esc_attr( $fixed_slide_height ); ?>" data-per-slide="<?php echo absint( $posts_per_slide ); ?>">

					<div class="preloader"></div>

					<?php /** BEGIN .slides */ ?>
					<ul class="slides <?php if ( ! empty( $fixed_slide_height ) ) { echo 'organic-widgets-fixed-slide-height'; } ?>">

						<?php	while ( $slideshow_query->have_posts() ) {

							$slideshow_query->the_post();
							$thumb  = ( get_the_post_thumbnail() ) ? wp_get_attachment_image_src( get_post_thumbnail_id(), 'organic-widgets-featured-large' ) : false;
							$no_img = ( ! has_post_thumbnail() ) ? array( 'no-post-thumbnail' ) : false;
							?>

							<li <?php post_class( $no_img ); ?> id="post-<?php the_ID(); ?>" <?php if ( has_post_thumbnail() && $hide_content_bg || 'middle-center' === $instance['alignment'] || 'style-default' !== $slide_style ) { echo 'style="background-image:url(' . esc_url( $thumb[0] ) . ')"'; } ?>>

								<?php /** BEGIN .organic-widgets-aligner */ ?>
								<div class="organic-widgets-aligner <?php if ( ! empty( $instance['alignment'] ) ) { echo 'organic-widgets-aligner-' . esc_attr( $instance['alignment'] ); } else { echo 'organic-widgets-aligner-middle-center'; } ?>">

									<?php if ( ! $hide_post_title || ! $hide_post_meta || ! $hide_post_content || ! $hide_post_button ) { ?>

									<?php /** BEGIN .organic-widgets-content */ ?>
									<div class="organic-widgets-content <?php if ( $hide_content_bg ) echo 'organic-widgets-hide-bg'; ?> <?php if ( $text_align ) echo 'organic-widgets-text-' ?><?php echo $text_align; ?>">

										<?php /** BEGIN .organic-widgets-card */ ?>
										<div class="<?php if ( ! $hide_content_bg ) { ?>organic-widgets-card <?php } ?>organic-widgets-card-content clearfix">

											<?php if ( ! $hide_post_title ) { ?>
												<<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?> class="organic-widgets-title"><a href="<?php echo get_the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a></<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?>>
											<?php } ?>

											<?php if ( ! $hide_post_content ) { ?>
											<?php /** BEGIN .excerpt */ ?>
											<div class="organic-widgets-excerpt">
												<?php the_excerpt(); ?>
												<?php edit_post_link( esc_html__( '(Edit)', 'organic-widgets-pro' ), '<p>', '</p>' ); ?>
											<?php /** END .organic-widgets-excerpt */ ?>
											</div>
											<?php } ?>

											<?php if ( ! $hide_post_button ) { ?>
											<a class="organic-widgets-button button" href="<?php the_permalink(); ?>"><?php if ( $post_button_text ) { ?><?php echo esc_html( $post_button_text ); ?><?php } ?></a>
											<?php } ?>

											<?php if ( ! $hide_post_meta ) { ?>
											<?php /** BEGIN .organic-widgets-post-meta */ ?>
											<div class="organic-widgets-post-meta">
												<p class="organic-widgets-post-date">
													<?php echo get_the_date( get_option( 'date_format' ) ); ?>
												</p>
												<p class="organic-widgets-post-author">
													<?php esc_html_e( 'By ', 'organic-widgets-pro' ); ?><?php esc_url( the_author_posts_link() ); ?>
												</p>
											<?php /** END .organic-widgets-post-meta */ ?>
											</div>
											<?php } ?>

										<?php /** END .organic-widgets-card */ ?>
										</div>

									<?php /** END .organic-widgets-content */ ?>
									</div>

									<?php } ?>

									<?php if ( 'middle-center' !== $instance['alignment'] && 'style-default' === $slide_style && ! $hide_content_bg ) { ?>
									<div class="organic-widgets-slide-img" <?php if ( has_post_thumbnail() && ! $hide_content_bg ) { echo 'style="background-image:url(' . esc_url( $thumb[0] ) . ')"'; } ?>></div>
									<?php } ?>

								<?php /** END .organic-widgets-aligner */ ?>
								</div>

								<div class="organic-widgets-hide-img">
									<?php the_post_thumbnail( 'organic-widgets-featured-large' ); ?>
								</div>

							</li>

						<?php } ?>

					<?php /** END .slides */ ?>
					</ul>

				<?php /** END .flexslider */ ?>
				</div>

			<?php } ?>
			<?php wp_reset_postdata(); ?>

		<?php /** END .organic-widgets-section */ ?>
		</div>

		<?php

		echo $args['after_widget'];

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		// Setup Variables.
		$this->id_prefix = $this->get_field_id( '' );

		if ( isset( $instance['category'] ) ) {
			$category = $instance['category'];
		} else {
			$category = false;
		}
		if ( isset( $instance['max_posts'] ) ) {
			$max_posts = $instance['max_posts'];
		} else {
			$max_posts = 5;
		}
		if ( isset( $instance['posts_per_slide'] ) ) {
			$posts_per_slide = $instance['posts_per_slide'];
		} else {
			$posts_per_slide = 1;
		}
		if ( isset( $instance['slide_style'] ) ) {
			$slide_style = $instance['slide_style'];
		} else {
			$slide_style = 'style-default';
		}
		if ( isset( $instance['slideshow_transition_style'] ) && '1' === $posts_per_slide ) {
			$slideshow_transition_style = $instance['slideshow_transition_style'];
		} else {
			$slideshow_transition_style = 'slide';
		}
		if ( isset( $instance['post_button_text'] ) ) {
			$post_button_text = $instance['post_button_text'];
		} else {
			$post_button_text = 'Read More';
		}

		$slideshow_interval = ( isset( $instance['slideshow_interval'] ) ) ? $instance['slideshow_interval'] : 12000;
		$fixed_slide_height = ( isset( $instance['fixed_slide_height'] ) ) ? $instance['fixed_slide_height'] : 0;

		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Post Category:', 'organic-widgets-pro' ) ?></label>
			<?php
			wp_dropdown_categories( array(
				'selected' => $category,
				'id'       => $this->get_field_id( 'category' ),
				'name'     => $this->get_field_name( 'category' ),
			) );
			?>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'max_posts' ); ?>"><?php _e( 'Max Number of Posts:', 'organic-widgets-pro' ) ?></label>
			<input type="number" min="1" max="10" value="<?php echo absint( $max_posts ); ?>" id="<?php echo $this->get_field_id( 'max_posts' ); ?>" name="<?php echo $this->get_field_name( 'max_posts' ); ?>" class="widefat" style="width:100%;"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'posts_per_slide' ); ?>"><?php _e( 'Posts Per Slide:', 'organic-widgets-pro' ); ?></label>
			<select id="<?php echo $this->get_field_id( 'posts_per_slide' ); ?>" name="<?php echo $this->get_field_name( 'posts_per_slide' ); ?>" class="widefat" style="width:100%;">
				<option <?php selected( $posts_per_slide, '1' ); ?> value="1">1</option>
				<option <?php selected( $posts_per_slide, '2' ); ?> value="2">2</option>
				<option <?php selected( $posts_per_slide, '3' ); ?> value="3">3</option>
				<option <?php selected( $posts_per_slide, '4' ); ?> value="4">4</option>
				<option <?php selected( $posts_per_slide, '5' ); ?> value="5">5</option>
				<option <?php selected( $posts_per_slide, '6' ); ?> value="6">6</option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'slideshow_transition_style' ); ?>"><?php _e( 'Slide Transition:', 'organic-widgets-pro' ); ?></label>
			<select id="<?php echo $this->get_field_id( 'slideshow_transition_style' ); ?>" name="<?php echo $this->get_field_name( 'slideshow_transition_style' ); ?>" class="widefat" style="width:100%;">
				<option <?php selected( $slideshow_transition_style, 'fade' ); ?> value="fade"><?php _e( 'Fade', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_transition_style, 'slide' ); ?> value="slide"><?php _e( 'Slide', 'organic-widgets-pro' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'slideshow_interval' ); ?>"><?php _e( 'Slide Interval:', 'organic-widgets-pro' ); ?></label>
			<select id="<?php echo $this->get_field_id( 'slideshow_interval' ); ?>" name="<?php echo $this->get_field_name( 'slideshow_interval' ); ?>" class="widefat" style="width:100%;">
				<option <?php selected( $slideshow_interval, '2000' ); ?> value="2000"><?php _e( '2 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '4000' ); ?> value="4000"><?php _e( '4 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '6000' ); ?> value="6000"><?php _e( '6 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '8000' ); ?> value="8000"><?php _e( '8 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '10000' ); ?> value="10000"><?php _e( '10 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '12000' ); ?> value="12000"><?php _e( '12 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '20000' ); ?> value="20000"><?php _e( '20 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '30000' ); ?> value="30000"><?php _e( '30 Seconds', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '60000' ); ?> value="60000"><?php _e( '1 Minute', 'organic-widgets-pro' ); ?></option>
				<option <?php selected( $slideshow_interval, '999999999' ); ?> value="999999999"><?php _e( 'Hold Frame', 'organic-widgets-pro' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'slide_style' ); ?>"><?php _e( 'Slideshow Style:', 'organic-widgets-pro' ); ?>
				<select id="<?php echo $this->get_field_id( 'slide_style' ); ?>" name="<?php echo $this->get_field_name( 'slide_style' ); ?>">
					<option value="style-default" <?php echo ( 'style-default' === $slide_style ) ? 'selected' : ''; ?>><?php _e( 'Default', 'organic-widgets-pro' ); ?></option>
					<option value="style-rounded" <?php echo ( 'style-rounded' === $slide_style ) ? 'selected' : ''; ?>><?php _e( 'Rounded', 'organic-widgets-pro' ); ?></option>
					<option value="style-modern" <?php echo ( 'style-modern' === $slide_style ) ? 'selected' : ''; ?>><?php _e( 'Modern', 'organic-widgets-pro' ); ?></option>
				</select>
			</label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $fixed_slide_height, '1' ); ?> id="<?php echo $this->get_field_id( 'fixed_slide_height' ); ?>" name="<?php echo $this->get_field_name( 'fixed_slide_height' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'fixed_slide_height' ); ?>"><?php _e( 'Fixed Height Slideshow', 'organic-widgets-pro' ); ?></label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'post_button_text' ); ?>"><?php _e( 'Slide Button Text', 'organic-widgets-pro' ) ?></label>
			<input type="text" value="<?php echo esc_html( $post_button_text ); ?>" id="<?php echo $this->get_field_id( 'post_button_text' ); ?>" name="<?php echo $this->get_field_name( 'post_button_text' ); ?>" class="widefat" style="width:100%;"/>
		</p>

		<br />

		<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

		<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

		<?php $this->section_display_input_markup( $instance, $this->display_options ); ?>

		<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php _e( 'Custom Widget Class', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
		</p>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
		</p>

		<?php

	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}
		if ( isset( $new_instance['category'] ) ) {
			$instance['category'] = wp_strip_all_tags( $new_instance['category'] );
		}
		if ( isset( $new_instance['max_posts'] ) ) {
			$instance['max_posts'] = wp_strip_all_tags( $new_instance['max_posts'] );
		}
		if ( isset( $new_instance['posts_per_slide'] ) ) {
			$instance['posts_per_slide'] = wp_strip_all_tags( $new_instance['posts_per_slide'] );
		}
		if ( isset( $new_instance['slide_style'] ) ) {
			$instance['slide_style'] = wp_strip_all_tags( $new_instance['slide_style'] );
		}
		if ( isset( $new_instance['slideshow_transition_style'] ) ) {
			$instance['slideshow_transition_style'] = $this->organic_widgets_sanitize_transition_style( wp_strip_all_tags( $new_instance['slideshow_transition_style'] ) );
		}
		if ( isset( $new_instance['slideshow_interval'] ) ) {
			$instance['slideshow_interval'] = $this->organic_widgets_sanitize_transition_interval( (int) wp_strip_all_tags( $new_instance['slideshow_interval'] ) );
		}
		if ( isset( $new_instance['fixed_slide_height'] ) && ! empty( $new_instance['fixed_slide_height'] ) ) {
			$instance['fixed_slide_height'] = 1;
		} else {
			$instance['fixed_slide_height'] = 0;
		}
		if ( isset( $new_instance['post_button_text'] ) ) {
			$instance['post_button_text'] = wp_strip_all_tags( $new_instance['post_button_text'] );
		}

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		/*--- END Background ----*/

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = wp_strip_all_tags( $new_instance['title_text_heading'] );
		}
		if ( isset( $new_instance['title_text_color'] ) ) {
			$instance['title_text_color'] = wp_strip_all_tags( $new_instance['title_text_color'] );
		}
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		if ( isset( $new_instance['body_font_family'] ) ) {
			$instance['body_font_family'] = wp_strip_all_tags( $new_instance['body_font_family'] );
		}
		if ( isset( $new_instance['body_text_color'] ) ) {
			$instance['body_text_color'] = wp_strip_all_tags( $new_instance['body_text_color'] );
		}
		if ( isset( $new_instance['text_align'] ) ) {
			$instance['text_align'] = wp_strip_all_tags( $new_instance['text_align'] );
		}
		/*--- END Font Options ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['alignment'] ) ) {
			$instance['alignment'] = wp_strip_all_tags( $new_instance['alignment'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		if ( isset( $new_instance['hide_content_bg'] ) ) {
			$instance['hide_content_bg'] = true;
		} else {
			$instance['hide_content_bg'] = false;
		}
		if ( isset( $new_instance['hide_post_title'] ) ) {
			$instance['hide_post_title'] = true;
		} else {
			$instance['hide_post_title'] = false;
		}
		if ( isset( $new_instance['hide_post_meta'] ) ) {
			$instance['hide_post_meta'] = true;
		} else {
			$instance['hide_post_meta'] = false;
		}
		if ( isset( $new_instance['hide_post_button'] ) ) {
			$instance['hide_post_button'] = true;
		} else {
			$instance['hide_post_button'] = false;
		}
		if ( isset( $new_instance['hide_post_content'] ) ) {
			$instance['hide_post_content'] = true;
		} else {
			$instance['hide_post_content'] = false;
		}
		/*--- END Layout ----*/

		return $instance;
	}

	/**
	 * Enqueue admin javascript.
	 */
	public function admin_setup() {

		wp_enqueue_media();

		// Content Aligner.
		if ( ! wp_script_is( 'organic-widgets-module-content-aligner' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-content-aligner', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-content-aligner.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );

		wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
		wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
			'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
			'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
		) );

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ), '1.0', true );
		}
		wp_enqueue_script( 'organic-widgets-flexslider', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.flexslider.js', array( 'jquery' ), '2.7.1', true );
		wp_enqueue_script( 'organic-widgets-flexslider-initialize', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/flexslider-setup.js', array( 'jquery', 'organic-widgets-flexslider' ), '1.0', true );

	}

} // class Organic_Widgets_Pro_Content_Slideshow_Widget
