<?php
/**
 * Registers a widget to show a list of features.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Feature_List_Widget widget.
 */
class Organic_Widgets_Pro_Feature_List_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_feature_list_section', // Base ID.
			__( 'Organic List', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'A list of features with icons.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'video'     => false,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'          => true,
			'title_font'             => true,
			'title_color'            => true,
			'title_weight'           => true,
			'title_spacing'          => true,
			'title_size'             => true,
			'content_heading_font'   => true,
			'content_heading_size'   => true,
			'content_heading_weight' => true,
			'body_font'              => true,
			'body_color'             => true,
			'text_alignment'         => true,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner' => false,
			'padding_top'     => true,
			'padding_bottom'  => true,
			'custom_height'   => true,
			'custom_width'    => true,
			'content_width'   => true,
			'full_height'     => false,
		);

		// Admin Scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_setup' ) );
		add_action( 'admin_footer-widgets.php', array( $this, 'render_control_template_scripts' ) );

		// Public scripts.
		if ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) {
			add_action( 'init', array( $this, 'public_scripts' ) );
		}

	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$bg_image_id      = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image         = ( isset( $instance['bg_image'] ) && '' !== $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color         = ( isset( $instance['bg_color'] ) && '' !== $instance['bg_color'] ) ? $instance['bg_color'] : false;
		$icon_color       = ( isset( $instance['icon_color'] ) && '' !== $instance['icon_color'] ) ? $instance['icon_color'] : false;
		$text             = ( isset( $instance['text'] ) && '' !== $instance['text'] ) ? $instance['text'] : false;
		$button_text      = ( isset( $instance['button_text'] ) && '' !== $instance['button_text'] ) ? $instance['button_text'] : false;
		$button_url       = ( isset( $instance['button_url'] ) && '' !== $instance['button_url'] ) ? $instance['button_url'] : false;
		$num_columns      = ( isset( $instance['num_columns'] ) ) ? $instance['num_columns'] : 4;
		$repeatable_array = ( isset( $instance['repeatable_array'] ) ) ? json_decode( $instance['repeatable_array'], true ) : array();

		// Register BG Fixed Option.
		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		// Register BG Repeat Option.
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}
		// Register Hide Content BG Option.
		if ( isset( $instance['hide_content_bg'] ) ) {
			$hide_content_bg = $instance['hide_content_bg'];
		} else {
			$hide_content_bg = true;
		}
		// Register Icon Image Size Option.
		if ( isset( $instance['icon_image_size'] ) ) {
			$icon_image_size = $instance['icon_image_size'];
		} else {
			$icon_image_size = 24;
		}
		// Register Text Align Option.
		if ( isset( $instance['text_align'] ) ) {
			$text_align = $instance['text_align'];
		} else {
			$text_align = 'center';
		}

		echo $args['before_widget']; ?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_max_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content {
					max-width: <?php echo absint( $instance['content_max_width'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) || '' !== $instance['widget_padding_top'] || '' !== $instance['widget_padding_bottom'] ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-section {
					<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
					min-height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_top'] ) { ?>
					padding-top: <?php echo intval( $instance['widget_padding_top'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_bottom'] ) { ?>
					padding-bottom: <?php echo intval( $instance['widget_padding_bottom'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['body_font_family'] ) || ! empty( $instance['body_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-text p,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-item p {
					<?php if ( ! empty( $instance['body_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['body_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['body_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['body_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['icon_image_size'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-item-icon i,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-item-icon img {
					max-width: <?php echo esc_html( $instance['icon_image_size'] ); ?>px;
					font-size: <?php echo esc_html( $instance['icon_image_size'] ); ?>px;
				}
			<?php } ?>
			<?php if ( $icon_color ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-item-icon i {
					color: <?php echo esc_attr( $icon_color ); ?>;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_heading_font_family'] ) || ! empty( $instance['content_heading_font_weight'] ) || ! empty( $instance['content_heading_font_size'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-item h6 {
					<?php if ( ! empty( $instance['content_heading_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['content_heading_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['content_heading_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['content_heading_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['content_heading_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['content_heading_font_size'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( $text_align ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-text,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-item-icon,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-feature-list-item-content {
					text-align: <?php echo esc_html( $text_align ); ?>;
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"<?php } ?>
		class="organic-widgets-section organic-widgets-feature-list-section
		<?php if ( $bg_image_fixed ) echo ' organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo ' organic-widgets-repeat-bg-img'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>
			style="background-image:url(<?php echo esc_url( $bg_image ); ?>);"
		<?php } if ( $bg_color ) { ?>
			style="background-color:<?php echo esc_attr( $bg_color ); ?>;"
		<?php } ?>>

			<?php /** BEGIN .organic-widgets-content */ ?>
			<div class="organic-widgets-content clearfix">

			<?php if ( ! empty( $instance['title'] ) ) { ?>
				<<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?> class="organic-widgets-title"><?php echo apply_filters( 'organic_widget_title', $instance['title'] ); ?></<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?>>
			<?php } ?>

			<?php if ( ! empty( $instance['text'] ) ) { ?>
				<div class="organic-widgets-text"><?php echo apply_filters( 'the_content', $instance['text'] ); ?></div>
			<?php } ?>

			<?php if ( false === $hide_content_bg ) { ?>
			<?php /** BEGIN .organic-widgets-card */ ?>
			<div class="organic-widgets-card clearfix">
			<?php } ?>

				<div class="organic-widgets-feature-list-items-wrapper organic-widgets-flex-row organic-widgets-flex-wrap">

				<?php
				if ( is_array( $repeatable_array ) && count( $repeatable_array ) ) {
					$incrementer = 0;
					usort( $repeatable_array, array( $this, 'sort_by_order' ) );
					foreach ( $repeatable_array as $key => $repeatable ) {
						$incrementer++;

						if ( $repeatable && isset( $repeatable['icon'] ) ) {
							$icon_type = strpos( $repeatable['icon'], 'fa' ) !== false ? 'fontawesome' : 'image';
						} else {
							$icon_type = false;
						}
						?>

						<div class="organic-widgets-feature-list-item organic-widgets-<?php echo $this->column_string( $num_columns ); ?>">

							<div class="organic-widgets-feature-list-item-content">

								<div class="organic-widgets-feature-list-item-icon">

									<?php
									if ( '' !== $repeatable['link_url'] && 'image' === $icon_type || '' !== $repeatable['link_url'] && 'fontawesome' === $icon_type ) {
										echo '<a href="' . esc_url( $repeatable['link_url'] ) . '">';
									}
									?>
										<?php if ( 'image' === $icon_type ) { ?>
											<?php echo $this->get_image_html( $instance, $repeatable ); ?>
										<?php } elseif ( 'fontawesome' === $icon_type ) { ?>
											<i class="fa <?php echo esc_attr( $repeatable['icon'] ); ?>"></i>
										<?php } ?>
									<?php
									if ( '' !== $repeatable['link_url'] && 'image' === $icon_type || '' !== $repeatable['link_url'] && 'fontawesome' === $icon_type ) {
										echo '</a>';
									}
									?>

								</div>

								<div class="organic-widgets-feature-list-item-text">

									<h6>
										<?php if ( '' !== $repeatable['link_url'] ) { ?>
											<?php echo '<a href="' . esc_url( $repeatable['link_url'] ) . '">'; ?>
										<?php } ?>
											<?php if ( array_key_exists( 'title', $repeatable ) ) { ?>
												<?php echo esc_html( $repeatable['title'] ); ?>
											<?php } ?>
										<?php if ( '' !== $repeatable['link_url'] ) { ?>
											<?php echo '</a>'; ?>
										<?php } ?>
									</h6>

									<p>
									<?php
									if ( array_key_exists( 'text', $repeatable ) ) {
										echo $repeatable['text'];
									}
									?>
									</p>

									<?php if ( '' !== $repeatable['link_url'] ) { ?>
										<a class="button" href="<?php echo esc_url( $repeatable['link_url'] ); ?>" <?php if ( 'window-new' === $repeatable['link_target'] ) { ?>target="_blank"<?php } ?>>
											<?php if ( '' !== $repeatable['link_text'] ) { ?>
												<?php echo wp_kses_post( $repeatable['link_text'] ); ?>
											<?php } else { ?>
												<?php esc_html_e( 'Learn More', 'organic-widgets-pro' ); ?>
											<?php } ?>
										</a>
									<?php } ?>

								</div>

							</div>

						</div>

						<?php
					}
				}
				?>

				</div>

			<?php if ( false === $hide_content_bg ) { ?>
			<?php /** END .organic-widgets-card */ ?>
			</div>
			<?php } ?>

			<?php if ( ! empty( $button_url ) ) { ?>
				<div class="organic-widgets-button-holder">
					<a class="organic-widgets-button button" href="<?php echo esc_url( $button_url );?>"><?php if ( ! empty( $button_text ) ) { echo esc_html_e( $button_text, 'organic-widgets-pro' ); } else { esc_html_e( 'See More', 'organic-widgets-pro' ); } ?></a>
				</div>
			<?php } ?>

			<?php /** END .organic-widgets-content */ ?>
			</div>

		</div>

		<?php

		echo $args['after_widget'];

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'text'  => '',
			)
		);

		// Setup Variables.
		$this->id_prefix = $this->get_field_id( '' );

		if ( isset( $instance['button_text'] ) ) {
			$button_text = $instance['button_text'];
		} else {
			$button_text = false;
		}

		if ( isset( $instance['button_url'] ) ) {
			$button_url = $instance['button_url'];
		} else {
			$button_url = false;
		}

		if ( isset( $instance['num_columns'] ) ) {
			$num_columns = $instance['num_columns'];
		} else {
			$num_columns = 4;
		}

		if ( isset( $instance['icon_image_size'] ) ) {
			$icon_image_size = $instance['icon_image_size'];
		} else {
			$icon_image_size = 24;
		}

		if ( isset( $instance['icon_color'] ) ) {
			$icon_color = $instance['icon_color'];
		} else {
			$icon_color = false;
		}

		if ( isset( $instance['hide_content_bg'] ) ) {
			$hide_content_bg = $instance['hide_content_bg'];
		} else {
			$hide_content_bg = true;
		}

		if ( isset( $instance['repeatable_array'] ) ) {
			$repeatable_array = json_decode( $instance['repeatable_array'], true );
		} else {
			$repeatable_array = array();
		}

		?>

		<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" class="title" type="hidden" value="<?php echo esc_attr( $instance['title'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" class="text organic-widgets-wysiwyg-anchor" type="hidden" value="<?php echo esc_attr( $instance['text'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'filter' ); ?>" name="<?php echo $this->get_field_name( 'filter' ); ?>" class="filter" type="hidden" value="on">
		<input id="<?php echo $this->get_field_id( 'visual' ); ?>" name="<?php echo $this->get_field_name( 'visual' ); ?>" class="visual" type="hidden" value="on">

		<div class="organic-widgets-option-set organic-widgets-repeatable-other-options">
			<p class="organic-widgets-input-half">
				<label for="<?php echo $this->get_field_id( 'button_text' ); ?>"><?php _e( 'Button Text:', 'organic-widgets-pro' ); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'button_text' ); ?>" name="<?php echo $this->get_field_name( 'button_text' ); ?>" value="<?php echo esc_html( $button_text ); ?>" />
			</p>
			<p class="organic-widgets-input-half last">
				<label for="<?php echo $this->get_field_id( 'button_url' ); ?>"><?php _e('Button URL', 'organic-widgets-pro'); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'button_url' ); ?>" name="<?php echo $this->get_field_name( 'button_url' ); ?>" value="<?php echo esc_url( $button_url ); ?>" />
			</p>
		</div>

		<p>
			<label for="<?php echo $this->get_field_id( 'num_columns' ); ?>"><?php _e( 'Number of Columns:', 'organic-widgets-pro' ); ?></label>
			<select id="<?php echo $this->get_field_id( 'num_columns' ); ?>" name="<?php echo $this->get_field_name( 'num_columns' ); ?>" class="widefat" style="width:100%;">
				<option <?php selected( $num_columns, '1' ); ?> value="1">1</option>
				<option <?php selected( $num_columns, '2' ); ?> value="2">2</option>
				<option <?php selected( $num_columns, '3' ); ?> value="3">3</option>
				<option <?php selected( $num_columns, '4' ); ?> value="4">4</option>
				<option <?php selected( $num_columns, '5' ); ?> value="5">5</option>
				<option <?php selected( $num_columns, '6' ); ?> value="6">6</option>
			</select>
		</p>

		<p>
			<label
				for="<?php echo $this->get_field_id( 'icon_image_size' ); ?>"><?php _e( 'Icon Image Size:', 'organic-widgets-pro' ); ?>
			</label>
			<output
				id="rangevalue<?php echo absint( preg_replace( '/[^0-9,.]/', '', $this->id ) ); ?>"
				for="<?php echo $this->get_field_id( 'icon_image_size' ); ?>"
			>
				<?php if ( ! empty( $instance['icon_image_size'] ) ) { echo $instance['icon_image_size']; } else { echo '32'; } ?>
			</output>
			<input
				class="widefat organic-widgets-input-range"
				type="range"
				min="10"
				max="100"
				onchange="rangevalue<?php echo absint( preg_replace( '/[^0-9,.]/', '', $this->id ) ); ?>.value=value;"
				oninput="rangevalue<?php echo absint( preg_replace( '/[^0-9,.]/', '', $this->id ) ); ?>.value=value;"
				id="<?php echo $this->get_field_id( 'icon_image_size' ); ?>"
				name="<?php echo $this->get_field_name( 'icon_image_size' ); ?>"
				value="<?php if ( ! empty( $instance['icon_image_size'] ) ) { echo $instance['icon_image_size']; } else { echo '32'; } ?>"
			/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_name( 'icon_color' ); ?>"><?php _e( 'Icon Color:', 'organic-widgets-pro' ); ?></label><br>
			<input type="text" name="<?php echo $this->get_field_name( 'icon_color' ); ?>" id="<?php echo $this->get_field_id( 'icon_color' ); ?>" value="<?php echo esc_attr( $icon_color ); ?>" class="organic-widgets-color-picker" />
		</p>

		<p>
			<input class="checkbox" type="checkbox" value="1" <?php checked( $hide_content_bg, '1' ); ?> id="<?php echo $this->get_field_id( 'hide_content_bg' ); ?>" name="<?php echo $this->get_field_name( 'hide_content_bg' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'hide_content_bg' ); ?>"><?php _e( 'Hide Content Background Card', 'organic-widgets-pro' ); ?></label>
		</p>

		<br />

		<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

		<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

		<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

		<div class="organic-widgets-repeatable-form-item-widget-admin">

			<?php $this->repeatable_form_item_inputs_markup( $repeatable_array, 'Feature List Items', $instance ); ?>

		</div>

		<br />

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php _e( 'Custom Widget Class', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
		</p>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
		</p>

		<?php
	}

	/**
	 * Render form template scripts.
	 *
	 * @access public
	 */
	public function render_control_template_scripts() {

		?>
		<script type="text/html" id="tmpl-widget-organic_widgets_feature_list_section-control-fields">

			<# var elementIdPrefix = 'el' + String( Math.random() ).replace( /\D/g, '' ) + '_' #>

			<p><b><?php _e( 'Add Custom Content:', 'organic-widgets-pro' ) ?></b></p>

			<p>
				<label for="{{ elementIdPrefix }}title"><?php esc_html_e( 'Title:' ); ?></label>
				<input id="{{ elementIdPrefix }}title" type="text" class="widefat title">
			</p>
			<p>
				<label for="{{ elementIdPrefix }}text" class="screen-reader-text"><?php esc_html_e( 'Content:' ); ?></label>
				<textarea id="{{ elementIdPrefix }}text" class="widefat text" style="height: 200px" rows="16" cols="20"></textarea>
			</p>
		</script>
		<?php
	}

	/**
	 * Ouput HTML for a Repeatable Feature List Form Item
	 *
	 * @access protected
	 */
	protected function echo_repeatable_form_item( $id = 'template', $order = 'template', $repeatable = false, $instance = false ) {

		if ( 'template' === $id || 'template' === $order ) {
			$template = true;
			$id       = '__x__';
			$order    = '';
		} else {
			$template = false;
			$id       = (int) $id;
			$order    = (int) $order;
		}
		$icon_id_string = '_reapeatable_icon_image-' . $id;

		if ( $repeatable && isset( $repeatable['icon'] ) ) {
			$icon_type = strpos( $repeatable['icon'], 'fa' ) !== false ? 'fontawesome' : 'image';
		} else {
			$icon_type = false;
		}

		?>

		<div class="<?php if ( $template ) { echo 'organic-widgets-repeatable-form-item-template'; } else { echo 'organic-widgets-repeatable-form-item'; } ?>" data-feature-id="<?php echo $id; ?>" data-order="<?php echo $order; ?>">

			<div class="organic-widgets-repeatable-form-item-title-bar">
				<?php esc_html_e( 'Feature', 'organic-widgets-pro' ); ?>
				<span class="organic-widgets-repeatable-item-number">
					<?php
					if ( is_numeric( $order ) ) {
						echo $order + 1;
					}
					?>
				</span>
			</div>

			<div class="organic-widgets-repeatable-form-item-fields-wrapper">

				<div class="organic-widgets-feature-list-icon-preview-wrapper">
					<p>
						<label><?php esc_html_e( 'Icon:', 'organic-widgets-pro' ); ?></label>
					</p>
					<div class="organic-widgets-feature-list-icon-preview organic-widgets-repeatable-image-preview" id="<?php echo ( $this->get_field_id( 'image_preview' . $icon_id_string ) ); ?>">
						<?php if ( $icon_type && 'image' === $icon_type && $repeatable['icon'] > 0 ) { ?>
							<?php echo $this->get_image_html( $instance, $repeatable ); ?>
						<?php } elseif ( 'fontawesome' === $icon_type ) { ?>
							<i class="fa <?php echo esc_attr( $repeatable['icon'] ); ?>"></i>
						<?php } ?>
					</div>
				</div>

				<div class="organic-widgets-feature-list-text-fields-wrapper">

					<p>
						<label><?php esc_html_e( 'Feature Title:', 'organic-widgets-pro' ) ?></label>
						<input class="widefat organic-widgets-feature-list-title-input organic-widgets-repeatable-form-item-input" data-input-name="title" data-activator="true" type="text" value="<?php if ( $repeatable && array_key_exists( 'title', $repeatable ) ) echo esc_html( $repeatable['title'] ); ?>" data-feature-id="<?php echo $id; ?>" />
					</p>

					<p>
						<label><?php esc_html_e( 'Feature Link Text:', 'organic-widgets-pro' ) ?></label>
						<input class="widefat organic-widgets-feature-list-link-text-input organic-widgets-repeatable-form-item-input" data-input-name="link_text" type="text" value="<?php if ( $repeatable && array_key_exists( 'link_text', $repeatable ) ) echo esc_html( $repeatable['link_text'] ); ?>" data-feature-id="<?php echo $id; ?>" />
					</p>

					<p>
						<label><?php esc_html_e( 'Feature Link URL:', 'organic-widgets-pro' ) ?></label>
						<input class="widefat organic-widgets-feature-list-link-url-input organic-widgets-repeatable-form-item-input" data-input-name="link_url" type="text" value="<?php if ( $repeatable && array_key_exists( 'link_url', $repeatable ) ) echo esc_url( $repeatable['link_url'] ); ?>" data-feature-id="<?php echo $id; ?>" />
					</p>

					<p>
						<script>
						(function($) {
							$('#<?php echo $this->get_field_id( 'link_target' ); ?>-<?php echo $id; ?>').change(function() {
								var selected = $(this).val();
								$('#<?php echo esc_html( $this->get_field_id( 'link_target_selected' ) ); ?>-<?php echo $id; ?>').val(selected);
								$('#<?php echo esc_html( $this->get_field_id( 'link_target_selected' ) ); ?>-<?php echo $id; ?>').trigger('change');
							});
						})(jQuery);
						</script>
						<input id="<?php echo $this->get_field_id( 'link_target_selected' ); ?>-<?php echo $id; ?>" class="widefat organic-widgets-feature-list-hidden-input organic-widgets-repeatable-form-item-input" type="hidden" data-input-name="link_target_selected" value="" data-feature-id="<?php echo $id; ?>" />
						<label for="<?php echo $this->get_field_id( 'link_target' ); ?>-<?php echo $id; ?>"><?php esc_html_e( 'Feature Link Target:', 'organic-widgets-pro' ); ?>
							<select class="organic-widgets-feature-list-select organic-widgets-repeatable-form-item-input" id="<?php echo $this->get_field_id( 'link_target' ); ?>-<?php echo $id; ?>" data-input-name="link_target" data-feature-id="<?php echo $id; ?>">
								<option data-value="window-same" value="window-same" <?php selected( $repeatable['link_target'], 'window-same' ); ?>><?php esc_html_e( 'Same Window', 'organic-widgets-pro' ); ?></option>
								<option data-value="window-new" value="window-new" <?php selected( $repeatable['link_target'], 'window-new' ); ?>><?php esc_html_e( 'New Window', 'organic-widgets-pro' ); ?></option>
							</select>
						</label>
					</p>

				</div>

				<div class="organic-widgets-clear"></div>

				<label><?php esc_html_e( 'Select Icon:', 'organic-widgets-pro' ); ?></label>
				<p>
					<div class="organic-widgets-feature-list-select">
						<div class="organic-widgets-dropdown-button">
							<div class="organic-widgets-feature-list-select-icon"><i class="fa fa-angle-down"></i></div>
							<p><?php esc_html_e( 'Select Icon', 'organic-widgets-pro' ); ?></p>
						</div>
						<div class="organic-widgets-clear"></div>
						<div class="organic-widgets-feature-list-select-dropdown">
							<?php $this->getIconOptionsDivs(); ?>
							<div class="organic-widgets-clear"></div>
						</div>
					</div>
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'icon' ); ?>"><?php _e( 'Custom Icon Image:', 'organic-widgets-pro' ); ?></label>
					<div class="organic-widgets-image-uploader">
						<div
							class="organic-widgets-upload-image-button button"
							id="<?php echo( $this->get_field_id( 'uploader_button' . $icon_id_string ) ); ?>" onclick="organicWidgetFeatureIconImage.uploader( '<?php echo $this->id; ?>', '<?php echo $this->id_prefix; ?>', '<?php echo $icon_id_string; ?>' ); return false;"
						>
							<?php
							if ( isset( $repeatable['icon'] ) ) {
								esc_html_e( 'Change Image', 'organic-widgets-pro' );
							} else {
								esc_html_e( 'Select Image', 'organic-widgets-pro' ); }
							?>
						</div>
						<div
							class="organic-widgets-remove-image-button button"
							id="<?php echo( $this->get_field_id( 'remover_button' . $icon_id_string ) ); ?>" onclick="organicWidgetFeatureIconImage.remover( '<?php echo $this->id; ?>', '<?php echo $this->id_prefix;?>', '<?php echo $icon_id_string; ?>', 'remover_button' ); return false;"
							<?php if ( ! isset( $repeatable['icon'] ) || $repeatable['icon'] < 1 ) echo( 'style="display:none;"' ); ?>
						>
							<?php esc_html_e( 'Remove Image', 'organic-widgets-pro' ); ?>
						</div>
						<!-- Removed name attribute on this input so customizer refreshes on move -->
						<input
							class="organic-widgets-repeatable-form-item-input"
							data-input-name="icon"
							data-activator="true"
							type="hidden"
							id="<?php echo ( esc_html( $this->get_field_id( 'icon' . $icon_id_string ) ) ); ?>"
							value="<?php if ( $icon_type ) echo esc_attr( $repeatable['icon'] ); ?>"
							data-feature-id="<?php echo esc_html( $id ); ?>"
						/>
					</div>
				</p>

				<p>
					<label><?php esc_html_e( 'Feature Text:', 'organic-widgets-pro' ); ?></label>
					<textarea class="widefat organic-widgets-feature-list-text-input organic-widgets-repeatable-form-item-input" data-input-name="text" data-activator="true" data-feature-id="<?php echo $id; ?>" rows="3" cols="20" ><?php if ( $repeatable && array_key_exists( 'text', $repeatable ) ) { echo esc_html( $repeatable['text'] ); } ?></textarea>
				</p>

				<div class="organic-widgets-clear"></div>

				<?php $this->echo_repeatable_form_item_actions(); ?>

			</div>

		</div>

		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		/*--- Text/Title ----*/
		if ( ! isset( $newinstance['filter'] ) )
			$instance['filter'] = false;
		if ( ! isset( $newinstance['visual'] ) )
			$instance['visual'] = null;
		// Upgrade 4.8.0 format.
		if ( isset( $old_instance['filter'] ) && 'content' === $old_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( 'content' === $new_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( isset( $new_instance['visual'] ) ) {
			$instance['visual'] = ! empty( $new_instance['visual'] );
		}
		// Filter is always true in visual mode.
		if ( ! empty( $instance['visual'] ) ) {
			$instance['filter'] = true;
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance['title'] = $new_instance['title'];
			$instance['text']  = $new_instance['text'];
		} else {
			$instance['title'] = wp_kses_post( $new_instance['title'] );
			$instance['text']  = wp_kses_post( $new_instance['text'] );
		}
		/*--- END Text/Title ----*/

		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}
		if ( isset( $new_instance['button_text'] ) ) {
			$instance['button_text'] = wp_strip_all_tags( $new_instance['button_text'] );
		}
		if ( isset( $new_instance['button_url'] ) ) {
			$instance['button_url'] = wp_strip_all_tags( $new_instance['button_url'] );
		}
		if ( isset( $new_instance['num_columns'] ) ) {
			$instance['num_columns'] = wp_strip_all_tags( $new_instance['num_columns'] );
		}
		if ( isset( $new_instance['icon_image_size'] ) ) {
			$instance['icon_image_size'] = wp_strip_all_tags( $new_instance['icon_image_size'] );
		}
		if ( isset( $new_instance['icon_color'] ) && $this->check_hex_color( $new_instance['icon_color'] ) ) {
			$instance['icon_color'] = wp_strip_all_tags( $new_instance['icon_color'] );
		}
		if ( isset( $new_instance['repeatable_array'] ) ) {
			$instance['repeatable_array'] = $new_instance['repeatable_array'];
		}

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		if ( isset( $new_instance['hide_content_bg'] ) ) {
			$instance['hide_content_bg'] = true;
		} else {
			$instance['hide_content_bg'] = false;
		}
		/*--- END Background ----*/

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = wp_strip_all_tags( $new_instance['title_text_heading'] );
		}
		if ( isset( $new_instance['title_text_color'] ) ) {
			$instance['title_text_color'] = wp_strip_all_tags( $new_instance['title_text_color'] );
		}
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		if ( isset( $new_instance['content_heading_font_family'] ) ) {
			$instance['content_heading_font_family'] = wp_strip_all_tags( $new_instance['content_heading_font_family'] );
		}
		if ( isset( $new_instance['content_heading_font_weight'] ) ) {
			$instance['content_heading_font_weight'] = wp_strip_all_tags( $new_instance['content_heading_font_weight'] );
		}
		if ( isset( $new_instance['content_heading_font_size'] ) ) {
			$instance['content_heading_font_size'] = wp_strip_all_tags( $new_instance['content_heading_font_size'] );
		}
		if ( isset( $new_instance['body_font_family'] ) ) {
			$instance['body_font_family'] = wp_strip_all_tags( $new_instance['body_font_family'] );
		}
		if ( isset( $new_instance['body_text_color'] ) ) {
			$instance['body_text_color'] = wp_strip_all_tags( $new_instance['body_text_color'] );
		}
		if ( isset( $new_instance['text_align'] ) ) {
			$instance['text_align'] = wp_strip_all_tags( $new_instance['text_align'] );
		}
		/*--- END Font Options ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['widget_padding_top'] ) ) {
			$instance['widget_padding_top'] = wp_strip_all_tags( $new_instance['widget_padding_top'] );
		}
		if ( isset( $new_instance['widget_padding_bottom'] ) ) {
			$instance['widget_padding_bottom'] = wp_strip_all_tags( $new_instance['widget_padding_bottom'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['content_max_width'] ) ) {
			$instance['content_max_width'] = wp_strip_all_tags( $new_instance['content_max_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		/*--- END Layout ----*/

		return $instance;
	}

	/**
	 * Enqueue all the javascript.
	 */
	public function admin_setup() {

		// Text Editor.
		wp_enqueue_editor();

		wp_enqueue_script( 'organic-widgets-feature-list-text-title', plugin_dir_url( __FILE__ ) . 'js/feature-list-widgets.js', array( 'jquery', 'wp-embed', 'underscore' ), '1.0', true );
		wp_localize_script( 'organic-widgets-feature-list-text-title', 'OrganicFeatureListWidget', array(
			'id_base' => $this->id_base,
		) );
		wp_add_inline_script( 'organic-widgets-feature-list-text-title', 'wp.organicFeatureListWidget.init();', 'after' );

		wp_enqueue_media();

		// Repeatable Form Items.
		if ( ! wp_script_is( 'organic-widgets-module-repeatable-form-item-js' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-repeatable-form-item-js', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-repeatable-form-items.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_style( 'organic-widgets-fontawesome', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/css/font-awesome.css', '', '4.0' );

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );
		// wp_enqueue_script( 'organic-widgets-module-icon-sizer', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-icon-sizer.js', array( 'jquery' ), '1.0', true );

		if ( ! wp_script_is( 'organic-widgets-module-image-background' ) ) {
			wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
			wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
				'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
				'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
			) );
		}
		if ( ! wp_script_is( 'organic-widgets-module-repeatable-icon-image' ) ) {
			wp_enqueue_script( 'organic-widgets-module-repeatable-icon-image', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-repeatable-icon-image.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
			wp_localize_script( 'organic-widgets-module-repeatable-icon-image', 'RepeatableIcon', array(
				'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
				'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
			) );
		}

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		wp_enqueue_style( 'organic-widgets-fontawesome', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/css/font-awesome.css', '', '4.7' );

		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ), '1.0', true );
		}

	}


} // class Organic_Widgets_Pro_Feature_List_Widget
