<?php
/**
 * Registers a widget to show a audio playlist section.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Gallery_Widget widget.
 */
class Organic_Widgets_Pro_Gallery_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_gallery_section', // Base ID.
			__( 'Organic Image Gallery', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'An image gallery section.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'video'     => false,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'          => true,
			'title_font'             => true,
			'title_color'            => true,
			'title_weight'           => true,
			'title_spacing'          => true,
			'title_size'             => true,
			'content_heading_font'   => false,
			'content_heading_size'   => false,
			'content_heading_weight' => false,
			'body_font'              => true,
			'text_alignment'         => false,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner' => false,
			'padding_top'     => true,
			'padding_bottom'  => true,
			'custom_height'   => true,
			'custom_width'    => true,
			'content_width'   => true,
			'full_height'     => false,
		);

		// Admin Scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_setup' ) );
		add_action( 'admin_footer-widgets.php', array( $this, 'render_control_template_scripts' ) );

		// Public scripts.
		if ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'public_scripts' ) );
		}

	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$gallery_ids   = isset( $instance['gallery_ids'] ) ? $instance['gallery_ids'] : false;
		$gallery_style = ( isset( $instance['gallery_style'] ) ) ? $instance['gallery_style'] : 'style-gallery-square';
		$image_size    = ( isset( $instance['image_size'] ) ) ? $instance['image_size'] : 'large';
		$num_columns   = ( isset( $instance['num_columns'] ) ) ? $instance['num_columns'] : 3;
		$column_gutter = ( isset( $instance['column_gutter'] ) ) ? $instance['column_gutter'] : 24;
		$button_text   = ( isset( $instance['button_text'] ) && '' !== $instance['button_text'] ) ? $instance['button_text'] : false;
		$button_url    = ( isset( $instance['button_url'] ) && '' !== $instance['button_url'] ) ? $instance['button_url'] : false;
		$bg_image_id   = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image      = ( isset( $instance['bg_image'] ) && '' !== $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color      = ( isset( $instance['bg_color'] ) && '' !== $instance['bg_color'] ) ? $instance['bg_color'] : false;

		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}

		echo $args['before_widget'];

		?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_max_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content {
					max-width: <?php echo absint( $instance['content_max_width'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) || '' !== $instance['widget_padding_top'] || '' !== $instance['widget_padding_bottom'] ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-section {
					<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
					min-height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_top'] ) { ?>
					padding-top: <?php echo intval( $instance['widget_padding_top'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_bottom'] ) { ?>
					padding-bottom: <?php echo intval( $instance['widget_padding_bottom'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['body_font_family'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content p {
					font-family: <?php echo esc_html( $instance['body_font_family'] ); ?>;
				}
			<?php } ?>
			<?php if ( '1' == $button_display ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-form #audioform #s {
					width: 100%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['column_gutter'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-grid-spacer {
					width: <?php echo esc_html( $instance['column_gutter'] ); ?>px;
				}
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-item {
					margin-bottom: <?php echo esc_html( $instance['column_gutter'] ); ?>px;
				}
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-item.organic-widgets-half {
					width: calc(50% - ( <?php echo esc_html( $instance['column_gutter'] ); ?>px * 1 / 2 ));
				}
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-item.organic-widgets-third {
					width: calc(33.33% - ( <?php echo esc_html( $instance['column_gutter'] ); ?>px * 2 / 3 ));
				}
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-item.organic-widgets-fourth {
					width: calc(25% - ( <?php echo esc_html( $instance['column_gutter'] ); ?>px * 3 / 4 ));
				}
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-item.organic-widgets-fifth {
					width: calc(20% - ( <?php echo esc_html( $instance['column_gutter'] ); ?>px * 4 / 5 ));
				}
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-gallery-item.organic-widgets-sixth {
					width: calc(16.66% - ( <?php echo esc_html( $instance['column_gutter'] ); ?>px * 5 / 6 ));
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<?php /** BEGIN .organic-widgets-section */ ?>
		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>
			id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"
		<?php } ?>
			class="organic-widgets-section organic-widgets-gallery-section
		<?php if ( $bg_image_fixed ) echo 'organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo 'organic-widgets-repeat-bg-img'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>
			style="background-image:url(<?php echo esc_url( $bg_image ); ?>);"
		<?php } if ( $bg_color ) { ?>
			style="background-color:<?php echo esc_attr( $bg_color ); ?>;"
		<?php } ?>>

				<?php /** BEGIN .organic-widgets-content */ ?>
				<div class="organic-widgets-content">

					<?php /** BEGIN .organic-widgets-gallery-information */ ?>
					<div class="organic-widgets-gallery-information organic-widgets-information">

						<?php if ( ! empty( $instance['title'] ) ) { ?>
							<<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?> class="organic-widgets-title"><?php echo wp_kses_post( apply_filters( 'organic_widget_title', $instance['title'] ) ); ?></<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?>>
						<?php } ?>

						<?php if ( ! empty( $instance['text'] ) || ! empty( $button_url ) ) { ?>

						<div class="organic-widgets-text">

							<?php if ( ! empty( $instance['text'] ) ) { ?>
								<div class="organic-widgets-text"><?php echo wp_kses_post( apply_filters( 'the_content', $instance['text'] ) ); ?></div>
							<?php } ?>

							<?php if ( ! empty( $button_url ) ) { ?>
								<a class="organic-widgets-button button" href="<?php echo esc_url( $button_url ); ?>"><?php if ( ! empty( $button_text ) ) { echo esc_html_e( $button_text, 'organic-widgets-pro' ); } else { esc_html_e( 'See More', 'organic-widgets-pro' ); } ?></a>
							<?php } ?>

						</div>

						<?php } ?>

					<?php /** END .organic-widgets-gallery-information */ ?>
					</div>

					<?php /** BEGIN .organic-widgets-gallery */ ?>
					<div class="organic-widgets-gallery organic-widgets-row organic-widgets-masonry-container <?php echo esc_html( $gallery_style ); ?>">

						<div class="organic-widgets-grid-spacer"></div>

						<?php
						$attachment_ids   = $instance['gallery_ids'];
						$attachment_array = array_map( 'trim', explode( ',', $attachment_ids ) );
						$attachment_args  = array(
							'post__in'       => $attachment_array,
							'post_type'      => 'attachment',
							'post_mime_type' => 'image',
							'posts_per_page' => -1,
							'post_status'    => 'any',
							'orderby'        => 'post__in',
						);

						$attachments = get_posts( $attachment_args );
						?>

						<?php foreach ( $attachments as $attachment ) { ?>

							<div class="organic-widgets-gallery-item organic-widgets-masonry-wrapper organic-widgets-column organic-widgets-<?php echo esc_html( $this->column_string( $num_columns ) ); ?>">
								<?php if ( ! empty( wp_get_attachment_caption( $attachment->ID ) ) ) { ?>
								<div class="organic-widgets-img-text">
									<p class="organic-widgets-gallery-caption"><?php echo esc_html( wp_get_attachment_caption( $attachment->ID ) ); ?></p>
								</div>
								<?php } ?>
								<div class="organic-widgets-gallery-image">
									<?php echo wp_get_attachment_image( $attachment->ID, esc_html( $image_size ) ); ?>
								</div>
							</div>

						<?php } ?>

					<?php /** END .organic-widgets-gallery */ ?>
					</div>

				<?php /** END .organic-widgets-content */ ?>
				</div>

			<?php /** END .organic-widgets-section */ ?>
			</div>

			<?php

			echo $args['after_widget'];

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'text'  => '',
			)
		);

		// Setup Variables.
		$this->id_prefix = $this->get_field_id( '' );

		if ( isset( $instance['gallery_ids'] ) ) {
			$gallery_ids = $instance['gallery_ids'];
		} else {
			$gallery_ids = false;
		}

		if ( isset( $instance['gallery_style'] ) ) {
			$gallery_style = $instance['gallery_style'];
		} else {
			$gallery_style = 'style-gallery-square';
		}

		if ( isset( $instance['image_size'] ) ) {
			$image_size = $instance['image_size'];
		} else {
			$image_size = 'large';
		}

		if ( isset( $instance['num_columns'] ) ) {
			$num_columns = $instance['num_columns'];
		} else {
			$num_columns = 3;
		}

		if ( isset( $instance['column_gutter'] ) ) {
			$column_gutter = $instance['column_gutter'];
		} else {
			$column_gutter = 24;
		}

		if ( isset( $instance['button_text'] ) ) {
			$button_text = $instance['button_text'];
		} else {
			$button_text = false;
		}

		if ( isset( $instance['button_url'] ) ) {
			$button_url = $instance['button_url'];
		} else {
			$button_url = false;
		}

		?>

		<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" class="title" type="hidden" value="<?php echo esc_attr( $instance['title'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" class="text organic-widgets-wysiwyg-anchor" type="hidden" value="<?php echo esc_attr( $instance['text'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'filter' ); ?>" name="<?php echo $this->get_field_name( 'filter' ); ?>" class="filter" type="hidden" value="on">
		<input id="<?php echo $this->get_field_id( 'visual' ); ?>" name="<?php echo $this->get_field_name( 'visual' ); ?>" class="visual" type="hidden" value="on">

		<div class="organic-widgets-option-set">
			<p class="organic-widgets-input-half">
				<label for="<?php echo $this->get_field_id( 'button_text' ); ?>"><?php _e( 'Button Text:', 'organic-widgets-pro' ); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'button_text' ); ?>" name="<?php echo $this->get_field_name( 'button_text' ); ?>" value="<?php echo esc_html( $button_text ); ?>" />
			</p>
			<p class="organic-widgets-input-half last">
				<label for="<?php echo $this->get_field_id( 'button_url' ); ?>"><?php _e('Button URL', 'organic-widgets-pro'); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'button_url' ); ?>" name="<?php echo $this->get_field_name( 'button_url' ); ?>" value="<?php echo esc_url( $button_url ); ?>" />
			</p>
		</div>

		<p>
			<label for="<?php echo $this->get_field_id( 'image_gallery' ); ?>"><?php _e( 'Image Gallery:', 'organic-widgets-pro' ); ?></label>
			<div class="organic-widgets-uploader">
				<input type="submit" class="button" name="<?php echo $this->get_field_name( 'gallery_uploader_button' ); ?>" id="<?php echo $this->get_field_id( 'gallery_uploader_button' ); ?>" value="<?php if ( $gallery_ids ) { esc_html_e( 'Manage Gallery', 'organic-widgets-pro' ); } else { esc_html_e( 'Create Gallery', 'organic-widgets-pro' ); }?>" onclick="organicWidgetGallery.uploader( '<?php echo $this->id; ?>', '<?php echo $this->id_prefix; ?>' ); return false;" />
				<input type="hidden" id="<?php echo $this->get_field_id( 'gallery_ids' ); ?>" name="<?php echo $this->get_field_name( 'gallery_ids' ); ?>" value="<?php echo $gallery_ids; ?>" />
			</div>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'gallery_style' ); ?>"><?php esc_html_e( 'Gallery Image Style:', 'organic-widgets-pro' ); ?>
				<select id="<?php echo $this->get_field_id( 'gallery_style' ); ?>" name="<?php echo $this->get_field_name( 'gallery_style' ); ?>">
					<option value="style-gallery-square" <?php echo ( 'style-gallery-square' === $gallery_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Square', 'organic-widgets-pro' ); ?></option>
					<option value="style-gallery-round" <?php echo ( 'style-gallery-round' === $gallery_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Round', 'organic-widgets-pro' ); ?></option>
					<option value="style-gallery-border" <?php echo ( 'style-gallery-border' === $gallery_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Border', 'organic-widgets-pro' ); ?></option>
					<option value="style-gallery-shadow" <?php echo ( 'style-gallery-shadow' === $gallery_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Shadow', 'organic-widgets-pro' ); ?></option>
				</select>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'image_size' ); ?>"><?php esc_html_e( 'Gallery Image Size:', 'organic-widgets-pro' ); ?>
				<select id="<?php echo $this->get_field_id( 'image_size' ); ?>" name="<?php echo $this->get_field_name( 'image_size' ); ?>">
					<option value="thumbnail" <?php echo ( 'thumbnail' === $image_size ) ? 'selected' : ''; ?>><?php esc_html_e( 'Thumbnail', 'organic-widgets-pro' ); ?></option>
					<option value="medium" <?php echo ( 'medium' === $image_size ) ? 'selected' : ''; ?>><?php esc_html_e( 'Small', 'organic-widgets-pro' ); ?></option>
					<option value="medium_large" <?php echo ( 'medium_large' === $image_size ) ? 'selected' : ''; ?>><?php esc_html_e( 'Medium', 'organic-widgets-pro' ); ?></option>
					<option value="large" <?php echo ( 'large' === $image_size ) ? 'selected' : ''; ?>><?php esc_html_e( 'Large', 'organic-widgets-pro' ); ?></option>
					<option value="full" <?php echo ( 'full' === $image_size ) ? 'selected' : ''; ?>><?php esc_html_e( 'Full Size', 'organic-widgets-pro' ); ?></option>
				</select>
			</label>
		</p>

		<div class="organic-widgets-option-set">
			<p class="organic-widgets-input-half">
				<label for="<?php echo $this->get_field_id( 'num_columns' ); ?>"><?php esc_html_e( 'Gallery Columns:', 'organic-widgets-pro' ) ?></label>
				<select id="<?php echo $this->get_field_id( 'num_columns' ); ?>" name="<?php echo $this->get_field_name( 'num_columns' ); ?>" class="widefat" style="width:100%;">
					<option <?php selected( $num_columns, '2' ); ?> value="2">2</option>
					<option <?php selected( $num_columns, '3' ); ?> value="3">3</option>
					<option <?php selected( $num_columns, '4' ); ?> value="4">4</option>
					<option <?php selected( $num_columns, '5' ); ?> value="5">5</option>
					<option <?php selected( $num_columns, '6' ); ?> value="6">6</option>
				</select>
			</p>
			<p class="organic-widgets-input-half unit last">
				<label for="<?php echo $this->get_field_id( 'column_gutter' ); ?>"><?php esc_html_e( 'Gutter Width:', 'organic-widgets-pro' ); ?></label>
				<input class="widefat maximum" type="number" min="0" max="100" id="<?php echo $this->get_field_id( 'column_gutter' ); ?>" name="<?php echo $this->get_field_name( 'column_gutter' ); ?>" value="<?php if ( ! empty( $instance['column_gutter'] ) ) { echo absint( $instance['column_gutter'] ); } else { echo '24'; } ?>" />
				<span><?php esc_html_e( 'px', 'organic-widgets-pro' ); ?></span>
			</p>
		</div>

		<br />

		<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

		<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

		<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php _e( 'Custom Widget Class', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
		</p>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
		</p>

		<?php

	}

	/**
	 * Render form template scripts.
	 *
	 * @access public
	 */
	public function render_control_template_scripts() {

		?>
		<script type="text/html" id="tmpl-widget-organic_widgets_gallery_section-control-fields">

			<# var elementIdPrefix = 'el' + String( Math.random() ).replace( /\D/g, '' ) + '_' #>

			<p>
				<label for="{{ elementIdPrefix }}title"><?php esc_html_e( 'Title:' ); ?></label>
				<input id="{{ elementIdPrefix }}title" type="text" class="widefat title">
			</p>
			<p>
				<label for="{{ elementIdPrefix }}text" class="screen-reader-text"><?php esc_html_e( 'Content:' ); ?></label>
				<textarea id="{{ elementIdPrefix }}text" class="widefat text" style="height: 200px" rows="16" cols="20"></textarea>
			</p>
		</script>
		<?php

	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}

		/*--- Text/Title ----*/
		if ( ! isset( $newinstance['filter'] ) ) {
			$instance['filter'] = false;
		}
		if ( ! isset( $newinstance['visual'] ) ) {
			$instance['visual'] = null;
		}
		// Upgrade 4.8.0 format.
		if ( isset( $old_instance['filter'] ) && 'content' === $old_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( 'content' === $new_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( isset( $new_instance['visual'] ) ) {
			$instance['visual'] = ! empty( $new_instance['visual'] );
		}
		// Filter is always true in visual mode.
		if ( ! empty( $instance['visual'] ) ) {
			$instance['filter'] = true;
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance['title'] = $new_instance['title'];
			$instance['text']  = $new_instance['text'];
		} else {
			$instance['title'] = wp_kses_post( $new_instance['title'] );
			$instance['text']  = wp_kses_post( $new_instance['text'] );
		}
		/*--- END Text/Title ----*/

		/*--- Unique Options ----*/
		if ( isset( $new_instance['gallery_ids'] ) ) {
			$instance['gallery_ids'] = wp_strip_all_tags( $new_instance['gallery_ids'] );
		}
		if ( isset( $new_instance['gallery_style'] ) ) {
			$instance['gallery_style'] = wp_strip_all_tags( $new_instance['gallery_style'] );
		}
		if ( isset( $new_instance['image_size'] ) ) {
			$instance['image_size'] = wp_strip_all_tags( $new_instance['image_size'] );
		}
		if ( isset( $new_instance['num_columns'] ) ) {
			$instance['num_columns'] = wp_strip_all_tags( $new_instance['num_columns'] );
		}
		if ( isset( $new_instance['column_gutter'] ) ) {
			$instance['column_gutter'] = wp_strip_all_tags( $new_instance['column_gutter'] );
		}
		if ( isset( $new_instance['button_text'] ) ) {
			$instance['button_text'] = wp_strip_all_tags( $new_instance['button_text'] );
		}
		if ( isset( $new_instance['button_url'] ) ) {
			$instance['button_url'] = wp_strip_all_tags( $new_instance['button_url'] );
		}
		/*--- END Unique Options ----*/

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		/*--- END Background ----*/

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = wp_strip_all_tags( $new_instance['title_text_heading'] );
		}
		if ( isset( $new_instance['title_text_color'] ) ) {
			$instance['title_text_color'] = wp_strip_all_tags( $new_instance['title_text_color'] );
		}
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		if ( isset( $new_instance['body_font_family'] ) ) {
			$instance['body_font_family'] = wp_strip_all_tags( $new_instance['body_font_family'] );
		}
		/*--- END Font Options ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['widget_padding_top'] ) ) {
			$instance['widget_padding_top'] = wp_strip_all_tags( $new_instance['widget_padding_top'] );
		}
		if ( isset( $new_instance['widget_padding_bottom'] ) ) {
			$instance['widget_padding_bottom'] = wp_strip_all_tags( $new_instance['widget_padding_bottom'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['content_max_width'] ) ) {
			$instance['content_max_width'] = wp_strip_all_tags( $new_instance['content_max_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		/*--- END Layout ----*/

		return $instance;
	}

	/**
	 * Enqueue all the javascript.
	 */
	public function admin_setup() {

		// Text Editor.
		wp_enqueue_editor();
		wp_enqueue_script( 'organic-widgets-gallery-text-title', plugin_dir_url( __FILE__ ) . 'js/image-gallery-widgets.js', array( 'jquery', 'wp-embed', 'underscore' ), '1.0', true );
		wp_localize_script( 'organic-widgets-gallery-text-title', 'OrganicImageGalleryWidget', array(
			'id_base' => $this->id_base,
		) );
		wp_add_inline_script( 'organic-widgets-gallery-text-title', 'wp.organicImageGalleryWidget.init();', 'after' );

		// Content Aligner.
		if ( ! wp_script_is( 'organic-widgets-module-content-aligner' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-content-aligner', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-content-aligner.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_media();

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );

		wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
		wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
			'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
			'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
		) );

		wp_enqueue_script( 'organic-widgets-module-gallery', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-gallery.js', array( 'jquery', 'media-upload', 'media-views' ), '1.0', true );
		wp_localize_script( 'organic-widgets-module-gallery', 'OrganicWidgetGALLERY', array(
			'frame_title'  => __( 'Select Gallery', 'organic-widgets-pro' ),
			'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
		) );

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_script( 'organic-widgets-masonry', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/masonry-setup.js', array( 'jquery', 'masonry' ), '1.0', true );

	}

} // class Organic_Widgets_Pro_Gallery_Widget
