<?php
/**
 * Registers a widget to show a list of features.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Image_Slideshow_Widget widget.
 */
class Organic_Widgets_Pro_Image_Slideshow_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_image_slideshow_section', // Base ID.
			__( 'Organic Image Slideshow', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'A slideshow of images.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'video'     => false,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'          => false,
			'title_font'             => true,
			'title_color'            => false,
			'title_weight'           => true,
			'title_spacing'          => true,
			'title_size'             => true,
			'content_heading_font'   => false,
			'content_heading_size'   => false,
			'content_heading_weight' => false,
			'body_font'              => false,
			'text_alignment'         => false,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner' => true,
			'padding_top'     => false,
			'padding_bottom'  => false,
			'custom_height'   => true,
			'custom_width'    => true,
			'full_height'     => false,
		);

		// Admin Scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_setup' ) );

		// Public scripts.
		if ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'public_scripts' ) );
		}

	}
	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$bg_image_id                = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image                   = ( isset( $instance['bg_image'] ) && '' != $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color                   = ( isset( $instance['bg_color'] ) && '' != $instance['bg_color'] ) ? $instance['bg_color'] : false;
		$slide_style                = ( isset( $instance['slide_style'] ) ) ? $instance['slide_style'] : 'style-default';
		$slideshow_transition_style = ( isset( $instance['slideshow_transition_style'] ) ) ? $instance['slideshow_transition_style'] : 'fade';
		$slideshow_interval         = ( isset( $instance['slideshow_interval'] ) ) ? $instance['slideshow_interval'] : 12000;

		// Register BG Fixed Option.
		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		// Register BG Repeat Option.
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}

		$repeatable_array = ( isset( $instance['repeatable_array'] ) ) ? json_decode( $instance['repeatable_array'], true ) : array();

		echo $args['before_widget'];

		?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-flexslider,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-flexslider .slides li.slide {
					height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .slide-text h4 {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"<?php } ?>
		class="organic-widgets-section organic-widgets-image-slideshow-section
		<?php echo esc_html( $slide_style ); ?>
		<?php if ( $bg_image_fixed ) echo 'organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo 'organic-widgets-repeat-bg-img'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>
			style="background-image:url(<?php echo esc_url( $bg_image ); ?>);"
		<?php } if ( $bg_color ) { ?>
			style="background-color:<?php echo esc_attr( $bg_color ); ?>;"
		<?php } ?>>

		<?php if ( ! empty( $repeatable_array ) ) { ?>

			<?php /** BEGIN .flexslider */ ?>
			<div class="organic-widgets-flexslider loading" data-speed="<?php echo esc_attr( $slideshow_interval ); ?>" data-transition="<?php echo esc_attr( $slideshow_transition_style ); ?>">

				<div class="preloader"></div>

				<?php /** BEGIN .slides */ ?>
				<ul class="slides">

				<?php

				if ( is_array( $repeatable_array ) && count( $repeatable_array ) ) {
					$incrementer = 0;
					usort( $repeatable_array, array( $this, 'sort_by_order' ) );
					foreach ( $repeatable_array as $key => $repeatable ) {

						$image_id = $repeatable['image'];

						$incrementer++;

						?>

						<li class="slide" <?php echo 'style="background-image:url(' . esc_url( wp_get_attachment_url( $image_id ) ) . ')"'; ?>>

							<?php if ( '' !== $repeatable['link_url'] ) { ?>
							<a class="slide-link" href="<?php echo esc_url( $repeatable['link_url'] ); ?>" <?php if ( 'window-new' === $repeatable['link_target'] ) { ?>target="_blank"<?php } ?>>
							<?php } ?>

							<?php /** BEGIN .organic-widgets-aligner */ ?>
							<div class="organic-widgets-aligner <?php if ( ! empty( $instance['alignment'] ) ) { echo 'organic-widgets-aligner-' . esc_attr( $instance['alignment'] ); } ?>">

								<div class="slide-text">
									<h4><?php if ( array_key_exists( 'title', $repeatable ) ) { echo esc_html( $repeatable['title'] ); } ?></h4>
								</div>

							<?php /** END .organic-widgets-aligner */ ?>
							</div>

							<?php if ( '' != $repeatable['link_url'] ) { echo '</a>'; } ?>

							<div class="organic-widgets-hide-img">
								<?php echo $this->get_image_html( $instance, $repeatable ); ?>
							</div>

						</li>

					<?php } ?>

				<?php } ?>

				<?php /** END .slides */ ?>
				</ul>

			<?php /** END .flexslider */ ?>
			</div>

		<?php } ?>

		</div>

		<?php

		echo $args['after_widget'];

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		// Setup Variables.
		$this->id_prefix = $this->get_field_id( '' );

		$slideshow_transition_style = ( isset( $instance['slideshow_transition_style'] ) ) ? $instance['slideshow_transition_style'] : 'fade';
		$slideshow_interval         = ( isset( $instance['slideshow_interval'] ) ) ? $instance['slideshow_interval'] : 12000;

		if ( isset( $instance['slide_style'] ) ) {
			$slide_style = $instance['slide_style'];
		} else {
			$slide_style = 'style-default';
		}
		if ( isset( $instance['repeatable_array'] ) ) {
			$repeatable_array = json_decode( $instance['repeatable_array'], true );
		} else {
			$repeatable_array = array();
		}

		?>

			<p>
				<label for="<?php echo $this->get_field_id( 'slideshow_transition_style' ); ?>"><?php esc_html_e( 'Slide Transition:', 'organic-widgets-pro' ); ?></label>
				<select id="<?php echo $this->get_field_id( 'slideshow_transition_style' ); ?>" name="<?php echo $this->get_field_name( 'slideshow_transition_style' ); ?>" class="widefat" style="width:100%;">
					<option <?php selected( $slideshow_transition_style, 'fade' ); ?> value="fade"><?php esc_html_e( 'Fade', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_transition_style, 'slide' ); ?> value="slide"><?php esc_html_e( 'Slide', 'organic-widgets-pro' ); ?></option>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'slideshow_interval' ); ?>"><?php esc_html_e( 'Slide Interval:', 'organic-widgets-pro' ); ?></label>
				<select id="<?php echo $this->get_field_id( 'slideshow_interval' ); ?>" name="<?php echo $this->get_field_name( 'slideshow_interval' ); ?>" class="widefat" style="width:100%;">
					<option <?php selected( $slideshow_interval, '2000' ); ?> value="2000"><?php esc_html_e( '2 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '4000' ); ?> value="4000"><?php esc_html_e( '4 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '6000' ); ?> value="6000"><?php esc_html_e( '6 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '8000' ); ?> value="8000"><?php esc_html_e( '8 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '10000' ); ?> value="10000"><?php esc_html_e( '10 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '12000' ); ?> value="12000"><?php esc_html_e( '12 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '20000' ); ?> value="20000"><?php esc_html_e( '20 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '30000' ); ?> value="30000"><?php esc_html_e( '30 Seconds', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '60000' ); ?> value="60000"><?php esc_html_e( '1 Minute', 'organic-widgets-pro' ); ?></option>
					<option <?php selected( $slideshow_interval, '999999999' ); ?> value="999999999"><?php esc_html_e( 'Hold Frame', 'organic-widgets-pro' ); ?></option>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'slide_style' ); ?>"><?php esc_html_e( 'Slideshow Style:', 'organic-widgets-pro' ); ?>
					<select id="<?php echo $this->get_field_id( 'slide_style' ); ?>" name="<?php echo $this->get_field_name( 'slide_style' ); ?>">
						<option value="style-default" <?php echo ( 'style-default' === $slide_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Default', 'organic-widgets-pro' ); ?></option>
						<option value="style-rounded" <?php echo ( 'style-rounded' === $slide_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Rounded', 'organic-widgets-pro' ); ?></option>
						<option value="style-modern" <?php echo ( 'style-modern' === $slide_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Modern', 'organic-widgets-pro' ); ?></option>
					</select>
				</label>
			</p>

			<br />

			<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

			<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

			<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

			<div class="organic-widgets-repeatable-form-item-widget-admin">

				<?php $this->repeatable_form_item_inputs_markup( $repeatable_array, '' ); ?>

			</div>

			<p class="organic-widgets-input">
				<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php esc_html_e( 'Custom Widget Class', 'organic-widgets-pro' ); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
			</p>

			<p class="organic-widgets-input">
				<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
			</p>

		<?php

	}

	/**
	 * Ouput HTML for a Repeatable Form Item
	 *
	 * @access protected
	 */
	protected function echo_repeatable_form_item( $id = 'template', $order = 'template', $repeatable = false, $instance = false ) {

		if ( 'template' === $id || 'template' === $order ) {
			$template = true;
			$id       = '__x__';
			$order    = '';
		} else {
			$template = false;
			$id       = (int) $id;
			$order    = (int) $order;
		}

		$image_id_string = '_reapeatable_slide_image-' . $id;

		?>

		<div class="<?php if ( $template ) { echo 'organic-widgets-repeatable-form-item-template'; } else { echo 'organic-widgets-repeatable-form-item'; } ?>" data-feature-id="<?php echo $id; ?>" data-order="<?php echo $order; ?>">

			<div class="organic-widgets-repeatable-form-item-title-bar">
				<?php esc_html_e( 'Slide', 'organic-widgets-pro' ); ?>
				<span class="organic-widgets-repeatable-item-number">
					<?php
					if ( is_numeric( $order ) ) {
						echo (int)$order + 1;
					}
					?>
				</span>
			</div>

			<div class="organic-widgets-repeatable-form-item-fields-wrapper organic-widgets-slide-fields-wrapper">

				<div class="organic-widgets-slide-image-preview organic-widgets-repeatable-image-preview" id="<?php echo ( $this->get_field_id( 'image_preview' . $image_id_string ) ); ?>">
					<?php echo $this->get_image_html( $instance, $repeatable ); ?>
				</div>

				<div class="organic-widgets-image-uploader">
					<div class="organic-widgets-upload-image-button button" id="<?php echo( $this->get_field_id( 'uploader_button' . $image_id_string ) ); ?>" onclick="organicWidgetSlideImage.uploader( '<?php echo $this->id; ?>', '<?php echo $this->id_prefix; ?>', '<?php echo $image_id_string; ?>' ); return false;" >
						<?php
						if ( isset( $repeatable['image'] ) ) {
							esc_html_e( 'Change Image', 'organic-widgets-pro' );
						} else {
							esc_html_e( 'Select Image', 'organic-widgets-pro' );
						}
						?>
					</div>
					<div class="organic-widgets-remove-image-button button" id="<?php echo( $this->get_field_id( 'remover_button' . $image_id_string ) ); ?>" onclick="organicWidgetSlideImage.remover( '<?php echo $this->id; ?>', '<?php echo $this->id_prefix;?>', '<?php echo $image_id_string; ?>', 'remover_button' ); return false;" <?php if ( ! isset( $repeatable['image'] ) || $repeatable['image'] < 1 ) echo( 'style="display:none;"' ); ?>>
						<?php esc_html_e( 'Remove Image', 'organic-widgets-pro' ); ?>
					</div>
					<input
						class="organic-widgets-repeatable-form-item-input"
						data-input-name="image"
						data-activator="true"
						type="hidden"
						id="<?php echo ( esc_html( $this->get_field_id( 'image' . $image_id_string ) ) ); ?>"
						data-feature-id="<?php echo esc_html( $id ); ?>"
						value="<?php echo esc_html( $repeatable['image'] ); ?>"
					/>
				</div>

				<div class="organic-widgets-slide-text-fields">

					<p>
						<label><?php esc_html_e( 'Slide Title:', 'organic-widgets-pro' ) ?></label>
						<input class="widefat organic-widgets-slide-title-input organic-widgets-repeatable-form-item-input" data-input-name="title" data-activator="true" type="text" value="<?php if ( $repeatable && array_key_exists( 'title', $repeatable ) ) echo esc_html( $repeatable['title'] ); ?>" data-feature-id="<?php echo $id; ?>"/>
					</p>

					<p>
						<label><?php esc_html_e( 'Slide URL:', 'organic-widgets-pro' ) ?></label>
						<input class="widefat organic-widgets-slide-link-url-input organic-widgets-repeatable-form-item-input" data-input-name="link_url" data-activator="true" type="text" value="<?php if ( $repeatable && array_key_exists( 'link_url', $repeatable ) ) echo esc_url( $repeatable['link_url'] ); ?>" data-feature-id="<?php echo $id; ?>"/>
					</p>

					<p>
						<script>
						(function($) {
							$('#<?php echo $this->get_field_id( 'link_target' ); ?>-<?php echo $id; ?>').change(function() {
								var selected = $(this).val();
								$('#<?php echo esc_html( $this->get_field_id( 'link_target_selected' ) ); ?>-<?php echo $id; ?>').val(selected);
								$('#<?php echo esc_html( $this->get_field_id( 'link_target_selected' ) ); ?>-<?php echo $id; ?>').trigger('change');
							});
						})(jQuery);
						</script>
						<input id="<?php echo $this->get_field_id( 'link_target_selected' ); ?>-<?php echo $id; ?>" class="widefat organic-widgets-feature-list-hidden-input organic-widgets-repeatable-form-item-input" type="hidden" data-input-name="link_target_selected" value="" data-feature-id="<?php echo $id; ?>" />
						<label for="<?php echo $this->get_field_id( 'link_target' ); ?>-<?php echo $id; ?>"><?php esc_html_e( 'Slide Link Target:', 'organic-widgets-pro' ); ?>
							<select class="organic-widgets-feature-list-select organic-widgets-repeatable-form-item-input" id="<?php echo $this->get_field_id( 'link_target' ); ?>-<?php echo $id; ?>" data-input-name="link_target" data-feature-id="<?php echo $id; ?>">
								<option data-value="window-same" value="window-same" <?php selected( $repeatable['link_target'], 'window-same' ); ?>><?php esc_html_e( 'Same Window', 'organic-widgets-pro' ); ?></option>
								<option data-value="window-new" value="window-new" <?php selected( $repeatable['link_target'], 'window-new' ); ?>><?php esc_html_e( 'New Window', 'organic-widgets-pro' ); ?></option>
							</select>
						</label>
					</p>

				</div>

				<br />

				<div class="organic-widgets-clear"></div>

				<?php $this->echo_repeatable_form_item_actions(); ?>

			</div>

		</div>

		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}
		if ( isset( $new_instance['slide_style'] ) ) {
			$instance['slide_style'] = wp_strip_all_tags( $new_instance['slide_style'] );
		}
		if ( isset( $new_instance['slideshow_transition_style'] ) ) {
			$instance['slideshow_transition_style'] = $this->organic_widgets_sanitize_transition_style( wp_strip_all_tags( $new_instance['slideshow_transition_style'] ) );
		}
		if ( isset( $new_instance['slideshow_interval'] ) ) {
			$instance['slideshow_interval'] = $this->organic_widgets_sanitize_transition_interval( (int) wp_strip_all_tags( $new_instance['slideshow_interval'] ) );
		}
		if ( isset( $new_instance['repeatable_array'] ) ) {
			$instance['repeatable_array'] = $new_instance['repeatable_array'];
		}

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		/*--- END Font Options ----*/

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		/*--- END Background ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['alignment'] ) ) {
			$instance['alignment'] = wp_strip_all_tags( $new_instance['alignment'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		/*--- END Layout ----*/

		return $instance;
	}

	/**
	 * Enqueue all the javascript.
	 */
	public function admin_setup() {

		wp_enqueue_media();

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );

		// Repeatable Form Items.
		if ( ! wp_script_is( 'organic-widgets-module-repeatable-form-item-js' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-repeatable-form-item-js', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-repeatable-form-items.js', array( 'jquery' ), '1.0', true );
		}

		// Content Aligner.
		if ( ! wp_script_is( 'organic-widgets-module-content-aligner' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-content-aligner', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-content-aligner.js', array( 'jquery' ), '1.0', true );
		}

		if ( ! wp_script_is( 'organic-widgets-module-image-background' ) ) {
			wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
			wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
				'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
				'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
			) );
		}
		if ( ! wp_script_is( 'organic-widgets-module-repeatable-slide-image' ) ) {
			wp_enqueue_script( 'organic-widgets-module-repeatable-slide-image', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-repeatable-slide-image.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
			wp_localize_script( 'organic-widgets-module-repeatable-slide-image', 'RepeatableImage', array(
				'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
				'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
			) );
		}

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_script( 'organic-widgets-flexslider', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.flexslider.js', array( 'jquery' ), '2.7.1', true );
		wp_enqueue_script( 'organic-widgets-flexslider-initialize', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/flexslider-setup.js', array( 'jquery', 'organic-widgets-flexslider' ), '1.0', true );

	}

} // class Organic_Widgets_Pro_Image_Slideshow_Widget
