<?php
/**
 * Registers a widget to show a search section.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Search_Widget widget.
 */
class Organic_Widgets_Pro_Search_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_search_section', // Base ID.
			__( 'Organic Search', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'A custom search section.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'video'     => true,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'          => true,
			'title_font'             => true,
			'title_color'            => true,
			'title_weight'           => true,
			'title_spacing'          => true,
			'title_size'             => true,
			'content_heading_font'   => false,
			'content_heading_size'   => false,
			'content_heading_weight' => false,
			'body_font'              => true,
			'text_alignment'         => false,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner'     => true,
			'content_orientation' => false,
			'padding_top'         => true,
			'padding_bottom'      => true,
			'custom_height'       => true,
			'custom_width'        => true,
			'content_width'       => true,
			'full_height'         => true,
		);

		// Admin Scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_setup' ) );
		add_action( 'admin_footer-widgets.php', array( $this, 'render_control_template_scripts' ) );

		// Public scripts.
		add_action( 'init', array( $this, 'public_scripts' ) );

	}
	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$post_type_select = ( isset( $instance['post_type_select'] ) ) ? $instance['post_type_select'] : 'all';
		$placeholder_text = ( isset( $instance['placeholder_text'] ) && '' !== $instance['placeholder_text'] ) ? $instance['placeholder_text'] : false;
		$button_text      = ( isset( $instance['button_text'] ) && '' !== $instance['button_text'] ) ? $instance['button_text'] : false;
		$search_style     = ( isset( $instance['search_style'] ) ) ? $instance['search_style'] : 'style-search-default';
		$bg_image_id      = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image         = ( isset( $instance['bg_image'] ) && '' !== $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color         = ( isset( $instance['bg_color'] ) && '' !== $instance['bg_color'] ) ? $instance['bg_color'] : false;
		$bg_video         = ( isset( $instance['bg_video'] ) && $instance['bg_video'] ) ? $instance['bg_video'] : false;

		if ( isset( $instance['button_display'] ) ) {
			$button_display = $instance['button_display'];
		} else {
			$button_display = false;
		}
		if ( isset( $instance['full_window_height'] ) ) {
			$full_window_height = $instance['full_window_height'];
		} else {
			$full_window_height = false;
		}
		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}

		echo $args['before_widget'];

		?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_max_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content {
					max-width: <?php echo absint( $instance['content_max_width'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) || '' !== $instance['widget_padding_top'] || '' !== $instance['widget_padding_bottom'] ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-search-section {
					<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
					min-height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_top'] ) { ?>
					padding-top: <?php echo intval( $instance['widget_padding_top'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_bottom'] ) { ?>
					padding-bottom: <?php echo intval( $instance['widget_padding_bottom'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['body_font_family'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content p {
					font-family: <?php echo esc_html( $instance['body_font_family'] ); ?>;
				}
			<?php } ?>
			<?php if ( '1' == $button_display ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-search-form #searchform #s {
					width: 100%;
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<?php /** BEGIN .organic-widgets-section */ ?>
		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>
			id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"
		<?php } ?>
			class="organic-widgets-section organic-widgets-search-section organic-widgets-video-bg-section
		<?php if ( $bg_image_fixed ) echo 'organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo 'organic-widgets-repeat-bg-img'; ?>
		<?php if ( $full_window_height ) echo 'organic-widgets-full-height-section'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>
			style="background-image:url(<?php echo esc_url( $bg_image ); ?>);"
		<?php } if ( $bg_color ) { ?>
			style="background-color:<?php echo esc_attr( $bg_color ); ?>;"
		<?php } ?>>

			<?php
			// Video Background Section.
			if ( $bg_video ) {

				// Prep arguments.
				$video_info = array(
					'video'           => $bg_video,
					'video_type'      => $this->get_video_type( $bg_video ),
					'video_id'        => $this->youtube_id_from_url( $bg_video ),
					'widget_id'       => $this->id,
					'clean_widget_id' => $this->sanitize_js_variable( $this->id ),
				);

				// Add video bg to global var.
				$this->add_video_bg( $video_info );

				// Output video HTML.
				$this->video_bg_html( $video_info );

			}

			?>

				<?php /** BEGIN .organic-widgets-content */ ?>
				<div class="organic-widgets-content">

					<?php /** BEGIN .organic-widgets-aligner */ ?>
					<div class="organic-widgets-aligner <?php if ( ! empty( $instance['alignment'] ) ) { echo 'organic-widgets-aligner-' . esc_attr( $instance['alignment'] ); } else { echo 'organic-widgets-aligner-middle-center'; } ?>">

						<?php /** BEGIN .organic-widgets-search-information */ ?>
						<div class="organic-widgets-search-information">

							<?php if ( ! empty( $instance['title'] ) ) { ?>
								<<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?> class="organic-widgets-title"><?php echo wp_kses_post( apply_filters( 'organic_widget_title', $instance['title'] ) ); ?></<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?>>
							<?php } ?>

							<?php if ( ! empty( $instance['text'] ) ) { ?>
								<div class="organic-widgets-text"><?php echo wp_kses_post( apply_filters( 'the_content', $instance['text'] ) ); ?></div>
							<?php } ?>

						<?php /** END .organic-widgets-search-information */ ?>
						</div>

						<?php /** BEGIN .organic-widgets-search-form */ ?>
						<div class="organic-widgets-search-form <?php echo esc_html( $search_style ); ?>">

							<form method="get" id="searchform" class="clearfix" action="<?php echo esc_url( home_url( '/' ) ); ?>" role="search">

								<label for="s" class="screen-reader-text"><?php esc_html_e( 'Search', 'organic-widgets-pro' ); ?></label>
								<input type="text" class="field" name="s" value="<?php echo get_search_query(); ?>" id="s" placeholder="<?php if ( ! empty( $placeholder_text ) ) { echo esc_html( $placeholder_text ); } else { esc_html_e( 'Search &hellip;', 'organic-widgets-pro' ); } ?>" />

								<input type="hidden" value="1" name="sentence" />

								<?php if ( 'all' !== $post_type_select && ! empty( $post_type_select ) ) { ?>
									<input type="hidden" value="<?php echo esc_html( $post_type_select ); ?>" name="post_type" />
								<?php } ?>

								<?php if ( '1' != $button_display ) { ?>
									<input type="submit" class="submit" name="submit" id="searchsubmit" value="<?php if ( ! empty( $button_text ) ) { echo esc_html_e( $button_text, 'organic-widgets-pro' ); } else { esc_html_e( 'Search', 'organic-widgets-pro' ); } ?>" />
								<?php } ?>

							</form>

						<?php /** END .organic-widgets-search-form */ ?>
						</div>

					<?php /** END .organic-widgets-aligner */ ?>
					</div>

				<?php /** END .organic-widgets-content */ ?>
				</div>

			<?php /** END .organic-widgets-section */ ?>
			</div>

			<?php

			if ( is_active_widget( false, false, $this->id_base, true ) ) {
				wp_enqueue_script( 'yt-player-api', 'https://www.youtube.com/player_api', array(), '1.0', true );
			}

			echo $args['after_widget'];

	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'text'  => '',
			)
		);

		// Setup Variables.
		$this->id_prefix = $this->get_field_id( '' );

		if ( isset( $instance['post_type_select'] ) ) {
			$post_type_select = $instance['post_type_select'];
		} else {
			$post_type_select = 'all';
		}

		if ( isset( $instance['search_style'] ) ) {
			$search_style = $instance['search_style'];
		} else {
			$search_style = 'style-search-default';
		}

		if ( isset( $instance['placeholder_text'] ) ) {
			$placeholder_text = $instance['placeholder_text'];
		} else {
			$placeholder_text = false;
		}

		if ( isset( $instance['button_text'] ) ) {
			$button_text = $instance['button_text'];
		} else {
			$button_text = false;
		}

		if ( isset( $instance['button_display'] ) ) {
			$button_display = $instance['button_display'];
		} else {
			$button_display = false;
		}

		?>

		<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" class="title" type="hidden" value="<?php echo esc_attr( $instance['title'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" class="text organic-widgets-wysiwyg-anchor" type="hidden" value="<?php echo esc_attr( $instance['text'] ); ?>">
		<input id="<?php echo $this->get_field_id( 'filter' ); ?>" name="<?php echo $this->get_field_name( 'filter' ); ?>" class="filter" type="hidden" value="on">
		<input id="<?php echo $this->get_field_id( 'visual' ); ?>" name="<?php echo $this->get_field_name( 'visual' ); ?>" class="visual" type="hidden" value="on">

		<p>
			<label for="<?php echo $this->get_field_id( 'post_type_select' ); ?>"><?php esc_html_e( 'Search Within Post Type:', 'organic-widgets-pro' ); ?>
				<select id="<?php echo $this->get_field_id( 'post_type_select' ); ?>" name="<?php echo $this->get_field_name( 'post_type_select' ); ?>">
					<option value="all" <?php if ( 'all' === $post_type_select || empty( $post_type_select ) ) { ?>selected="selected"<?php } ?>>
						<?php esc_html_e( 'All Post Types', 'organic-widgets-pro' ); ?>
					</option>
					<?php
					$args       = array(
						'public' => true,
					);
					$post_types = get_post_types( $args, 'objects' );
					?>
					<?php foreach ( $post_types as $post_type ) : ?>
						<?php
						$selected_state = $post_type_select === $post_type->name ? ' selected="selected" ' : '';
						if ( $post_type_select === $post_type->name ) {
							$selected = ' selected';
						} else {
							$selected = '';
						}
						?>
						<option value="<?php echo esc_attr( $post_type->name ); echo esc_attr( $selected ); ?>"
							<?php echo esc_attr( $selected_state ); ?>>
							<?php echo esc_html( $post_type->label ); ?>
						</option>
					<?php endforeach; ?>
				</select>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'search_style' ); ?>"><?php esc_html_e( 'Search Form Style:', 'organic-widgets-pro' ); ?>
				<select id="<?php echo $this->get_field_id( 'search_style' ); ?>" name="<?php echo $this->get_field_name( 'search_style' ); ?>">
					<option value="style-search-default" <?php echo ( 'style-search-default' === $search_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Theme Default', 'organic-widgets-pro' ); ?></option>
					<option value="style-search-modern" <?php echo ( 'style-search-modern' === $search_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Modern', 'organic-widgets-pro' ); ?></option>
					<option value="style-search-bordered" <?php echo ( 'style-search-bordered' === $search_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Bordered', 'organic-widgets-pro' ); ?></option>
					<option value="style-search-dark" <?php echo ( 'style-search-dark' === $search_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Dark', 'organic-widgets-pro' ); ?></option>
					<option value="style-search-large" <?php echo ( 'style-search-large' === $search_style ) ? 'selected' : ''; ?>><?php esc_html_e( 'Large', 'organic-widgets-pro' ); ?></option>
				</select>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'placeholder_text' ); ?>"><?php esc_html_e( 'Search Placeholder Text:', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'placeholder_text' ); ?>" name="<?php echo $this->get_field_name( 'placeholder_text' ); ?>" value="<?php echo esc_html( $placeholder_text ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'button_text' ); ?>"><?php esc_html_e( 'Search Button Text:', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'button_text' ); ?>" name="<?php echo $this->get_field_name( 'button_text' ); ?>" value="<?php echo esc_html( $button_text ); ?>" />
		</p>

		<p style="margin-top: 16px;">
			<input class="checkbox" type="checkbox" value="1" <?php checked( $button_display, '1' ); ?> id="<?php echo $this->get_field_id( 'button_display' ); ?>" name="<?php echo $this->get_field_name( 'button_display' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'button_display' ); ?>"><?php esc_html_e( 'Hide Search Button', 'organic-widgets-pro' ); ?></label>
		</p>

		<br />

		<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

		<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

		<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php _e( 'Custom Widget Class', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
		</p>

		<p class="organic-widgets-input">
			<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
		</p>

		<?php

	}

	/**
	 * Render form template scripts.
	 *
	 * @access public
	 */
	public function render_control_template_scripts() {

		?>
		<script type="text/html" id="tmpl-widget-organic_widgets_search_section-control-fields">

			<# var elementIdPrefix = 'el' + String( Math.random() ).replace( /\D/g, '' ) + '_' #>

			<p>
				<label for="{{ elementIdPrefix }}title"><?php esc_html_e( 'Title:' ); ?></label>
				<input id="{{ elementIdPrefix }}title" type="text" class="widefat title">
			</p>
			<p>
				<label for="{{ elementIdPrefix }}text" class="screen-reader-text"><?php esc_html_e( 'Content:' ); ?></label>
				<textarea id="{{ elementIdPrefix }}text" class="widefat text" style="height: 200px" rows="16" cols="20"></textarea>
			</p>
		</script>
		<?php

	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}

		/*--- Text/Title ----*/
		if ( ! isset( $newinstance['filter'] ) ) {
			$instance['filter'] = false;
		}
		if ( ! isset( $newinstance['visual'] ) ) {
			$instance['visual'] = null;
		}
		// Upgrade 4.8.0 format.
		if ( isset( $old_instance['filter'] ) && 'content' === $old_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( 'content' === $new_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( isset( $new_instance['visual'] ) ) {
			$instance['visual'] = ! empty( $new_instance['visual'] );
		}
		// Filter is always true in visual mode.
		if ( ! empty( $instance['visual'] ) ) {
			$instance['filter'] = true;
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance['title'] = $new_instance['title'];
			$instance['text']  = $new_instance['text'];
		} else {
			$instance['title'] = wp_kses_post( $new_instance['title'] );
			$instance['text']  = wp_kses_post( $new_instance['text'] );
		}
		/*--- END Text/Title ----*/

		/*--- Unique Options ----*/
		if ( isset( $new_instance['post_type_select'] ) ) {
			$instance['post_type_select'] = wp_strip_all_tags( $new_instance['post_type_select'] );
		}
		if ( isset( $new_instance['search_style'] ) ) {
			$instance['search_style'] = wp_strip_all_tags( $new_instance['search_style'] );
		}
		if ( isset( $new_instance['placeholder_text'] ) ) {
			$instance['placeholder_text'] = wp_strip_all_tags( $new_instance['placeholder_text'] );
		}
		if ( isset( $new_instance['button_text'] ) ) {
			$instance['button_text'] = wp_strip_all_tags( $new_instance['button_text'] );
		}
		if ( isset( $new_instance['button_display'] ) ) {
			$instance['button_display'] = true;
		} else {
			$instance['button_display'] = false;
		}
		/*--- END Unique Options ----*/

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_video'] ) && $this->check_video_url( $new_instance['bg_video'] ) ) {
			$instance['bg_video'] = wp_strip_all_tags( $new_instance['bg_video'] );
		} else {
			$instance['bg_video'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		/*--- END Background ----*/

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = wp_strip_all_tags( $new_instance['title_text_heading'] );
		}
		if ( isset( $new_instance['title_text_color'] ) ) {
			$instance['title_text_color'] = wp_strip_all_tags( $new_instance['title_text_color'] );
		}
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		if ( isset( $new_instance['body_font_family'] ) ) {
			$instance['body_font_family'] = wp_strip_all_tags( $new_instance['body_font_family'] );
		}
		/*--- END Font Options ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['alignment'] ) ) {
			$instance['alignment'] = wp_strip_all_tags( $new_instance['alignment'] );
		}
		if ( isset( $new_instance['widget_padding_top'] ) ) {
			$instance['widget_padding_top'] = wp_strip_all_tags( $new_instance['widget_padding_top'] );
		}
		if ( isset( $new_instance['widget_padding_bottom'] ) ) {
			$instance['widget_padding_bottom'] = wp_strip_all_tags( $new_instance['widget_padding_bottom'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['content_max_width'] ) ) {
			$instance['content_max_width'] = wp_strip_all_tags( $new_instance['content_max_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		if ( isset( $new_instance['full_window_height'] ) ) {
			$instance['full_window_height'] = true;
		} else {
			$instance['full_window_height'] = false;
		}
		/*--- END Layout ----*/

		return $instance;
	}

	/**
	 * Enqueue all the javascript.
	 */
	public function admin_setup() {

		// Text Editor.
		wp_enqueue_editor();
		wp_enqueue_script( 'organic-widgets-search-text-title', plugin_dir_url( __FILE__ ) . 'js/search-widgets.js', array( 'jquery', 'wp-embed', 'underscore' ), '1.0', true );
		wp_localize_script( 'organic-widgets-search-text-title', 'OrganicSearchWidget', array(
			'id_base' => $this->id_base,
		) );
		wp_add_inline_script( 'organic-widgets-search-text-title', 'wp.organicSearchWidget.init();', 'after' );

		// Content Aligner.
		if ( ! wp_script_is( 'organic-widgets-module-content-aligner' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-content-aligner', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-content-aligner.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_media();

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );

		wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
		wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
			'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
			'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
		) );

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ), '1.0', true );
		}

	}

} // class Organic_Widgets_Pro_Search_Widget
