<?php
/**
 * Registers a widget to display tabbed or toggle sections.
 *
 * @package Organic Widgets Pro
 */

// Block direct requests.
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Adds Organic_Widgets_Pro_Toggle_Widget widget.
 */
class Organic_Widgets_Pro_Toggle_Widget extends Organic_Widgets_Pro_Custom_Widget {

	const CUSTOM_IMAGE_SIZE_SLUG = 'organic_widgets_image_upload';

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'organic_widgets_toggle_section', // Base ID.
			__( 'Organic Tabs & Toggles', 'organic-widgets-pro' ), // Name.
			array(
				'description'                 => __( 'Display tabbed or toggle content.', 'organic-widgets-pro' ),
				'customize_selective_refresh' => true,
			)
		);

		$this->id_prefix = $this->get_field_id( '' );

		// BG options.
		$this->bg_options = array(
			'color'     => true,
			'image'     => true,
			'bg_fixed'  => true,
			'bg_repeat' => true,
			'video'     => false,
		);

		// Font options.
		$this->font_options = array(
			'title_heading'          => true,
			'title_font'             => true,
			'title_color'            => true,
			'title_weight'           => true,
			'title_spacing'          => true,
			'title_size'             => true,
			'content_heading_font'   => false,
			'content_heading_size'   => false,
			'content_heading_weight' => false,
			'body_font'              => true,
		);

		// Layout options.
		$this->layout_options = array(
			'content_aligner'     => true,
			'content_orientation' => false,
			'padding_top'         => true,
			'padding_bottom'      => true,
			'custom_height'       => true,
			'custom_width'        => true,
			'content_width'       => true,
			'full_height'         => false,
		);

		// Display options.
		$this->display_options = array(
			'hide_title'   => false,
			'hide_meta'    => false,
			'hide_content' => false,
			'hide_bg'      => false,
		);

		// Admin Scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_setup' ) );
		add_action( 'admin_footer-widgets.php', array( $this, 'render_control_template_scripts' ) );

		// Public scripts.
		if ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'public_scripts' ) );
		}

	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		$toggle_type      = ( isset( $instance['toggle_type'] ) ) ? $instance['toggle_type'] : 'type-toggle';
		$toggle_style     = ( isset( $instance['toggle_style'] ) ) ? $instance['toggle_style'] : 'style-toggle-bordered';
		$toggle_icon      = ( isset( $instance['toggle_icon'] ) ) ? $instance['toggle_icon'] : 'icon-default';
		$bg_image_id      = isset( $instance['bg_image_id'] ) ? $instance['bg_image_id'] : false;
		$bg_image         = ( isset( $instance['bg_image'] ) && '' !== $instance['bg_image'] ) ? $instance['bg_image'] : false;
		$bg_color         = ( isset( $instance['bg_color'] ) && '' !== $instance['bg_color'] ) ? $instance['bg_color'] : false;
		$repeatable_array = ( isset( $instance['repeatable_array'] ) ) ? json_decode( $instance['repeatable_array'], true ) : array();

		// Register BG Fixed Image Option.
		if ( isset( $instance['bg_image_fixed'] ) ) {
			$bg_image_fixed = $instance['bg_image_fixed'];
		} else {
			$bg_image_fixed = false;
		}
		// Register BG Repeat Option.
		if ( isset( $instance['bg_image_repeat'] ) ) {
			$bg_image_repeat = $instance['bg_image_repeat'];
		} else {
			$bg_image_repeat = false;
		}

		echo $args['before_widget'];

		?>

		<?php echo '<style media="screen">'; ?>
			<?php if ( ! empty( $instance['widget_custom_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> {
					width: <?php echo absint( $instance['widget_custom_width'] ); ?>%;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['content_max_width'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-content {
					max-width: <?php echo absint( $instance['content_max_width'] ); ?>px;
				}
			<?php } ?>
			<?php if ( ! empty( $instance['widget_custom_height'] ) || '' !== $instance['widget_padding_top'] || '' !== $instance['widget_padding_bottom'] ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-toggle-section {
					<?php if ( ! empty( $instance['widget_custom_height'] ) ) { ?>
					min-height: <?php echo absint( $instance['widget_custom_height'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_top'] ) { ?>
					padding-top: <?php echo absint( $instance['widget_padding_top'] ); ?>px;
					<?php } ?>
					<?php if ( '' !== $instance['widget_padding_bottom'] ) { ?>
					padding-bottom: <?php echo absint( $instance['widget_padding_bottom'] ); ?>px;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['title_font_family'] ) || ! empty( $instance['title_font_weight'] ) || ! empty( $instance['title_font_size'] ) || ! empty( $instance['title_letter_spacing'] ) || ! empty( $instance['title_text_color'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-title {
					<?php if ( ! empty( $instance['title_font_family'] ) ) { ?>
					font-family: <?php echo esc_html( $instance['title_font_family'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_weight'] ) ) { ?>
					font-weight: <?php echo esc_html( $instance['title_font_weight'] ); ?>;
					<?php } ?>
					<?php if ( ! empty( $instance['title_font_size'] ) ) { ?>
					font-size: <?php echo esc_html( $instance['title_font_size'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_letter_spacing'] ) ) { ?>
					letter-spacing: <?php echo esc_html( $instance['title_letter_spacing'] ); ?>px;
					<?php } ?>
					<?php if ( ! empty( $instance['title_text_color'] ) ) { ?>
					color: <?php echo esc_html( $instance['title_text_color'] ); ?>;
					<?php } ?>
				}
			<?php } ?>
			<?php if ( ! empty( $instance['body_font_family'] ) ) { ?>
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-text,
				#<?php echo esc_attr( $this->id ); ?> .organic-widgets-toggle-table table {
					font-family: <?php echo esc_html( $instance['body_font_family'] ); ?>;
				}
			<?php } ?>
		<?php echo '</style>'; ?>

		<?php /** BEGIN .organic-widgets-section */ ?>
		<div <?php if ( ! empty( $instance['widget_custom_anchor'] ) ) { ?>id="<?php echo esc_html( $instance['widget_custom_anchor'] ); ?>"<?php } ?>
		class="organic-widgets-section organic-widgets-toggle-section
		<?php if ( $bg_image_fixed ) echo 'organic-widgets-fixed-bg-img'; ?>
		<?php if ( $bg_image_repeat ) echo 'organic-widgets-repeat-bg-img'; ?>
		<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo esc_html( $instance['widget_custom_class'] ); ?>"
		<?php if ( 0 < $bg_image_id ) { ?>
			style="background-image:url(<?php echo esc_url( $bg_image ); ?>);"
		<?php } if ( $bg_color ) { ?>
			style="background-color:<?php echo esc_attr( $bg_color ); ?>;"
		<?php } ?>>

			<?php /** BEGIN .organic-widgets-content */ ?>
			<div class="organic-widgets-content">

				<?php /** BEGIN .organic-widgets-aligner */ ?>
				<div class="organic-widgets-aligner <?php if ( ! empty( $instance['alignment'] ) ) { echo 'organic-widgets-aligner-' . esc_attr( $instance['alignment'] ); } else { echo 'organic-widgets-aligner-middle-center'; } ?>">

					<?php /** BEGIN .organic-widgets-toggle-information */ ?>
					<div class="organic-widgets-toggle-information">

						<?php if ( ! empty( $instance['title'] ) ) { ?>
							<<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?> class="organic-widgets-title"><?php echo wp_kses_post( apply_filters( 'organic_widget_title', $instance['title'] ) ); ?></<?php if ( ! empty( $instance['title_text_heading'] ) ) { echo $instance['title_text_heading']; } else { ?>h2<?php } ?>>
						<?php } ?>

						<?php if ( ! empty( $instance['text'] ) ) { ?>
							<div class="organic-widgets-text"><?php echo wp_kses_post( apply_filters( 'the_content', $instance['text'] ) ); ?></div>
						<?php } ?>

					<?php /** END .organic-widgets-toggle-information */ ?>
					</div>

					<?php /** BEGIN .organic-widgets-toggles */ ?>
					<?php if ( 'type-toggle' === $toggle_type ) { ?>
					<div class="organic-widgets-toggles <?php echo esc_html( $toggle_style ); ?> <?php echo esc_html( $toggle_icon ); ?>">

						<?php
						if ( is_array( $repeatable_array ) && count( $repeatable_array ) ) {
							$incrementer = 0;
							usort( $repeatable_array, array( $this, 'sort_by_order' ) );
							foreach ( $repeatable_array as $key => $repeatable ) {
								$incrementer++;
								?>

								<div class="organic-widgets-toggle-box">
									<?php if ( array_key_exists( 'toggle_title', $repeatable ) && ! empty( $repeatable['toggle_title'] ) ) { ?>
										<p id="organic-toggle-<?php echo esc_html( $incrementer ); ?>" class="organic-widgets-trigger">
											<a href="javascript:void(0);"><?php echo wp_kses_post( $repeatable['toggle_title'] ); ?></a>
										</p>
									<?php } ?>
									<?php if ( array_key_exists( 'toggle_description', $repeatable ) && ! empty( $repeatable['toggle_description'] ) ) { ?>
										<div id="organic-toggle-content-<?php echo esc_html( $incrementer ); ?>" class="organic-widgets-toggle-content organic-widgets-card">
											<?php echo wp_kses_post( $repeatable['toggle_description'] ); ?>
										</div>
									<?php } ?>
								</div>

							<?php } ?>
						<?php } ?>

					<?php } elseif ( 'type-accordion' === $toggle_type ) { ?>
					<div class="organic-widgets-accordion organic-widgets-card <?php echo esc_html( $toggle_style ); ?> <?php echo esc_html( $toggle_icon ); ?>">

						<?php
						if ( is_array( $repeatable_array ) && count( $repeatable_array ) ) {
							$incrementer = 0;
							usort( $repeatable_array, array( $this, 'sort_by_order' ) );
							foreach ( $repeatable_array as $key => $repeatable ) {
								$incrementer++;
								?>

								<?php if ( array_key_exists( 'toggle_title', $repeatable ) && ! empty( $repeatable['toggle_title'] ) ) { ?>
									<p class="organic-widgets-trigger">
										<a href="javascript:void(0);"><?php echo wp_kses_post( $repeatable['toggle_title'] ); ?></a>
									</p>
								<?php } ?>

								<?php if ( array_key_exists( 'toggle_description', $repeatable ) && ! empty( $repeatable['toggle_description'] ) ) { ?>
									<div id="organic-toggle-<?php echo esc_html( $incrementer ); ?>" class="organic-widgets-toggle-content">
										<?php echo wp_kses_post( $repeatable['toggle_description'] ); ?>
									</div>
								<?php } ?>

							<?php } ?>
						<?php } ?>

					<?php } elseif ( 'type-tab' === $toggle_type ) { ?>
					<div class="organic-widgets-tabs <?php echo esc_html( $toggle_style ); ?> <?php echo esc_html( $toggle_icon ); ?>">

						<ul>
						<?php
						if ( is_array( $repeatable_array ) && count( $repeatable_array ) ) {
							$incrementer = 0;
							usort( $repeatable_array, array( $this, 'sort_by_order' ) );
							foreach ( $repeatable_array as $key => $repeatable ) {
								$incrementer++;
								?>

								<?php if ( array_key_exists( 'toggle_title', $repeatable ) && ! empty( $repeatable['toggle_title'] ) ) { ?>
									<li class="organic-widgets-tab">
										<a href="#organic-tab-<?php echo esc_html( $incrementer ); ?>"><?php echo wp_kses_post( $repeatable['toggle_title'] ); ?></a>
									</li>
								<?php } ?>

							<?php } ?>
						</ul>

							<?php
							unset( $incrementer );
							foreach ( $repeatable_array as $key => $repeatable ) {
								$incrementer++;
								?>

								<?php if ( array_key_exists( 'toggle_description', $repeatable ) && ! empty( $repeatable['toggle_description'] ) ) { ?>
									<div id="organic-tab-<?php echo esc_html( $incrementer ); ?>" class="organic-widgets-toggle-content organic-widgets-card">
										<?php echo wp_kses_post( $repeatable['toggle_description'] ); ?>
									</div>
								<?php } ?>

							<?php } ?>
						<?php } ?>

					<?php } ?>

					<?php /** END .organic-widgets-toggles */ ?>
					</div>

				<?php /** END .organic-widgets-content */ ?>
				</div>

			<?php /** END .organic-widgets-section */ ?>
			</div>

		<?php /** END .organic-widgets-aligner */ ?>
		</div>

		<?php

		echo $args['after_widget'];

	} // End widget()

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'text'  => '',
			)
		);

		// Setup Variables.
		$this->id_prefix = $this->get_field_id( '' );

		if ( isset( $instance['toggle_type'] ) ) {
			$toggle_type = $instance['toggle_type'];
		} else {
			$toggle_type = 'type-toggle';
		}
		if ( isset( $instance['toggle_style'] ) ) {
			$toggle_style = $instance['toggle_style'];
		} else {
			$toggle_style = 'style-toggle-bordered';
		}
		if ( isset( $instance['toggle_icon'] ) ) {
			$toggle_icon = $instance['toggle_icon'];
		} else {
			$toggle_icon = 'icon-default';
		}
		if ( isset( $instance['repeatable_array'] ) ) {
			$repeatable_array = json_decode( $instance['repeatable_array'], true );
		} else {
			$repeatable_array = array();
		}

		?>

		<div class="organic-widgets-repeatable-form-item-widget-admin">

			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" class="title" type="hidden" value="<?php echo esc_attr( $instance['title'] ); ?>">
			<input id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" class="text organic-widgets-wysiwyg-anchor" type="hidden" value="<?php echo esc_attr( $instance['text'] ); ?>">
			<input id="<?php echo $this->get_field_id( 'filter' ); ?>" name="<?php echo $this->get_field_name( 'filter' ); ?>" class="filter" type="hidden" value="on">
			<input id="<?php echo $this->get_field_id( 'visual' ); ?>" name="<?php echo $this->get_field_name( 'visual' ); ?>" class="visual" type="hidden" value="on">

			<p>
				<label for="<?php echo $this->get_field_id( 'toggle_type' ); ?>"><?php _e( 'Toggle Type:', 'organic-widgets-pro' ); ?>
					<select id="<?php echo $this->get_field_id( 'toggle_type' ); ?>" name="<?php echo $this->get_field_name( 'toggle_type' ); ?>">
						<option value="type-toggle" <?php echo ( 'type-toggle' === $toggle_type ) ? 'selected' : ''; ?>><?php _e( 'Toggle', 'organic-widgets-pro' ); ?></option>
						<option value="type-accordion" <?php echo ( 'type-accordion' === $toggle_type ) ? 'selected' : ''; ?>><?php _e( 'Accordion', 'organic-widgets-pro' ); ?></option>
						<option value="type-tab" <?php echo ( 'type-tab' === $toggle_type ) ? 'selected' : ''; ?>><?php _e( 'Tabs', 'organic-widgets-pro' ); ?></option>
					</select>
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'toggle_style' ); ?>"><?php _e( 'Toggle Style:', 'organic-widgets-pro' ); ?>
					<select id="<?php echo $this->get_field_id( 'toggle_style' ); ?>" name="<?php echo $this->get_field_name( 'toggle_style' ); ?>">
						<option value="style-toggle-bordered" <?php echo ( 'style-toggle-bordered' === $toggle_style ) ? 'selected' : ''; ?>><?php _e( 'Bordered', 'organic-widgets-pro' ); ?></option>
						<option value="style-toggle-modern" <?php echo ( 'style-toggle-modern' === $toggle_style ) ? 'selected' : ''; ?>><?php _e( 'Modern', 'organic-widgets-pro' ); ?></option>
						<option value="style-toggle-dark" <?php echo ( 'style-toggle-dark' === $toggle_style ) ? 'selected' : ''; ?>><?php _e( 'Dark', 'organic-widgets-pro' ); ?></option>
						<option value="style-toggle-minimal" <?php echo ( 'style-toggle-minimal' === $toggle_style ) ? 'selected' : ''; ?>><?php _e( 'Minimal', 'organic-widgets-pro' ); ?></option>
					</select>
				</label>
			</p>

			<label for="<?php echo $this->get_field_id( 'toggle_icon' ); ?>"><?php esc_html_e( 'Toggle Icon:', 'organic-widgets-pro' ); ?></label>
			<div class="toggle-icon-options">
				<p>
					<input type="radio" value="icon-default" id="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-default" name="<?php echo $this->get_field_name( 'toggle_icon' ); ?>" <?php if ( 'icon-default' === $toggle_icon ) { ?>checked="yes"<?php } ?> />
					<label for="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-default"><i class="fa fa-plus"></i></label>
					<input type="radio" value="icon-circle" id="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-circle" name="<?php echo $this->get_field_name( 'toggle_icon' ); ?>" <?php if ( 'icon-circle' === $toggle_icon ) { ?>checked="yes"<?php } ?> />
					<label for="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-circle"><i class="fa fa-plus-circle"></i></label>
					<input type="radio" value="icon-arrow" id="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-arrow" name="<?php echo $this->get_field_name( 'toggle_icon' ); ?>" <?php if ( 'icon-arrow' === $toggle_icon ) { ?>checked="yes"<?php } ?> />
					<label for="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-arrow"><i class="fa fa-angle-down"></i></label>
					<input type="radio" value="icon-caret" id="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-caret" name="<?php echo $this->get_field_name( 'toggle_icon' ); ?>" <?php if ( 'icon-caret' === $toggle_icon ) { ?>checked="yes"<?php } ?> />
					<label for="<?php echo $this->get_field_id( 'toggle_icon' ); ?>-caret"><i class="fa fa-caret-down"></i></label>
				</p>
			</div>

			<br />

			<?php $this->section_font_input_markup( $instance, $this->font_options ); ?>

			<?php $this->section_layout_input_markup( $instance, $this->layout_options ); ?>

			<?php $this->section_background_input_markup( $instance, $this->bg_options ); ?>

			<?php $this->repeatable_form_item_inputs_markup( $repeatable_array, 'Toggle Items' ); ?>

			<p class="organic-widgets-input">
				<label for="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>"><?php esc_html_e( 'Custom Widget Class', 'organic-widgets-pro' ); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_class' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_class' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_class'] ) ) echo $instance['widget_custom_class']; ?>" />
			</p>

			<p class="organic-widgets-input">
				<label for="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>"><?php _e( 'Custom Widget Anchor', 'organic-widgets-pro' ); ?></label>
				<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_custom_anchor' ); ?>" name="<?php echo $this->get_field_name( 'widget_custom_anchor' ); ?>" value="<?php if ( ! empty( $instance['widget_custom_anchor'] ) ) echo $instance['widget_custom_anchor']; ?>" />
			</p>

		</div>

		<?php

	}

	/**
	 * Ouput HTML for a Repeatable Table Item
	 *
	 * @access protected
	 */
	protected function echo_repeatable_form_item( $id = 'template', $order = 'template', $repeatable = false ) {

		if ( 'template' === $id || 'template' === $order ) {
			$template = true;
			$id       = '__x__';
			$order    = '';
		} else {
			$template = false;
			$id       = (int) $id;
			$order    = (int) $order;
		}
		?>

		<div class="<?php if ( $template ) { echo 'organic-widgets-repeatable-form-item-template'; } else { echo 'organic-widgets-repeatable-form-item'; } ?>" data-feature-id="<?php echo $id; ?>" data-order="<?php echo $order; ?>">

			<div class="organic-widgets-repeatable-form-item-title-bar">
				<?php esc_html_e( 'Toggle Item:', 'organic-widgets-pro' ) ?>
				<span class="organic-widgets-repeatable-item-number">
					<?php
					if ( is_numeric( $order ) ) {
						echo $order + 1;
					}
					?>
				</span>
			</div>

			<div class="organic-widgets-repeatable-form-item-fields-wrapper">

				<p>
					<label for="<?php echo $this->get_field_id( 'toggle_title' ); ?>"><?php esc_html_e( 'Title:', 'organic-widgets-pro' ) ?></label>
					<input class="widefat organic-widgets-repeatable-form-item-input" data-input-name="toggle_title" data-activator="true" type="text" value="<?php if ( $repeatable && array_key_exists( 'toggle_title', $repeatable ) ) { echo $repeatable['toggle_title']; } ?>" />
				</p>

				<p>
					<label for="<?php echo $this->get_field_id( 'toggle_description' ); ?>"><?php esc_html_e( 'Description:', 'organic-widgets-pro' ) ?></label>
					<textarea class="widefat organic-widgets-repeatable-form-item-input" data-input-name="toggle_description" data-activator="true" rows="4" cols="20" ><?php if ( $repeatable && array_key_exists( 'toggle_description', $repeatable ) ) { echo esc_html( $repeatable['toggle_description'] ); } ?></textarea>
				</p>

				<br />

				<div class="organic-widgets-clear"></div>

				<?php $this->echo_repeatable_form_item_actions(); ?>

			</div>

		</div>

		<?php
	}

	/**
	 * Render form template scripts.
	 *
	 * @access public
	 */
	public function render_control_template_scripts() {

		?>
		<script type="text/html" id="tmpl-widget-organic_widgets_toggle_section-control-fields">

			<# var elementIdPrefix = 'el' + String( Math.random() ).replace( /\D/g, '' ) + '_' #>

			<p>
				<label for="{{ elementIdPrefix }}title"><?php esc_html_e( 'Title:' ); ?></label>
				<input id="{{ elementIdPrefix }}title" type="text" class="widefat title">
			</p>
			<p>
				<label for="{{ elementIdPrefix }}text" class="screen-reader-text"><?php esc_html_e( 'Content:' ); ?></label>
				<textarea id="{{ elementIdPrefix }}text" class="widefat text" style="height: 200px" rows="16" cols="20"></textarea>
			</p>
		</script>
		<?php

	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		/*--- Text/Title ----*/
		if ( ! isset( $newinstance['filter'] ) ) {
			$instance['filter'] = false;
		}
		if ( ! isset( $newinstance['visual'] ) ) {
			$instance['visual'] = null;
		}
		// Upgrade 4.8.0 format.
		if ( isset( $old_instance['filter'] ) && 'content' === $old_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( 'content' === $new_instance['filter'] ) {
			$instance['visual'] = true;
		}
		if ( isset( $new_instance['visual'] ) ) {
			$instance['visual'] = ! empty( $new_instance['visual'] );
		}
		// Filter is always true in visual mode.
		if ( ! empty( $instance['visual'] ) ) {
			$instance['filter'] = true;
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance['title'] = $new_instance['title'];
			$instance['text']  = $new_instance['text'];
		} else {
			$instance['title'] = wp_kses_post( $new_instance['title'] );
			$instance['text']  = wp_kses_post( $new_instance['text'] );
		}
		/*--- END Text/Title ----*/

		if ( ! isset( $old_instance['created'] ) ) {
			$instance['created'] = time();
		}
		if ( isset( $new_instance['toggle_type'] ) ) {
			$instance['toggle_type'] = wp_strip_all_tags( $new_instance['toggle_type'] );
		}
		if ( isset( $new_instance['toggle_style'] ) ) {
			$instance['toggle_style'] = wp_strip_all_tags( $new_instance['toggle_style'] );
		}
		if ( isset( $new_instance['toggle_icon'] ) ) {
			$instance['toggle_icon'] = wp_strip_all_tags( $new_instance['toggle_icon'] );
		}
		if ( isset( $new_instance['repeatable_array'] ) ) {
			$instance['repeatable_array'] = $new_instance['repeatable_array'];
		}

		/*--- Background ----*/
		if ( isset( $new_instance['bg_image_id'] ) ) {
			$instance['bg_image_id'] = wp_strip_all_tags( $new_instance['bg_image_id'] );
		}
		if ( isset( $new_instance['bg_image'] ) ) {
			$instance['bg_image'] = wp_strip_all_tags( $new_instance['bg_image'] );
		}
		if ( isset( $new_instance['bg_image_fixed'] ) ) {
			$instance['bg_image_fixed'] = true;
		} else {
			$instance['bg_image_fixed'] = false;
		}
		if ( isset( $new_instance['bg_image_repeat'] ) ) {
			$instance['bg_image_repeat'] = true;
		} else {
			$instance['bg_image_repeat'] = false;
		}
		if ( isset( $new_instance['bg_color'] ) && $this->check_hex_color( $new_instance['bg_color'] ) ) {
			$instance['bg_color'] = wp_strip_all_tags( $new_instance['bg_color'] );
		} else {
			$instance['bg_color'] = false;
		}
		/*--- END Background ----*/

		/*--- Font Options ----*/
		if ( isset( $new_instance['title_text_heading'] ) ) {
			$instance['title_text_heading'] = wp_strip_all_tags( $new_instance['title_text_heading'] );
		}
		if ( isset( $new_instance['title_text_color'] ) ) {
			$instance['title_text_color'] = wp_strip_all_tags( $new_instance['title_text_color'] );
		}
		if ( isset( $new_instance['title_font_weight'] ) ) {
			$instance['title_font_weight'] = wp_strip_all_tags( $new_instance['title_font_weight'] );
		}
		if ( isset( $new_instance['title_font_size'] ) ) {
			$instance['title_font_size'] = wp_strip_all_tags( $new_instance['title_font_size'] );
		}
		if ( isset( $new_instance['title_letter_spacing'] ) ) {
			$instance['title_letter_spacing'] = wp_strip_all_tags( $new_instance['title_letter_spacing'] );
		}
		if ( isset( $new_instance['title_font_family'] ) ) {
			$instance['title_font_family'] = wp_strip_all_tags( $new_instance['title_font_family'] );
		}
		if ( isset( $new_instance['body_font_family'] ) ) {
			$instance['body_font_family'] = wp_strip_all_tags( $new_instance['body_font_family'] );
		}
		/*--- END Font Options ----*/

		/*--- Layout ----*/
		if ( isset( $new_instance['alignment'] ) ) {
			$instance['alignment'] = wp_strip_all_tags( $new_instance['alignment'] );
		}
		if ( isset( $new_instance['widget_padding_top'] ) ) {
			$instance['widget_padding_top'] = wp_strip_all_tags( $new_instance['widget_padding_top'] );
		}
		if ( isset( $new_instance['widget_padding_bottom'] ) ) {
			$instance['widget_padding_bottom'] = wp_strip_all_tags( $new_instance['widget_padding_bottom'] );
		}
		if ( isset( $new_instance['widget_custom_height'] ) ) {
			$instance['widget_custom_height'] = wp_strip_all_tags( $new_instance['widget_custom_height'] );
		}
		if ( isset( $new_instance['widget_custom_width'] ) ) {
			$instance['widget_custom_width'] = wp_strip_all_tags( $new_instance['widget_custom_width'] );
		}
		if ( isset( $new_instance['content_max_width'] ) ) {
			$instance['content_max_width'] = wp_strip_all_tags( $new_instance['content_max_width'] );
		}
		if ( isset( $new_instance['widget_custom_class'] ) ) {
			$instance['widget_custom_class'] = wp_strip_all_tags( $new_instance['widget_custom_class'] );
		}
		if ( isset( $new_instance['widget_custom_anchor'] ) ) {
			$instance['widget_custom_anchor'] = wp_strip_all_tags( $new_instance['widget_custom_anchor'] );
		}
		/*--- END Layout ----*/

		return $instance;

	}

	/**
	 * Enqueue all the javascript.
	 */
	public function admin_setup() {

		// Text Editor.
		wp_enqueue_editor();
		wp_enqueue_script( 'organic-widgets-toggle-text-title', plugin_dir_url( __FILE__ ) . 'js/toggle-widgets.js', array( 'jquery', 'wp-embed', 'underscore' ), '1.0', true );
		wp_localize_script( 'organic-widgets-toggle-text-title', 'OrganicToggleWidget', array(
			'id_base' => $this->id_base,
		) );
		wp_add_inline_script( 'organic-widgets-toggle-text-title', 'wp.organicToggleWidget.init();', 'after' );

		// Repeatable Form Items.
		if ( ! wp_script_is( 'organic-widgets-module-repeatable-form-item-js' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-repeatable-form-item-js', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-repeatable-form-items.js', array( 'jquery' ), '1.0', true );
		}

		// Content Aligner.
		if ( ! wp_script_is( 'organic-widgets-module-content-aligner' ) && is_customize_preview() ) {
			wp_enqueue_script( 'organic-widgets-module-content-aligner', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-content-aligner.js', array( 'jquery' ), '1.0', true );
		}

		wp_enqueue_media();

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'organic-widgets-module-color-picker', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-color-picker.js', array( 'jquery', 'wp-color-picker' ), '1.0', true );

		wp_enqueue_script( 'organic-widgets-module-image-background', ORGANIC_WIDGETS_PRO_ADMIN_JS_DIR . 'organic-widgets-module-image-background.js', array( 'jquery', 'media-upload', 'media-views', 'wp-color-picker' ), '1.0', true );
		wp_localize_script( 'organic-widgets-module-image-background', 'OrganicWidgetBG', array(
			'frame_title'  => __( 'Select an Image', 'organic-widgets-pro' ),
			'button_title' => __( 'Insert Into Widget', 'organic-widgets-pro' ),
		) );

	}

	/**
	 * Enqueue public javascript.
	 */
	public function public_scripts() {

		wp_enqueue_script( 'jquery-ui-accordion' );
		wp_enqueue_script( 'jquery-ui-tabs' );

		if ( ! wp_script_is( 'organic-widgets-backgroundimagebrightness-js' ) ) {
			wp_enqueue_script( 'organic-widgets-backgroundimagebrightness-js', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/jquery.backgroundbrightness.js', array( 'jquery' ), '1.0', true );
		}

		if ( ! wp_script_is( 'organic-widgets-toggle' ) ) {
			wp_enqueue_script( 'organic-widgets-toggle', ORGANIC_WIDGETS_PRO_BASE_DIR . 'public/js/toggle-setup.js', array( 'jquery' ), '1.0', false );
		}

	}

} // class Organic_Widgets_Pro_Toggle_Widget
