<?php
/**
 * This template is used to manage style options.
 *
 * @package Organic Startup
 * @since Organic Startup 1.0
 */

/**
 * Changes styles upon user defined options.
 */
function organic_startup_custom_styles() {

	$header_image = get_header_image();
	$header_width = get_theme_mod( 'organic_startup_header_width', '' );
	$hero_width = get_theme_mod( 'organic_startup_hero_width', '1240px' );
	$content_width = get_theme_mod( 'organic_startup_content_width', '1240px' );
	$footer_width = get_theme_mod( 'organic_startup_footer_width', '' );
	$site_width = get_theme_mod( 'organic_startup_site_width', '' );
	$display_title = get_theme_mod( 'organic_startup_site_title', '1' );
	$display_tagline = get_theme_mod( 'organic_startup_site_tagline', '1' );
	$nav_bg = get_theme_mod( 'organic_startup_colors_nav', '#ffffff' );
	$content_bg = get_theme_mod( 'organic_startup_colors_content', '#ffffff' );
	$footer_bg = get_theme_mod( 'organic_startup_colors_footer', '#f4f4f4' );
	$site_title_color = get_theme_mod( 'organic_startup_colors_site_title', '#000000' );
	$link_color = get_theme_mod( 'organic_startup_colors_links', '#00cc66' );
	$link_hover_color = get_theme_mod( 'organic_startup_colors_links_hover', '#009966' );
	$heading_link_color = get_theme_mod( 'organic_startup_colors_heading_links', '#000000' );
	$heading_link_hover_color = get_theme_mod( 'organic_startup_colors_heading_links_hover', '#009966' );
	$button_color = get_theme_mod( 'organic_startup_colors_button', '#00cc66' );
	$button_hover_color = get_theme_mod( 'organic_startup_colors_button_hover', '#009966' );
	$font_pairing = get_theme_mod( 'organic_startup_fonts', 'quicksand_roboto' );
	$nav_font = get_theme_mod( 'organic_startup_nav_font', 'roboto' );
	$title_font = get_theme_mod( 'organic_startup_title_font', 'quicksand' );
	$title_font_weight = get_theme_mod( 'organic_startup_title_font_weight', 'normal' );
	?>

	<style type="text/css">

	.wp-custom-header {
		<?php if ( ! empty( $header_image ) ) { ?>
			background-image: url('<?php header_image(); ?>');
		<?php } ?>
	}

	#nav-bar .flex-row {
		<?php
		if ( $header_width ) {
			echo 'max-width: ' . esc_html( $header_width ) . ';';
		};
		?>
	}

	.content {
		<?php
		if ( $content_width ) {
			echo 'max-width: ' . esc_html( $content_width ) . ';';
		};
		?>
	}

	#footer .content, #footer .footer-information {
		<?php
		if ( $footer_width ) {
			echo 'max-width: ' . esc_html( $footer_width ) . ';';
		};
		?>
	}

	#body, #footer {
		<?php
		if ( $site_width ) {
			echo 'max-width: ' . esc_html( $site_width ) . ';';
		};
		?>
	}

	.site-title {
		<?php
		if ( '1' != $display_title ) {
			echo
			'position: absolute;
			text-indent: -9999px;
			margin: 0px;
			padding: 0px;';
		};
		?>
	}

	.site-description {
		<?php
		if ( '1' != $display_tagline ) {
			echo
			'position: absolute;
			left: -9999px;
			margin: 0px;
			padding: 0px;';
		};
		?>
	}

	#nav-bar, .menu ul.sub-menu, .menu ul.children {
		<?php
		if ( $nav_bg ) {
			echo 'background-color: ' . esc_html( $nav_bg ) . ';';
		};
		?>
	}

	<?php if ( $content_bg ) { ?>
	#body, .blog-holder .feature-img + .article > h2 {
		background-color: <?php echo esc_html( $content_bg ); ?> ;
	}
	<?php } ?>

	#footer {
		<?php
		if ( $footer_bg ) {
			echo 'background-color: ' . esc_html( $footer_bg ) . ';';
		};
		?>
	}

	.startup-header-solid .site-title a, .startup-header-solid .site-title a:link, .startup-header-solid .site-title a:visited,
	.startup-header-static .site-title a, .startup-header-static .site-title a:link, .startup-header-static .site-title a:visited {
		<?php
		if ( $site_title_color ) {
			echo 'color: ' . esc_html( $site_title_color ) . ';';
		};
		?>
	}

	a, a:link, a:visited, .footer-widgets a, .footer-widgets a:link, .footer-widgets a:visited,
	.widget ul.menu li a, .widget ul.menu li a:link, .widget ul.menu li a:visited,
	.widget ul.menu li ul.sub-menu li a, .widget ul.menu li ul.sub-menu li a:link, .widget ul.menu li ul.sub-menu li a:visited,
	a.previous-post span, a.next-post span, .circle-next-prev i {
		<?php
		if ( $link_color ) {
			echo 'color: ' . esc_html( $link_color ) . ';';
		};
		?>
	}
	.circle-next-prev {
		<?php
		if ( $link_color ) {
			echo 'border-color: ' . esc_html( $link_color ) . ';';
		};
		?>
	}

	a:hover, a:focus, a:active, .footer-widgets a:hover, footer-widgets a:focus, footer-widgets a:active,
	.widget ul.menu li a:hover, .widget ul.menu li a:focus, .widget ul.menu li a:active,
	.widget ul.menu li ul.sub-menu li a:hover, .widget ul.menu li ul.sub-menu li a:focus, .widget ul.menu li ul.sub-menu li a:active,
	.widget ul.menu .current_page_item a, .widget ul.menu .current-menu-item a,
	.previous-post:hover .circle-next-prev i, .next-post:hover .circle-next-prev i, .previous-post:hover span, .next-post:hover span {
		<?php
		if ( $link_hover_color ) {
			echo 'color: ' . esc_html( $link_hover_color ) . ';';
		};
		?>
	}

	.previous-post:hover .circle-next-prev, .next-post:hover .circle-next-prev {
		<?php
		echo 'border-color: ' . esc_html( $link_hover_color ) . ';';
		?>
	}

	h1 a, h2 a, h3 a, h4 a, h5 a, h6 a,
	h1 a:link, h2 a:link, h3 a:link, h4 a:link, h5 a:link, h6 a:link,
	h1 a:visited, h2 a:visited, h3 a:visited, h4 a:visited, h5 a:visited, h6 a:visited {
		<?php
		if ( $heading_link_color ) {
			echo 'color: ' . esc_html( $heading_link_color ) . ';';
		};
		?>
	}

	h1 a:hover, h2 a:hover, h3 a:hover, h4 a:hover, h5 a:hover, h6 a:hover,
	h1 a:focus, h2 a:focus, h3 a:focus, h4 a:focus, h5 a:focus, h6 a:focus,
	h1 a:active, h2 a:active, h3 a:active, h4 a:active, h5 a:active, h6 a:active {
		<?php
		if ( $heading_link_hover_color ) {
			echo 'color: ' . esc_html( $heading_link_hover_color ) . ';';
		};
		?>
	}

	button, .button, a.button, a.button:link, a.button:visited, a.comment-reply-link, a.comment-reply-link:link, a.comment-reply-link:visited,
	button.give-btn, #searchsubmit, #prevLink a, #nextLink a, input#submit, input[type='submit'],
	.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button {
		<?php
		if ( $button_color ) {
			echo 'background-color: ' . esc_html( $button_color ) . ';';
		};
		?>
	}

	button:hover, button:focus, button:active, a.comment-reply-link:hover, a.comment-reply-link:focus, a.comment-reply-link:active,
	.button:hover, a.button:hover, a.button:focus, a.button:active, button.give-btn:hover, #searchsubmit:hover, #prevLink a:hover,
	#nextLink a:hover, input#submit:hover, input[type='submit']:hover, .gallery a:hover,
	.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover {
		<?php
		if ( $button_hover_color ) {
			echo 'background-color: ' . esc_html( $button_hover_color ) . ';';
		};
		?>
	}

	<?php
	$fonts = array(
		0 => array(),
		1 => array(),
		2 => array(),
		// 3 => array(),
	);
	switch ( $font_pairing ) {
		case 'helvetica_neue_double':
			$fonts[0]['font'] = "font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;";
			$fonts[1]['font'] = "font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;";
			break;
		case 'quicksand_roboto':
			$fonts[0]['font'] = "font-family: 'Quicksand', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Roboto', sans-serif;";
			break;
		case 'oswald_droid_serif':
			$fonts[0]['font'] = "font-family: 'Oswald', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Droid Serif', serif;";
			break;
		case 'montserrat_merriweather':
			$fonts[0]['font'] = "font-family: 'Montserrat', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'raleway_roboto_slab':
			$fonts[0]['font'] = "font-family: 'Roboto Slab', serif;";
			$fonts[1]['font'] = "font-family: 'Raleway', sans-serif;";
			break;
		case 'playfair_display_source_sans_pro':
			$fonts[0]['font'] = "font-family: 'Playfair Display', serif;";
			$fonts[1]['font'] = "font-family: 'Source Sans Pro', sans-serif;";
			break;
		case 'quicksand_lora':
			$fonts[0]['font'] = "font-family: 'Quicksand', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Lora', serif;";
			break;
		case 'cinzel_roboto':
			$fonts[0]['font'] = "font-family: 'Cinzel', serif;";
			$fonts[1]['font'] = "font-family: 'Roboto', sans-serif;";
			break;
		case 'merriweather_encode_sans':
			$fonts[0]['font'] = "font-family: 'Merriweather', serif;";
			$fonts[1]['font'] = "font-family: 'Encode Sans', sans-serif;";
			break;
		case 'lato_merriweather':
			$fonts[0]['font'] = "font-family: 'Lato', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'roboto_merriweather':
			$fonts[0]['font'] = "font-family: 'Roboto', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'roboto_condensed_roboto':
			$fonts[0]['font'] = "font-family: 'Roboto Condensed', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Roboto', sans-serif;";
			break;
		case 'raleway_open_sans':
			$fonts[0]['font'] = "font-family: 'Raleway', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Open Sans', sans-serif;";
			break;
		case 'abril_poppins':
			$fonts[0]['font'] = "font-family: 'Abril Fatface', serif;";
			$fonts[1]['font'] = "font-family: 'Poppins', sans-serif;";
			break;
		case 'oxygen_noto_serif':
			$fonts[0]['font'] = "font-family: 'Oxygen', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Noto Serif', serif;";
			break;
		case 'aleo_muli':
			$fonts[0]['font'] = "font-family: 'Aleo', serif;";
			$fonts[1]['font'] = "font-family: 'Muli', sans-serif;";
			break;
		default:
			$fonts[0]['font'] = "font-family: 'Helvetica Neue', Arial, sans-serif;";
			$fonts[1]['font'] = "font-family: 'Helvetica Neue', Arial, sans-serif;";
			break;
	}

	switch ( $title_font ) {
		case 'rochester':
			$fonts[2]['font'] = "font-family: 'Rochester', cursive;";
			break;
		case 'staatliches':
			$fonts[2]['font'] = "font-family: 'Staatliches', sans-serif;";
			break;
		case 'overlock':
			$fonts[2]['font'] = "font-family: 'Overlock', sans-serif;";
			break;
		case 'noto_serif':
			$fonts[2]['font'] = "font-family: 'Noto Serif', serif;";
			break;
		case 'poppins':
			$fonts[2]['font'] = "font-family: 'Poppins', sans-serif;";
			break;
		case 'muli':
			$fonts[2]['font'] = "font-family: 'Muli', sans-serif;";
			break;
		case 'oxygen':
			$fonts[2]['font'] = "font-family: 'Oxygen', sans-serif;";
			break;
		case 'pt_sans':
			$fonts[2]['font'] = "font-family: 'PT Sans', sans-serif;";
			break;
		case 'libre_franklin':
			$fonts[2]['font'] = "font-family: 'Libre Franklin', sans-serif;";
			break;
		case 'lato':
			$fonts[2]['font'] = "font-family: 'Lato', sans-serif;";
			break;
		case 'oswald':
			$fonts[2]['font'] = "font-family: 'Oswald', sans-serif;";
			break;
		case 'droid_serif':
			$fonts[2]['font'] = "font-family: 'Droid Serif', serif;";
			break;
		case 'montserrat':
			$fonts[2]['font'] = "font-family: 'Montserrat', sans-serif;";
			break;
		case 'merriweather':
			$fonts[2]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'raleway':
			$fonts[2]['font'] = "font-family: 'Raleway', sans-serif;";
			break;
		case 'roboto':
			$fonts[2]['font'] = "font-family: 'Roboto', serif;";
			break;
		case 'roboto_slab':
			$fonts[2]['font'] = "font-family: 'Roboto Slab', serif;";
			break;
		case 'playfair_display':
			$fonts[2]['font'] = "font-family: 'Playfair Display', serif;";
			break;
		case 'source_sans_pro':
			$fonts[2]['font'] = "font-family: 'Source Sans Pro', sans-serif;";
			break;
		case 'quicksand':
			$fonts[2]['font'] = "font-family: 'Quicksand', sans-serif;";
			break;
		case 'lora':
			$fonts[2]['font'] = "font-family: 'Lora', serif;";
			break;
		case 'helvetica_neue':
			$fonts[2]['font'] = "font-family: 'Helvetica Neue', 'Helvetica', Arial, sans-serif;";
			break;
		case 'encode_sans':
			$fonts[2]['font'] = "font-family: 'Encode Sans', sans-serif;";
			break;
		case 'lily_script':
			$fonts[2]['font'] = "font-family: 'Lily Script One', serif;";
			break;
		case 'cinzel':
			$fonts[2]['font'] = "font-family: 'Cinzel', serif;";
			break;
		case 'shrikhand':
			$fonts[2]['font'] = "font-family: 'Shrikhand', serif;";
			break;
		case 'amatic_sc':
			$fonts[2]['font'] = "font-family: 'Amatic SC', sans-serif;";
			break;
		case 'berkshire_swash':
			$fonts[2]['font'] = "font-family: 'Berkshire Swash', serif;";
			break;
		case 'abril_fatface':
			$fonts[2]['font'] = "font-family: 'Abril Fatface', serif;";
			break;
		case 'patua_one':
			$fonts[2]['font'] = "font-family: 'Patua One', serif;";
			break;
		case 'monoton':
			$fonts[2]['font'] = "font-family: 'Monoton', sans-serif;";
			break;
		default:
			$fonts[2]['font'] = "font-family: 'Helvetica Neue', Arial, sans-serif;";
			break;
	}

	switch ( $nav_font ) {
		case 'noto_serif':
			$fonts[3]['font'] = "font-family: 'Noto Serif', serif;";
			break;
		case 'poppins':
			$fonts[3]['font'] = "font-family: 'Poppins', sans-serif;";
			break;
		case 'muli':
			$fonts[3]['font'] = "font-family: 'Muli', sans-serif;";
			break;
		case 'oxygen':
			$fonts[3]['font'] = "font-family: 'Oxygen', sans-serif;";
			break;
		case 'pt_sans':
			$fonts[3]['font'] = "font-family: 'PT Sans', sans-serif;";
			break;
		case 'libre_franklin':
			$fonts[3]['font'] = "font-family: 'Libre Franklin', sans-serif;";
			break;
		case 'lato':
			$fonts[3]['font'] = "font-family: 'Lato', sans-serif;";
			break;
		case 'oswald':
			$fonts[3]['font'] = "font-family: 'Oswald', sans-serif;";
			break;
		case 'droid_serif':
			$fonts[3]['font'] = "font-family: 'Droid Serif', serif;";
			break;
		case 'montserrat':
			$fonts[3]['font'] = "font-family: 'Montserrat', sans-serif;";
			break;
		case 'merriweather':
			$fonts[3]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'raleway':
			$fonts[3]['font'] = "font-family: 'Raleway', sans-serif;";
			break;
		case 'roboto':
			$fonts[3]['font'] = "font-family: 'Roboto', serif;";
			break;
		case 'roboto_slab':
			$fonts[3]['font'] = "font-family: 'Roboto Slab', serif;";
			break;
		case 'playfair_display':
			$fonts[3]['font'] = "font-family: 'Playfair Display', serif;";
			break;
		case 'source_sans_pro':
			$fonts[3]['font'] = "font-family: 'Source Sans Pro', sans-serif;";
			break;
		case 'quicksand':
			$fonts[3]['font'] = "font-family: 'Quicksand', sans-serif;";
			break;
		case 'lora':
			$fonts[3]['font'] = "font-family: 'Lora', serif;";
			break;
		case 'helvetica_neue':
			$fonts[3]['font'] = "font-family: 'Helvetica Neue', 'Helvetica', Arial, sans-serif;";
			break;
		case 'encode_sans':
			$fonts[3]['font'] = "font-family: 'Encode Sans', sans-serif;";
			break;
		case 'cinzel':
			$fonts[3]['font'] = "font-family: 'Cinzel', serif;";
			break;
		case 'shrikhand':
			$fonts[3]['font'] = "font-family: 'Shrikhand', serif;";
			break;
		case 'amatic_sc':
			$fonts[3]['font'] = "font-family: 'Amatic SC', sans-serif;";
			break;
		case 'berkshire_swash':
			$fonts[3]['font'] = "font-family: 'Berkshire Swash', serif;";
			break;
		case 'abril_fatface':
			$fonts[3]['font'] = "font-family: 'Abril Fatface', serif;";
			break;
		case 'patua_one':
			$fonts[3]['font'] = "font-family: 'Patua One', serif;";
			break;
		default:
			$fonts[3]['font'] = "font-family: 'Helvetica Neue', Arial, sans-serif;";
			break;
	}
	?>

	<?php if ( $fonts[0]['font'] ) { ?>
	h1, h2, h3, h4, h5, h6, .site-description,
	.edit-post-visual-editor h1.editor-rich-text__tinymce,
	.edit-post-visual-editor h2.editor-rich-text__tinymce,
	.edit-post-visual-editor h3.editor-rich-text__tinymce,
	.edit-post-visual-editor h4.editor-rich-text__tinymce,
	.edit-post-visual-editor h5.editor-rich-text__tinymce,
	.edit-post-visual-editor h6.editor-rich-text__tinymce {
		<?php echo $fonts[0]['font']; ?>
	}
	<?php } ?>

	<?php if ( $fonts[1]['font'] ) { ?>
	body, table, form {
		<?php echo $fonts[1]['font']; ?>
	}
	<?php } ?>

	<?php if ( $fonts[2]['font'] ) { ?>
	.site-title, .editor-post-title__block .editor-post-title__input {
		<?php echo $fonts[2]['font']; ?>
	}
	<?php } ?>

	<?php if ( $fonts[3]['font'] ) { ?>
	#navigation, button, .button, .reply a, input[type=submit], .sidr li a {
		<?php echo $fonts[3]['font']; ?>
	}
	<?php } ?>

	<?php if ( $title_font_weight ) { ?>
	.site-title {
		<?php echo 'font-weight: ' . esc_html( $title_font_weight ) . ';'; ?>
	}
	<?php } ?>

	</style>

	<?php
}
add_action( 'wp_head', 'organic_startup_custom_styles', 100 );

/**
 * Changes styles in Gutenberg editor upon user defined options.
 */
function organic_startup_gutenberg_custom_styles() {

	$font_pairing = get_theme_mod( 'organic_startup_fonts', 'quicksand_roboto' );

	$fonts = array(
		0 => array(),
		1 => array(),
	);
	switch ( $font_pairing ) {
		case 'helvetica_neue_double':
			$fonts[0]['font'] = "font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;";
			$fonts[1]['font'] = "font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;";
			break;
		case 'quicksand_roboto':
			$fonts[0]['font'] = "font-family: 'Quicksand', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Roboto', sans-serif;";
			break;
		case 'oswald_droid_serif':
			$fonts[0]['font'] = "font-family: 'Oswald', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Droid Serif', serif;";
			break;
		case 'montserrat_merriweather':
			$fonts[0]['font'] = "font-family: 'Montserrat', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'raleway_roboto_slab':
			$fonts[0]['font'] = "font-family: 'Roboto Slab', serif;";
			$fonts[1]['font'] = "font-family: 'Raleway', sans-serif;";
			break;
		case 'playfair_display_source_sans_pro':
			$fonts[0]['font'] = "font-family: 'Playfair Display', serif;";
			$fonts[1]['font'] = "font-family: 'Source Sans Pro', sans-serif;";
			break;
		case 'quicksand_lora':
			$fonts[0]['font'] = "font-family: 'Quicksand', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Lora', serif;";
			break;
		case 'cinzel_roboto':
			$fonts[0]['font'] = "font-family: 'Cinzel', serif;";
			$fonts[1]['font'] = "font-family: 'Roboto', sans-serif;";
			break;
		case 'merriweather_encode_sans':
			$fonts[0]['font'] = "font-family: 'Merriweather', serif;";
			$fonts[1]['font'] = "font-family: 'Encode Sans', sans-serif;";
			break;
		case 'lato_merriweather':
			$fonts[0]['font'] = "font-family: 'Lato', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'roboto_merriweather':
			$fonts[0]['font'] = "font-family: 'Roboto', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Merriweather', serif;";
			break;
		case 'roboto_condensed_roboto':
			$fonts[0]['font'] = "font-family: 'Roboto Condensed', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Roboto', sans-serif;";
			break;
		case 'raleway_open_sans':
			$fonts[0]['font'] = "font-family: 'Raleway', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Open Sans', sans-serif;";
			break;
		case 'abril_poppins':
			$fonts[0]['font'] = "font-family: 'Abril Fatface', serif;";
			$fonts[1]['font'] = "font-family: 'Poppins', sans-serif;";
			break;
		case 'oxygen_noto_serif':
			$fonts[0]['font'] = "font-family: 'Oxygen', sans-serif;";
			$fonts[1]['font'] = "font-family: 'Noto Serif', serif;";
			break;
		case 'aleo_muli':
			$fonts[0]['font'] = "font-family: 'Aleo', serif;";
			$fonts[1]['font'] = "font-family: 'Muli', sans-serif;";
			break;
		default:
			$fonts[0]['font'] = "font-family: 'Helvetica Neue', Arial, sans-serif;";
			$fonts[1]['font'] = "font-family: 'Helvetica Neue', Arial, sans-serif;";
			break;
	}

	?>

	<style>

	<?php if ( $fonts[0]['font'] ) { ?>
	.edit-post-visual-editor h1.editor-rich-text__tinymce,
	.edit-post-visual-editor h2.editor-rich-text__tinymce,
	.edit-post-visual-editor h3.editor-rich-text__tinymce,
	.edit-post-visual-editor h4.editor-rich-text__tinymce,
	.edit-post-visual-editor h5.editor-rich-text__tinymce,
	.edit-post-visual-editor h6.editor-rich-text__tinymce,
	.edit-post-visual-editor .editor-post-title__block .editor-post-title__input {
		<?php echo $fonts[0]['font']; ?>
	}
	<?php } ?>

	<?php if ( $fonts[1]['font'] ) { ?>
	.edit-post-visual-editor .mce-content-body,
	.edit-post-visual-editor .editor-rich-text__tinymce {
		<?php echo $fonts[1]['font']; ?>
	}
	<?php } ?>

	</style>

	<?php
}
add_action( 'enqueue_block_assets', 'organic_startup_gutenberg_custom_styles', 99 );
